!(function (global, doc) {

    if (global.lgBridge) {
        return;
    }

    var VERSION = "1.0.1";
    var CUSTOM_PROTOCOL_SCHEME = 'lagou';
    var QUEUE_HAS_MESSAGE = 'bridge/notice';
    var STATE = {
        notFound: 1004,
        success: 1002,
        error: 1005
    };

    var getUniqueId = (function () {
        var uniqueId = 1;
        return function () {
            return 'lg_' + (uniqueId++) + '_' + new Date().getTime();
        };
    })();

    function Observe() {
        this.queue = {};
    }

    Observe.CONST = {
        error: 'error',
        notFound: 'notFound'
    };

    Observe.prototype.on = function (event, callback) {
        if (!this.queue[event]) {
            this.queue[event] = [];
        }
        this.queue[event].push(callback);
    };

    Observe.prototype.trigger = function (event, data) {
        if (!this.queue[event]) {
            return Observe.CONST.notFound;
        }
        var res;
        this.queue[event].forEach(function (cb, i) {
            try {
                res = cb(data);
            } catch (e) {
                res =  Observe.CONST.error;
            }
        });
        return res;
    };

    function Base() {

        var that = this;

        that.baseObserverIns = new Observe();

        that.const = {
            parse: 'pasre',
            status: Observe.CONST
        };

        window._nativeToWebview = function (message) {
            return that.baseObserverIns.trigger(that.const.parse, message);
        };

    }

    Base.prototype = {
        request: function (url) {
            var img = new Image();
            img.onerror = img.onload = img.onabort = function() {
                img = null;
            };
            img.src =  url + "&t=" + (+new Date());          
        },
        response: function (method, callback) {
            this.baseObserverIns.on(method, callback);
        }
    };

    function Bridge(base) {

        var that = this;

        that.base = base;
        
        this.const = {
            query: 'query',
            dispatch: 'dispatch'
        };

        base.response(base.const.parse, function (message) {
            if (typeof message === 'string') {
                try {
                    message = JSON.parse(message);
                } catch(e) {
                    throw (e); 
                }
            }
            var key;
            var statusConst = base.const.status;
            if (message.action === that.const.query) {
                return base.baseObserverIns.trigger(message.id);
            }
            if (message.action === that.const.dispatch) {
                message.methodName ? (key = message.methodName) : (key = message.callbackId);
                key && setTimeout(function() {
                    var status = base.baseObserverIns.trigger(key, message);
                    if (status === statusConst.notFound || status === statusConst.error) {
                        message.methodName && message.callbackId && that.request({
                            callbackId: message.callbackId,
                            state: status === statusConst.notFound ? STATE.notFound : STATE.error,
                            message: status
                        });
                    }
                }, 0);
            }
        });

    }

    Bridge.prototype.request = function(message) {

        var that = this;

        var id = getUniqueId();

        that.base.response(id, function () {
            return message;
        });

        that.base.request(CUSTOM_PROTOCOL_SCHEME + '://' + QUEUE_HAS_MESSAGE + '?id=' + id);   
    };

    Bridge.prototype.response = function(event, callback) {

        var that = this;
        
        that.base.response(event, callback);

    };

    function LgBridge() {

        this.STATE = STATE;
        this.version = VERSION;
    };

    LgBridge.prototype.request = function(methodName, option, callback) {

        !option && (option = {});

        if (arguments.length === 2 && typeof option === 'function') {
            callback = option;
        }        

        var message = {
            methodName: methodName,
            data: option.data,
            ext: option.ext
        };

        if (callback) {
            message.callbackId = getUniqueId();
            bridge.response(message.callbackId, function (data) {
                var result = {
                    data: data.data,
                    state: data.state,
                    message: data.message
                };
                callback(result);
            });
        }

        bridge.request(message);

    };

    LgBridge.prototype.response = function(methodName, callback) {

        bridge.response(methodName, function (message) {
            var callbackId = message.callbackId;
            if (!callbackId) {
                callback(message.data, undefined, message.ext);
                return;
            }
            var response = function (data) {
                var message = {
                    state: STATE.success,
                    data: data,
                    callbackId: callbackId
                };
                bridge.request(message);
            };
            callback(message.data, response, message.ext);
        });

    };

    var base = new Base();
        
    var bridge = new Bridge(base);

    global.lgBridge = new LgBridge();

    var readyEvent = document.createEvent('Events');
    readyEvent.initEvent('LgBridgeReady');
    readyEvent.bridge = lgBridge;
    document.dispatchEvent(readyEvent);

})(window, document);


