package com.alpha.lagouapk.manager.net

import com.ApiService
import com.alpha.lagouapk.bean.interview.CInterviewDetailRes
import com.alpha.lagouapk.bean.interview.CInterviewScheduleReq
import com.alpha.lagouapk.bean.interview.CInterviewScheduleRes
import com.lagou.commonlibs.utils.TimeUtils
import com.common.utils.PageHelper
import com.lagou.baselib.net.httpnetback.AdapterBaseCallBack
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListListenerImpl
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.lagouee.bean.jsonbean.interview.CInterviewDetailReq
import com.lagou.lagouee.ui.resume.list.interview.MinuteGroup
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import java.util.*

/**
 * @date 创建时间：2020/7/24
 * @author 作者：codeman
 * @Description  描述：C端面试相关网络请求
 * @version
 */
class CInterviewNetManager {

    companion object {
        /***
         * 获取C端面试详情
         */
        fun getInterviewDetail(interviewId: Long?, commonListenerImpl: OnAdapterCommonListenerImpl<CInterviewDetailRes, HttpResponse<CInterviewDetailRes>>?){
            if (commonListenerImpl == null || !commonListenerImpl.isActive){
                return
            }
            if (interviewId == null){
                return
            }

            commonListenerImpl.showLoading()
            ApiService.api.getCInterviewDetail(CInterviewDetailReq(interviewId)).enqueue(object : AdapterBaseCallBack<CInterviewDetailRes>(commonListenerImpl){
                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<CInterviewDetailRes>?) {
                    commonListenerImpl.onSuccess(response?.content)
                }
            })
        }

    }

    class InterviewListRequest {

        private var mPageNo = 1

        /**
         * 同一个时间点可能对应多个面试
         */
        private val mScheduleMap: HashMap<Long, CInterviewScheduleRes.CInterviewInfo> = HashMap()


        fun getInterviewList(interviewListReq: CInterviewScheduleReq?, first: Boolean,
                             adapterCommonListener: OnAdapterCommonListListenerImpl<List<Any>, HttpResponse<List<Any>>, Boolean>?) {
            if (adapterCommonListener == null || !adapterCommonListener.isActive) {
                return
            }
            if (interviewListReq == null) {
                return
            }
            if (first) {
                adapterCommonListener.showLoading()
                mPageNo = 1
            }
            interviewListReq.pageSize = PageHelper.COUNT_20
            interviewListReq.pageNo = mPageNo
            ApiService.api.getCInterviewSchedule(interviewListReq).enqueue(object : AdapterBaseCallBack<CInterviewScheduleRes?>(adapterCommonListener) {
                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<CInterviewScheduleRes?>?) {
                    val list = response?.content
                    val hasNext = list != null && list.isHasMore
                    if (hasNext) {
                        mPageNo++
                    }

                    var subList: MutableList<CInterviewScheduleRes.CInterviewInfo>? = list?.list
                    if (subList == null || subList.isEmpty()) {
                        if (first) {
                            adapterCommonListener.onNoData(null, first)
                            return
                        }

                        if (hasNext) {
                            adapterCommonListener.onSuccess(null, first)
                            return
                        }

                        adapterCommonListener.onNoMore(null, first)
                        return
                    }

                    ThreadUtil.compute {
                        synchronized(this@InterviewListRequest) {
                            if (first) {
                                mScheduleMap.clear()
                            }
                            // 包装处理数据
                            val result: List<Any>? = newList(subList)
                            ThreadUtil.ui {
                                if (!adapterCommonListener?.isActive) {
                                    return@ui
                                }
                                if (hasNext) {
                                    adapterCommonListener.onSuccess(result, first)
                                } else {
                                    adapterCommonListener.onNoMore(result, first)
                                }
                            }
                        }
                    }
                }

            })
        }

        /**
         * 重新装配数据
         */
        private fun newList(mutableList: MutableList<CInterviewScheduleRes.CInterviewInfo>?): List<Any>? {
            val list: MutableList<Any> = ArrayList()

            mutableList?.let {
                for (bean in mutableList) {
                    // set中的元素已非空
                    if (!mScheduleMap.containsKey(bean.interviewTime)){
                        list.add(MinuteGroup(bean.interviewTime, TimeUtils.secondToHM(bean.interviewTime)))
                        mScheduleMap[bean.interviewTime] = bean
                        list.add(bean)
                    }else{
                        list.add(bean)
                    }
                }
            }

            return list
        }

    }
}