package com.alpha.lagouapk.receiver

import cn.jpush.android.api.JPushInterface
import com.alpha.lagouapk.R
import com.common.integrate.push.TriplePushHelper.*
import com.common.integrate.push.PushType
import com.common.integrate.push.TriplePushHelper
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ShowLogInfo
import com.lagou.commonlibs.utils.LogUtils
import org.json.JSONObject


/**
 * 极光推送厂商通道分发
 * 推送依赖于类的路径，此路径{com.alpha.lagouapk.receiver.JPushTripleActivity}不可随意改动
 *
 * @author yph
 * @date 2020/3/20
 */
class JPushTripleActivity : BaseActivity() {

    override fun getContentLayoutId(): Int = R.layout.activity_triple_push

    override fun init() {
        // 获取华为平台附带的jpush信息
        var data = intent?.data?.toString()
        // 获取fcm、小米、oppo、vivo平台附带的jpush信息
        if (data.isNullOrEmpty()) {
            data = intent?.extras?.getString(KEY_EXTRA)
        }
        LogUtils.d(TAG, "JPush-----> --- triple push data:${data}")

        if (data.isNullOrEmpty()) {
            LogUtils.d(TAG, "JPush-----> --- triple push data is empty")
            NewJPushReceiver.startHomeBorC(this)
        } else {
            try {
                val jsonObject = JSONObject(data)
                val msgId: String = jsonObject.optString(KEY_MSGID)
                val whichPushSDK = jsonObject.optInt(KEY_WHICH_PUSH_SDK)
                val extras: String = jsonObject.optString(KEY_EXTRAS)
                val pushSDKName = getPushSDKName(whichPushSDK)
                LogUtils.d(TAG, "JPush-----> --- triple push data parse success-->channel:${pushSDKName},msgId:${msgId}")

                NewJPushReceiver.handleNotifyMessageOpened(this, extras)
                // 上报点击事件
                JPushInterface.reportNotificationOpened(this, msgId, whichPushSDK.toByte())
                AnalyticHelper.getInstance().sendShowInfo(ShowLogInfo().apply {
                    setAddress_Id("1pui")
                    addShowProp("jpush_id", msgId)
                    addShowProp("push_type",PushType.JPUSH.toString())
                    addShowProp("jpush_channel", pushSDKName)
                })
            } catch (e: Exception) {
                LogUtils.d(TAG, "JPush-----> --- triple push parse error:${e.message}")
                NewJPushReceiver.startHomeBorC(this)
            }
        }
        finish()
    }

    private fun getPushSDKName(whichPushSDK: Int) = when (whichPushSDK) {
        TriplePushHelper.JPUSH -> CHANNEL_NAME_JPUSH
        TriplePushHelper.XIAOMI -> CHANNEL_NAME_XIAOMI
        TriplePushHelper.HUAWEI -> CHANNEL_NAME_HUAWEI
        TriplePushHelper.MEIZU -> CHANNEL_NAME_MEIZU
        TriplePushHelper.OPPO -> CHANNEL_NAME_OPPO
        TriplePushHelper.VIVO -> CHANNEL_NAME_VIVO
        TriplePushHelper.FCM -> CHANNEL_NAME_FCM
        else -> CHANNEL_NAME_JPUSH
    }

    override fun enterMustLogin(): Boolean = false

    override fun needCheckInit(): Boolean = false

    companion object {
        private const val TAG = "JPushTripleActivity"

        private const val KEY_EXTRA = "JMessageExtra"

        /**消息Id */
        private const val KEY_MSGID = "msg_id"

        /**该通知的下发通道 */
        private const val KEY_WHICH_PUSH_SDK = "rom_type"

        /**通知标题 */
        private const val KEY_TITLE = "n_title"

        /**通知内容 */
        private const val KEY_CONTENT = "n_content"

        /**通知附加字段 */
        private const val KEY_EXTRAS = "n_extras"

    }

}
