package com.alpha.lagouapk.ui.company

import android.content.Context
import android.graphics.Canvas
import android.graphics.Paint
import android.text.*
import android.text.style.ImageSpan
import android.util.AttributeSet
import android.util.SparseBooleanArray
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.TextView
import com.alpha.lagouapk.Interface.OnCompanyItemListener
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.CompanyListBean.CompanyMsgVosBean
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.impl.GlideOptionHelper
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.utils.DensityUtil
import com.lagou.commonlibs.utils.ImageUrlUtils
import kotlinx.android.synthetic.main.item_company_list.view.*

/**
 *
 * @Author:         leon
 * @CreateDate:     1/21/21 12:31 PM
 * @Description:公司库item
 */

class CompanyItemView : FrameLayout {
    constructor(context: Context) : this(context, null)
    constructor(context: Context, attrs: AttributeSet?) : this(context, attrs, 0)
    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : super(context, attrs, defStyleAttr) {
        LayoutInflater.from(context).inflate(R.layout.item_company_list, this)
        TEXT_WIDTH = resources.displayMetrics.widthPixels - resources.getDimensionPixelSize(R.dimen.dp_122)
    }

    companion object {
        /**
         * 占位标记
         */
        private const val SPACE = "{space}"
    }
    /**
     * 一句话描述的宽度
     */
    private var TEXT_WIDTH = 0
    private val mOpenMap: SparseBooleanArray = SparseBooleanArray()

    @JvmOverloads
    fun setData(bean: CompanyMsgVosBean?, index: Int,dividerDrawableRes: Int = R.drawable.bg_company_list_line) {
        if (bean == null) {
            return
        }
        context?.let {
            companyItmRootView.setOnClickListener { mListener?.selectCompany(index,bean) }
            ImageLoadUtils.with(context)
                    .load(ImageUrlUtils.getLagouImageUrl(bean.companyLogo))
                    .bitmapTransform(RoundTransform(3f))
                    .displayOption(GlideOptionHelper.getLogoOption(context))
                    .borderRound(3)
                    .dontAnimate()
                    .into(iv_company_logo)

            if (TextUtils.isEmpty(bean.companyLogoWidget)) {
                iv_company_logo_widget.visibility = GONE
            } else {
                iv_company_logo_widget.visibility = VISIBLE
                ImageLoadUtils.with(context)
                    .load(ImageUrlUtils.getLagouImageUrl(bean.companyLogoWidget))
                    .bitmapTransform(RoundTransform(3f))
                    .dontAnimate()
                    .into(iv_company_logo_widget)
            }

            tv_company_name.text = bean.companyShortName
            rb_interview_score.isEditable = false
            rb_interview_score.visibility = if (bean.companyScore >= 1) View.VISIBLE else View.GONE
            tv_interview_score.visibility = if (bean.companyScore >= 1) View.VISIBLE else View.GONE
            rb_interview_score.rating = bean.companyScore.toInt()
            tv_looking_position.visibility = if (bean.positionNum > 0) View.VISIBLE else View.INVISIBLE
            tv_position_num.visibility = if (bean.positionNum > 0) View.VISIBLE else View.GONE
            tv_position_num.text = bean.positionNum.toString()
            setCompanyInfo(bean, dividerDrawableRes)
            //优先展示视频,如果没有视频,则展示标签或者一句话描述
            video_card.visibility = View.GONE
            if (!bean.videos.isNullOrEmpty()) {
                showVideoView()
                video_card.setData(bean.videos)
                video_card.setOnVideoItemClickListener { videoId ->
                    mListener?.onVideoItemClick(videoId)
                }
                return
            }
            // 标签或者一句话描述
            if (!bean.hiTags.isNullOrEmpty()) {
                showTagsView()
                bindTags(bean.hiTags)
                return
            }
            if (!bean.companyTags.isNullOrEmpty()) {
                showTagsView()
                bindTags(bean.companyTags)
                return
            }
            showDetailView()
            bindDetail(bean.description, index)

        }
    }

    private fun showVideoView() {
        fl_company_label.visibility = View.GONE
        s_label.visibility = View.INVISIBLE
        fl_detail_switch.visibility = View.GONE
        video_card.visibility = View.VISIBLE
    }

    private fun showTagsView() {
        fl_company_label.visibility = View.VISIBLE
        s_label.visibility = View.INVISIBLE
        fl_detail_switch.visibility = View.GONE
        video_card.visibility = View.GONE
    }

    private fun showDetailView() {
        fl_company_label.visibility = View.GONE
        s_label.visibility = View.GONE
        fl_detail_switch.visibility = View.VISIBLE
        video_card.visibility = View.GONE
    }

    private fun bindTags(tags: List<String>?) {
        if(tags.isNullOrEmpty()){
            return
        }
        fl_company_label.setHorizontalSpacing(DensityUtil.dip2px(context, 5f))
        fl_company_label.setMaxLines(1)
        fl_company_label.removeAllViews()
        for (i in tags.indices) {
            val tag: TextView = createTag()
            tag.text = tags[i]
            val params = ViewGroup.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT)
            fl_company_label.addView(tag, params)
        }
    }

    /**
     * 一句话描述
     */
    private fun bindDetail(description: String?, position: Int) {
        if (TextUtils.isEmpty(description)) {
            ib_detail_switch.visibility = View.INVISIBLE
            return
        }
        val staticLayout = StaticLayout(description, tv_company_detail.paint, TEXT_WIDTH, Layout.Alignment.ALIGN_NORMAL, 1f, 0f, false)
        val lineCount = staticLayout.lineCount
        if (lineCount > 1) {
            ib_detail_switch.visibility = View.VISIBLE
            val isOpen: Boolean = mOpenMap.get(position)
            ib_detail_switch.isSelected = isOpen
            tv_company_detail.text = description
            if (isOpen) {
                tv_company_detail.maxLines = lineCount
            } else {
                tv_company_detail.maxLines = 1
            }
            fl_detail_switch.setOnClickListener { v: View? ->
                // 当前
                val openState: Boolean = mOpenMap.get(position)
                ib_detail_switch.isSelected = !openState
                mOpenMap.put(position, !openState)
                if (openState) {
                    // 需要关闭
                    tv_company_detail.maxLines = 1
                } else {
                    // 需要展开
                    tv_company_detail.maxLines = lineCount
                }
            }
        } else {
            ib_detail_switch.visibility = View.INVISIBLE
            tv_company_detail.text = description
        }
    }

    private fun createTag(): TextView {
        val dp_5: Int = DensityUtil.dip2px(context, 5f)
        val dp_1_5: Int = DensityUtil.dip2px(context, 1.5f)
        val textView = TextView(context)
        textView.setTextColor(context.resources.getColor(R.color.color_666666))
        textView.textSize = 11f
        textView.setBackgroundResource(R.drawable.bg_company_list_tag)
        textView.setPadding(dp_5, dp_1_5, dp_5, dp_1_5)
        textView.gravity = Gravity.CENTER
        textView.ellipsize = TextUtils.TruncateAt.END
        textView.maxLines = 1
        return textView
    }

    private fun setCompanyInfo(bean: CompanyMsgVosBean, dividerDrawableRes: Int) {
        val builder = SpannableStringBuilder()
        //7.59加入判空
        if (bean.city != null) {
            builder.append(bean.city)
            setImageSpan(builder, dividerDrawableRes)
        }
        if (bean.fundsStage != null) {
            builder.append(bean.fundsStage)
            setImageSpan(builder, dividerDrawableRes)
        }
        if (bean.scale != null) {
            builder.append(bean.scale)
            setImageSpan(builder, dividerDrawableRes)
        }
        if (bean.industry != null) {
            builder.append(bean.industry)
        }
        tv_company_info.text = builder
    }

    private fun setImageSpan(builder: SpannableStringBuilder, dividerDrawableRes: Int) {
        builder.append(SPACE)
        builder.setSpan(createImageSpan(dividerDrawableRes), builder.length - SPACE.length, builder.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
    }

    private fun createImageSpan(dividerDrawableRes: Int): ImageSpan? {
        return object : ImageSpan(context, dividerDrawableRes) {
            override fun draw(canvas: Canvas, text: CharSequence, start: Int, end: Int, x: Float, top: Int, y: Int, bottom: Int, paint: Paint) {
                val drawable = drawable
                val fontMetricsInt = paint.fontMetricsInt
                val transY = (y + fontMetricsInt.descent + y + fontMetricsInt.ascent) / 2 - drawable.bounds.bottom / 2
                canvas.save()
                canvas.translate(x, transY.toFloat())
                drawable.draw(canvas)
                canvas.restore()
            }
        }
    }

    fun setRatingBarTitle(title: String) {
        tv_interview_score.text = title
    }

    fun setPositionNumTitle(title: String) {
        tv_looking_position.text = title
    }

    private var mListener: OnCompanyItemListener? = null

    fun setOnCompanyListAdapterListener(listener: OnCompanyItemListener?) {
        mListener = listener
    }
}