package com.alpha.lagouapk.ui.course

import android.content.Intent
import android.graphics.Bitmap
import android.os.Message
import com.alpha.lagouapk.Interface.logout.LogoutObserver
import com.alpha.lagouapk.Interface.logout.LogoutServer
import com.alpha.lagouapk.LagouApplication
import com.alpha.lagouapk.LagouMainPage
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.OpenScreenAdBean
import com.alpha.lagouapk.manager.AdManager
import com.alpha.lagouapk.manager.AdManager.OnAdCallback
import com.alpha.lagouapk.tools.DensityUtil
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.tools.SPUtils
import com.alpha.lagouapk.widget.AdDialog
import com.lagou.audiolib.dialog.AudioeBarDialog
import com.lagou.audiolib.event.CourseEventTags
import com.lagou.audiolib.manager.AudioPlayerManager
import com.lagou.audiolib.service.MediaPlayerService
import com.lagou.audiolib.utils.AudioIntentUtils
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.definition.c.AID
import com.lagou.baselib.analytic.definition.c.PageId
import com.lagou.baselib.util.BarUtil
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.inter.ALoadImgListener
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.course.home.HomeListFragment
import com.lagou.course.manager.HomeVipDialogManager
import com.lagou.course.monitor.VideoCatonHelper
import kotlinx.android.synthetic.main.activity_course_main.*

/**
 * 课程 (包括开悟和作者伴读)
 *
 * @author :  Alfred
 * @date   : 2019-08-29 11:39
 *
 */
class CourseMainActivity : BaseActivity(), LogoutObserver {

    companion object {
        /**
         * 教育弹窗广告
         */
        const val AD_TYPE_HOME_AD_DIALOG = 11
    }

    /**
     * 是否应该弹出vip会员广告弹框,主要是为了处理当弹出广告弹框的时候,不想在关闭广告弹框的时候立马弹出vip会员广告弹框,而是等切换到选课tab再弹出来
     */
    private var mIsShouldShowVipPop = true
    private lateinit var courseHomeFragment: HomeListFragment

    override fun getContentLayoutId() = R.layout.activity_course_main

    var adShowData: OpenScreenAdBean.AdShowDataList? = null

    override fun onResume() {
        super.onResume()

        // 优先展示广告弹窗，然后展示vip
        if (!showAdDialog(adShowData)) {
            showVipDialog()
        }

        AnalyticHelper.getInstance().sendClickInfo(PageId._1n2s, AID._1nd4)
    }

    override fun init() {
        BarUtil.transparentStatusBar(this)
        try {
            if (BarUtil.getStatusBarHeight(this) > 0) {
                frame_title_bar.setPadding(0, BarUtil.getStatusBarHeight(this), 0, 0)
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
        header_course_title.paint.isFakeBoldText = true
        courseHomeFragment = HomeListFragment()
        supportFragmentManager?.beginTransaction()?.add(R.id.mFlContent, courseHomeFragment)
            ?.commitAllowingStateLoss()
        /***
         * 已购点击页面
         */
        lin_purchase.setOnClickListener {
            IntentUtils.startPurchasedMainActivity(mContext)
        }
        //音频
        OkBus.getInstance().register(CourseEventTags.START_AUDIO, audioEvent)
        LogoutServer.getInstance().registerObserver(this)
        if (AudioPlayerManager.getInstance(mContext).isRunning()) {
            startAudio(false)
        } else {
            onClosePlayBarDialog()
        }

        // 获取视频配置
        VideoCatonHelper.getConfig()

        // 教育弹窗广告
        AdManager.fetchOpenScreenAd(
            AD_TYPE_HOME_AD_DIALOG,
            object : OnAdCallback<OpenScreenAdBean?> {
                override fun onGetAdDataSuccess(data: OpenScreenAdBean?) {
                    if (data != null && !ListUtil.isEmpty(data.adShowDataList)) {
                        adShowData = data.adShowDataList[0]
                    }
                }

                override fun onGetAdDataFail() {}
            })
    }

    override fun isEnableCommonBarSetting(): Boolean {
        return false
    }

    override fun getPageId(): String {
        return PageId._1n2s
    }

    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance().unRegister(audioEvent)
        LogoutServer.getInstance().removeObserver(this)
        if (dialog != null) {
            dialog!!.close()
        }
    }

    var dialog: AudioeBarDialog? = null
    private val audioEvent = Event { msg: Message? -> startAudio(true) }

    private fun startAudio(isPlay: Boolean) {
        if (dialog == null && parent is LagouMainPage) {
            dialog = AudioeBarDialog(parent)
        }
        dialog!!.setData()
        if (isPlay) {
            dialog!!.startPlay()
            // 开启服务
            val context = LagouApplication.getLagouApplication()
            AudioIntentUtils.startServiceNoException(
                context,
                Intent(context, MediaPlayerService::class.java)
            )
        }
        if (!dialog!!.isShowing) {
            dialog!!.show(fl_container)
        }
    }

    override fun onClosePlayBarDialog() {
        if (dialog != null) {
            dialog!!.close()
            dialog = null
        }
    }

    fun showVipDialog() {
        // 展示vip弹窗
        if (mIsShouldShowVipPop) {
            //如果当前切换到选课tab,而且应该弹出vip广告弹框的话 那就弹弹弹 骚年
            HomeVipDialogManager.getInstance().showVipDialog(this)
            mIsShouldShowVipPop = false
        }
    }

    /**
     * 展示广告弹窗
     */
    private fun showAdDialog(adShowData: OpenScreenAdBean.AdShowDataList?): Boolean {
        if (adShowData == null || !isShowAdDialog(adShowData.imageUrl)) {
            return false
        }

        ImageLoadUtils.with(this).load(adShowData.imageUrl).asBitmap()
            .into(object : ALoadImgListener<Bitmap?>() {
                override fun onResourceReady(resource: Bitmap?) {
                    if (resource == null && !isActivityEnable) {
                        return
                    }
                    val dialog = AdDialog.builder()
                        .jumpUrl(adShowData.infoLink)
                        .bitmapUrl(adShowData.imageUrl)
                        .bitmapWidth(DensityUtil.dip2px(320f))
                        .bitmapBgDrawable(R.color.transparent)
                        .build()
                    dialog.show(this@CourseMainActivity.supportFragmentManager)

                    SPUtils.saveEduAdDialogImageUrl(adShowData.imageUrl)
                }
            })

        return true
    }

    private fun isShowAdDialog(imageUrl: String): Boolean { //展示广告弹窗
        if (!mActivityEnable) {
            return false
        }
        return SPUtils.getEduSpAdDialogImageUrl() == null || imageUrl != SPUtils.getEduSpAdDialogImageUrl()
    }

}