package com.alpha.lagouapk.ui.dialog

import android.content.Context
import android.os.Bundle
import android.os.Message
import android.os.Parcelable
import android.text.Html
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ApiService
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.AnswerQuestionInfoBean
import com.alpha.lagouapk.bean.ResumeSummaryBean
import com.alpha.lagouapk.delivery.DeliveryEvent
import com.alpha.lagouapk.delivery.DeliveryInfo
import com.alpha.lagouapk.delivery.DeliveryManager
import com.alpha.lagouapk.observer.EventTags
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.ui.position.PositionDetailActivity
import com.alpha.lagouapk.ui.position.PositionDetailAnswerQuestionLogic.Companion.DELIVER_FINISH_ANSWER_FINISH
import com.alpha.lagouapk.ui.position.PositionDetailAnswerQuestionLogic.Companion.DELIVER_FINISH_ANSWER_ING
import com.alpha.lagouapk.ui.position.PositionDetailAnswerQuestionLogic.Companion.DELIVER_FINISH_ANSWER_NOT
import com.alpha.lagouapk.ui.position.PositionDetailAnswerQuestionLogic.Companion.DELIVER_NOT_ANSWER_FINISH
import com.alpha.lagouapk.ui.position.PositionDetailAnswerQuestionLogic.Companion.DELIVER_NOT_ANSWER_NOT
import com.alpha.lagouapk.widget.SelectResumeItemLayout
import com.common.FROM_DELIVERY_DLG
import com.common.utils.ViewUtils
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.dialog_answer_questions.*

/**
 * 职位详情页底部答题闯关弹窗
 */
class AnswerQuestionDialog:BaseBottomDialogFragment(),View.OnClickListener {
    private var mResumeList:MutableList<ResumeSummaryBean>? = null
    private var mResumeAdapter:SelectResumeAdapter? = null
    private lateinit var mAnswerInfo:AnswerQuestionInfoBean
    //当前的状态
    private var mState:Int = DELIVER_NOT_ANSWER_NOT
    private var mExpectId:Int = 0
    private var canDeliver = false
    private var mPositionId:Long = 0
    private var mReceiverId:Int = 0
    private var mDeliverFrom:String? = null
    companion object {
        const val KEY_DELIVER_ANSWER_STATE = "key_deliver_answer_state"
        const val KEY_RESUME_LIST = "key_resume_list"
        const val KEY_ANSWER_QUESTION_INFO = "key_answer_question_info"
        const val KEY_POSITION_ID = "key_position_id"
        const val KEY_EXPECT_ID = "key_expect_id"
        const val KEY_RECEIVER_ID = "key_receiver_id"
        const val KEY_DELIVER_FROM = "key_deliver_from"
        fun getInstance(state:Int, resumeList:List<ResumeSummaryBean>?, answerInfo:AnswerQuestionInfoBean,positionId:Long,receiverId:Int,expectId:Int,deliverFrom:String?): AnswerQuestionDialog {
            val bundle = Bundle()
            bundle.putInt(KEY_DELIVER_ANSWER_STATE,state)
            bundle.putParcelableArrayList(KEY_RESUME_LIST,resumeList as? ArrayList<out Parcelable>)
            bundle.putSerializable(KEY_ANSWER_QUESTION_INFO,answerInfo)
            bundle.putLong(KEY_POSITION_ID,positionId)
            bundle.putInt(KEY_RECEIVER_ID,receiverId)
            bundle.putInt(KEY_EXPECT_ID,expectId)
            bundle.putString(KEY_DELIVER_FROM,deliverFrom)
            val dialog = AnswerQuestionDialog()
            dialog.arguments = bundle
            return dialog
        }
    }

    /**
     * 在线简历完善 或者 上传附件简历
     */
    private val resumeCompleteBus = Event { _: Message? -> requestResumeList() }

    override fun getLayoutId(): Int = R.layout.dialog_answer_questions

    override fun initConfigAtCreate() {
        super.initConfigAtCreate()
        mState = arguments?.getInt(KEY_DELIVER_ANSWER_STATE) ?: -1
        mAnswerInfo = arguments?.getSerializable(KEY_ANSWER_QUESTION_INFO) as AnswerQuestionInfoBean
        mResumeList = arguments?.getParcelableArrayList(KEY_RESUME_LIST)
        mPositionId = arguments?.getLong(KEY_POSITION_ID) ?: 0
        mReceiverId = arguments?.getInt(KEY_RECEIVER_ID) ?: 0
        mExpectId = arguments?.getInt(KEY_EXPECT_ID) ?: 0
        mDeliverFrom = arguments?.getString(KEY_DELIVER_FROM)
    }

    override fun initView(view: View?) {
        super.initView(view)
        OkBus.getInstance().registerTags(resumeCompleteBus, EventTags.RESUME_COMPLETE, EventTags.UPLOAD_ATTACH_RESUME)
    }

    override fun fillUI() {
        super.fillUI()
        ViewUtils.setViewsClick(this,tvUploadAttachResume,btnSendResume)
        context?.let {
            rvResumeList.layoutManager = LinearLayoutManager(context)
            setBottomButtonTxt()
            val isAnswered = mState == DELIVER_NOT_ANSWER_FINISH || mState == DELIVER_FINISH_ANSWER_FINISH
            tvQuestionTitle.visibility = if (isAnswered) View.GONE else View.VISIBLE
            val title = ResourceUtils.getString(R.string.answer_question_go_through_score, mAnswerInfo.excellentScore)
            val subTitle = if (isAnswered) ResourceUtils.getString(R.string.answer_question_go_through_date,mAnswerInfo.answerTime) else ResourceUtils.getString(R.string.answer_question_go_through_time,mAnswerInfo.examTime)
            tvQuestionTitle.text = Html.fromHtml(title)
            tvQuestionSubTitle.text = Html.fromHtml(subTitle)
            val isDelivered = mState in arrayOf(DELIVER_FINISH_ANSWER_FINISH,DELIVER_FINISH_ANSWER_NOT,DELIVER_FINISH_ANSWER_ING)
            if (isDelivered){
                ViewUtils.setViewGone(tvSendResumeTitle,tvUploadAttachResume,tvOnlineResumeNotPerfect,rvResumeList)
            }
            setDefaultSelectResume()
            setResumeData()
            mResumeAdapter = SelectResumeAdapter(requireContext(),mResumeList)
            rvResumeList.adapter = mResumeAdapter
        }

    }
    private fun setResumeData() {
        if (mResumeList.isNullOrEmpty()) {
            return
        }
        tvUploadAttachResume.visibility = if (mResumeList!!.size > 4) View.GONE else View.VISIBLE
        //检查在线简历 是否完整
        var onlineResume =  mResumeList!!.find { it.isOnlineResume }
        val isOnlineResumeNotPerfect = onlineResume?.isNotPerfectByType == true
        canDeliver = onlineResume?.isCanDeliver == true
        val resumeSize = mResumeList!!.size
        if (resumeSize > 1) {
            tvOnlineResumeNotPerfect.visibility = View.GONE
            tvSendResumeTitle.text = ResourceUtils.getString(R.string.confirm_deliver_resume)
        } else if (resumeSize == 1) {
            //仅有 在线简历
            tvSendResumeTitle.text = "你目前只有1份在线简历"
            tvOnlineResumeNotPerfect.visibility = if (isOnlineResumeNotPerfect) View.VISIBLE else View.GONE
        }
        mResumeAdapter?.setData(mResumeList)
    }

    /**
     * 设置选中简历
     */
    private fun setDefaultSelectResume(){
        if (mResumeList.isNullOrEmpty()) {
            return
        }
        //首先查找默认简历
        val defaultResumeBean =  mResumeList!!.find { it.isDefault }
        if (defaultResumeBean != null){
            defaultResumeBean.isChecked = true
            return
        }
        //查找在线简历
        val onLineResumeBean =  mResumeList!!.find { it.isOnlineResume }
        if (onLineResumeBean != null){
            onLineResumeBean.isChecked = true
            return
        }
        //设置第一个选中
        mResumeList!![0].isChecked = true
    }

    /**
     * 设置底部按钮文字
     */
    private fun setBottomButtonTxt() {
        btnSendResume.text =  when(mState){
            DELIVER_NOT_ANSWER_NOT ->   ResourceUtils.getString(R.string.confirm_deliver_answer_question)
            DELIVER_FINISH_ANSWER_FINISH ->   ResourceUtils.getString(R.string.i_konw)
            DELIVER_FINISH_ANSWER_NOT ->   ResourceUtils.getString(R.string.start_answer_question)
            DELIVER_NOT_ANSWER_FINISH ->   ResourceUtils.getString(R.string.confirm_deliver)
            else -> ""
        }
    }

    /**
     * 请求简历列表
     */
    private fun requestResumeList() {
        ApiService.api.fetchResumeList().enqueue(object: BaseCallback<List<ResumeSummaryBean?>>(){
            override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<List<ResumeSummaryBean?>>) {
                val isActivityDestroyed = isActivityDestroyed(context as? PositionDetailActivity)
                if(isActivityDestroyed || response.content.isNullOrEmpty())return
                val newResumeList = response.content.filterNotNull()
                //同步勾选状态
                mResumeList?.forEach { srcResumeBean ->
                    if (srcResumeBean.isChecked){
                        newResumeList.find { it.resumeId == srcResumeBean.resumeId }?.isChecked = true
                    }
                }
                mResumeList = newResumeList as MutableList<ResumeSummaryBean>?
                setResumeData()
            }
        })
    }

    override fun onViewStateRestored(savedInstanceState: Bundle?) {
        super.onViewStateRestored(savedInstanceState)
        if (savedInstanceState != null) {
            mResumeList = savedInstanceState.getParcelableArrayList(KEY_RESUME_LIST)
        }
    }

    override fun onSaveInstanceState(outState: Bundle) {
        super.onSaveInstanceState(outState)
        if (mResumeList is ArrayList<*>) {
            outState.putParcelableArrayList(KEY_RESUME_LIST, mResumeList as ArrayList<out Parcelable?>?)
        }
    }
    override fun onClick(v: View?) {
        super.onClick(v)
        when(v?.id){
            R.id.tvUploadAttachResume -> IntentUtils.startAttachmentResumeListActivity(getActivity(), FROM_DELIVERY_DLG)
            R.id.btnSendResume -> {
                //投递or答题
                deliverOrAnswerQuestions()
            }
        }
    }

    /**
     * 投递or答题
     */
    private fun deliverOrAnswerQuestions() {
        when(mState){
            DELIVER_NOT_ANSWER_NOT,DELIVER_NOT_ANSWER_FINISH ->{
                //投递
                val info = DeliveryInfo()
                info.positionId = mPositionId
                info.receiverId = mReceiverId.toLong()
                info.expectJobId = mExpectId
                info.deliverFrom = mDeliverFrom
                info.isDeliverAndAnswer = true
                val selectResume = mResumeList?.find { it.isChecked }
                if (context !is PositionDetailActivity || selectResume == null){
                    return
                }
                val activity = context as PositionDetailActivity
                val deliverEvent = DeliveryEvent()
                deliverEvent.deliveryInfo = info
                DeliveryManager.getInstance().sendResume(activity,deliverEvent,selectResume){event ->
                    when (event?.action) {
                        DeliveryEvent.DELIVERY_SUCCEED -> {
                            if (mState == DELIVER_NOT_ANSWER_NOT) {
                                //扫码进入答题
                                onDeliverFinishListener?.onScan()
                            }
                            onDeliverFinishListener?.onDeliverFinish()
                            dismiss()
                        }
                    }
                    false
                }
            }
            DELIVER_FINISH_ANSWER_NOT ->{
                //扫码进入答题
                onDeliverFinishListener?.onScan()
                dismiss()
            }
            DELIVER_FINISH_ANSWER_FINISH -> dismiss()
        }
    }


    override fun onDestroyView() {
        super.onDestroyView()
        OkBus.getInstance().unRegister(resumeCompleteBus)
    }

    class SelectResumeAdapter(val context:Context,var resumeList:MutableList<ResumeSummaryBean>?): RecyclerView.Adapter<SelectResumeAdapter.SelectResumeViewHolder>(),
        SelectResumeItemLayout.OnItemCheckListener {
        fun setData(resumeList:MutableList<ResumeSummaryBean>?){
            this.resumeList = resumeList
            notifyDataSetChanged()
        }
        class SelectResumeViewHolder(itemView: View): RecyclerView.ViewHolder(itemView)
        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): SelectResumeViewHolder {
            val itemView = SelectResumeItemLayout(parent.context)
            val params =  RecyclerView.LayoutParams(RecyclerView.LayoutParams.MATCH_PARENT,RecyclerView.LayoutParams.WRAP_CONTENT)
            itemView.layoutParams = params
            itemView.setOnItemCheckedListener(this)
            return SelectResumeViewHolder(itemView)
        }
        override fun onBindViewHolder(viewHolder: SelectResumeViewHolder, position: Int) {
            val bean: ResumeSummaryBean = resumeList?.get(position) ?: return
            val selectResumeItemLayout = viewHolder.itemView as SelectResumeItemLayout
            selectResumeItemLayout.showCheckBox(resumeList?.size ?: 0  > 1)
            selectResumeItemLayout.setOnClickListener {
                //预览简历
                if (bean.isOnlineResume) {
                    if (bean.isNotPerfectByType) IntentUtils.startResumeEditActivity(context)  else IntentUtils.startResumePreviewActivity(context)
                } else {
                    IntentUtils.startAttachmentResumePreviewActivity(context, -1, bean.resumeId)
                }
            }
            selectResumeItemLayout.setData(bean)
        }

        override fun getItemCount(): Int = 5.coerceAtMost(resumeList?.size ?: 0)

        override fun onItemChecked(bean: ResumeSummaryBean?) {
            resumeList?.forEach { resumeBean ->
                resumeBean.isChecked = resumeBean.resumeId == bean?.resumeId
            }
            notifyDataSetChanged()
        }
    }

    private var onDeliverFinishListener:OnActionListener? = null
    fun setOnDeliverFinishListener(listener:OnActionListener?){
        this.onDeliverFinishListener = listener
    }
    interface OnActionListener{
        /**
         * 投递完成
         */
        fun onDeliverFinish()

        /**
         * 扫码答题
         */
        fun onScan()
    }

}