package com.alpha.lagouapk.ui.dialog

import android.app.Activity
import android.os.Bundle
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.ResumeBaseInfo
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.ui.login.guidePerfect.PostcardActivity
import com.common.adapter.BaseRecycleAdapter
import com.common.adapter.BaseViewHolder
import com.common.adapter.listener.OnItemClick
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.component.ui.itemDecoration.CommonItemDecoration
import kotlinx.android.synthetic.main.dialog_business_card_help.*

/**
 * @date： Crate by wangjunwei on 2022/9/15
 * @description：立即沟通，名片信息缺失弹窗
 **/
class BusinessCardHelpDialog : BaseBottomDialogFragment() {

    var businessCardShortAdapter: BusinessCardShortAdapter ? = null

    var resumeBaseInfo: ResumeBaseInfo? = null

    companion object {

        const val KEY_RESUME_INFO = "key_resume_info"

        fun getInstance(resumeBaseInfo: ResumeBaseInfo?): BusinessCardHelpDialog {
            val bundle = Bundle()
            bundle.putSerializable(KEY_RESUME_INFO, resumeBaseInfo)
            val businessCardHelpDialog = BusinessCardHelpDialog()
            businessCardHelpDialog.arguments = bundle
            return businessCardHelpDialog;
        }
    }

    override fun getLayoutId(): Int {
        return R.layout.dialog_business_card_help
    }


    override fun initListener() {
        super.initListener()
        image_close.setOnClickListener {
            dismiss()
        }
        btn_to_perfect.setOnClickListener {
            IntentUtils.startPostcardActivity(context,PostcardActivity.SOURCE_POSITION_DETAIL)
            dismiss()
        }
    }

    override fun fillUI() {
        super.fillUI()
        resumeBaseInfo = arguments?.getSerializable(KEY_RESUME_INFO) as? ResumeBaseInfo

        val dividerItemDecoration = CommonItemDecoration(context)
        dividerItemDecoration.setDrawable(resources.getDrawable(com.lagou.component.ui.R.drawable.recycler_divider))
        recycle_view.apply {
            addItemDecoration(dividerItemDecoration)
        }
        businessCardShortAdapter = BusinessCardShortAdapter(getActivity())
        recycle_view.adapter = businessCardShortAdapter
        resumeBaseInfo?.apply {
            businessCardShortAdapter?.setData(talentCardPerfectLessList)
            //businessCardShortAdapter?.setData(prefectLessList)
        }
    }


    class BusinessCardShortAdapter(activity: Activity?) :
        BaseRecycleAdapter<String, BusinessCardShortAdapter.BusinessCardHolder>(activity) {

        private val DP_15 = ResourceUtils.getDimenSize(R.dimen.dp_15)
        private val DP_10 = ResourceUtils.getDimenSize(R.dimen.dp_10)

        class BusinessCardHolder(itemView: View?) : BaseViewHolder<String>(itemView) {

            override fun onBindViewHolder(
                itemView: View?,
                content: String?,
                position: Int,
                onItemClick: OnItemClick<*>?
            ) {
                val textView: TextView? = itemView as? TextView
                //后端返回缺失字段，补充XX"未填写"
                if (content != null && !content.contains(ResourceUtils.getString(R.string.not_write))){
                    textView?.text = content + ResourceUtils.getString(R.string.not_write)
                }else {
                    textView?.text = content
                }
            }

            override fun getTitle(): String {
                return "缺失名片卡片信息"
            }
        }

        override fun onCreateViewHolder(
            viewGroup: ViewGroup,
            viewType: Int
        ): RecyclerView.ViewHolder {
            val tv = TextView(mActivity)
            tv.layoutParams = ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,
                ViewGroup.LayoutParams.WRAP_CONTENT)
            tv.setPadding(DP_10, DP_15, DP_10, DP_15)
            tv.textSize = 16f
            tv.setTextColor(ResourceUtils.getColor(R.color.color_333333))
            return BusinessCardHolder(tv)
        }
    }
}