package com.alpha.lagouapk.ui.interview

import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.widget.FrameLayout
import android.widget.LinearLayout
import android.widget.TextView
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.deliver.DeliverGetBean
import com.alpha.lagouapk.bean.interview.CInterviewDetailRes
import com.alpha.lagouapk.manager.net.CInterviewNetManager
import com.alpha.lagouapk.observer.EventTags
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.tools.UserHeadUtils
import com.alpha.lagouapk.ui.interview.adapter.CNewInterviewRecordAdapter
import com.common.utils.SpUserNotClearUtils
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.ui.dialog.inter.ADismissListener
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.web.router.RouteUtils
import com.lagou.lagouee.manager.net.InterviewNetManager
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.activity_interview_detail_c.*
import kotlinx.android.synthetic.main.layout_calendar_empty.*

/**
 * @date 创建时间：2020/7/23
 * @author 作者：codemano
 * @Description  描述：C端面试详情页
 * @version
 */

@RouterRule(CInterviewDetailActivity.URI)
class CInterviewDetailActivity : BaseActivity() {

    private var interviewId: Long? = null
    private var detailRes: CInterviewDetailRes? = null

    companion object {
        const val KEY_INTERVIEW_ID = "key_interview_id"
        const val URI = "lagou://lagou.com/interview_detail?interviewid={interviewid}"
    }

    private var interviewRecordAdapter: CNewInterviewRecordAdapter? = null
    private val eventFlush = Event { getInterviewDetail() }

    private val commonListenerImpl =
            object : OnAdapterCommonListenerImpl<CInterviewDetailRes, HttpResponse<CInterviewDetailRes>>(this) {
                override fun onSuccess(t: CInterviewDetailRes?) {
                    super.onSuccess(t)
                    detailRes = t
                    showNormal()
                    fillUi(t)
                }

                override fun onError(errorBean: HttpResponse<CInterviewDetailRes>?) {
                    super.onError(errorBean)
                    if (errorBean?.state == 261001) {
                        showOther(errorBean?.message)
                    }
                }

                override fun onNoInternet() {
                    super.onNoInternet()
                    showWifi()
                }
            }

    /**
     * 拒绝面试
     */
    private val btnRefuseClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qrj")
        detailRes?.apply {
            cRefuseInterview(id)
        }
    }

    /**
     * 接受面试
     */
    private val btnAcceptClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qrh")
        detailRes?.apply {
            if (!SpUserNotClearUtils.getInstance().isVideoChatPrivacyTipsShowed) {
                DialogUtils.showVideoChatPrivacyDialog(
                    baseActivity,
                    object : ADismissListener<Any?>() {
                        override fun onRight() {
                            SpUserNotClearUtils.getInstance().setVideoChatPrivacyTipsShowed()
                            cAcceptInterview(id)
                        }
                    })
            } else {
                cAcceptInterview(id)
            }
        }
    }

    /**
     * 面试评价
     */
    private val btnCommentClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qrt")
        detailRes?.apply {
            /*val bundle = Bundle()
            bundle.putString("pd_positionId", positionId.toString())
            bundle.putString("pd_orderId", orderId.toString())
            bundle.putString("pd_salary", salary)
            bundle.putString("pd_companyName", companyName)
            bundle.putString("pd_companyLogo_uri", companyLogo)
            bundle.putString("pd_workAdress", address)
            IntentUtils.startCommentAddActivity(mContext, bundle)*/
            //一定是约面试状态,所以该处
            IntentUtils.startCommentAddActivity(mContext, positionId, orderId, DeliverGetBean.ResumeState.INVITED_INTERVIEW);
        }
    }

    /**
     * 查看我的面试评价
     */
    private val btnScanCommentClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qrv")
        detailRes?.apply {
            IntentUtils.startCCommentDetailActivity(this@CInterviewDetailActivity, orderId)
        }
    }

    /**
     * 取消面试
     */
    private val btnCancelClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qrm")
        detailRes?.apply {
            cCancelInterview(id)
        }
    }

    override fun getContentLayoutId() = R.layout.activity_interview_detail_c

    override fun init() {
        if (RouteUtils.matchRule(intent, URI)) {
            interviewId = RouteUtils.getQueryParameter(intent, "interviewid", Long::class.javaPrimitiveType)
        } else {
            interviewId = intent?.getLongExtra(KEY_INTERVIEW_ID, -1)
        }
        initRecycleView()
        initListener()
        getInterviewDetail()
    }

    private fun initRecycleView() {
        recycle_interview_record.isNestedScrollingEnabled = false
        interviewRecordAdapter = CNewInterviewRecordAdapter(this)
        recycle_interview_record?.apply {
            adapter = interviewRecordAdapter
            layoutManager = LinearLayoutManager(mContext)
            var decoration = DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL)
            decoration.setDrawable(ResourceUtils.getDrawable(R.drawable.shape_no_size))
            addItemDecoration(decoration)
        }
    }

    private fun getInterviewDetail() {
        if (interviewId == -1L) {
            return
        }

        CInterviewNetManager.getInterviewDetail(interviewId, commonListenerImpl)
    }

    private fun initListener() {
        ltitle_bar.setLeftImgListener {
            AnalyticHelper.getInstance().sendClickInfo("1qrd")
            finish()
        }

        constrain_base.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qrf")
            //去职位详情
            detailRes?.positionId?.toLong()?.let {
                IntentUtils.startPositionDetailActivity(this@CInterviewDetailActivity, it)
            }
        }
        wifi.setReLoadListener {
            getInterviewDetail()
        }
        OkBus.getInstance().register(EventTags.UPDATE_INTERVIEW_DETAIL, eventFlush)
    }

    private fun showWifi() {
        constrain_empty.visibility = View.GONE
        wifi.visibility = View.VISIBLE
        nest_root.visibility = View.GONE
    }

    private fun showNormal() {
        constrain_empty.visibility = View.GONE
        wifi.visibility = View.GONE
        nest_root.visibility = View.VISIBLE
    }

    private fun showOther(message: String?) {
        wifi.visibility = View.GONE
        nest_root.visibility = View.GONE
        constrain_empty.visibility = View.VISIBLE
        tv_state.text = message
    }

    private fun fillUi(detailRes: CInterviewDetailRes?) {
        detailRes?.apply {
            circle_head?.apply {
                UserHeadUtils.setUserHeader(this, hrIcon)
            }
            tv_interview_contact_content?.setOnClickListener {
                AnalyticHelper.getInstance().sendClickInfo("1qrx")
                BaseUtils.dialNumber(this@CInterviewDetailActivity, linkPhone)
            }
            image_chat?.setOnClickListener {
                AnalyticHelper.getInstance().sendClickInfo("1qre")
                IntentUtils.startChatActivity(this@CInterviewDetailActivity, hrId, positionId)
            }

            //1 基本信息包含头像、姓名等
            tv_company_name?.text = companyName
            image_company_logo?.apply {
                ImageLoadUtils.with(context)
                        .load(companyLogo)
                        .bitmapTransform(RoundTransform(3F))
                        .placeholder(R.drawable.occupy_logo)
                        .error(R.drawable.occupy_logo).into(image_company_logo)
            }
            //2 候选人工作信息
            fillWorkInfo()
            tv_except_salary?.text = salaryInfo
            tv_hr_info?.text = hrInfo
            //2 面试详情部分
            fillInterview()

            //3 面试状态记录问题
            if (interviewStatusList == null || interviewStatusList.isEmpty()) {
                lin_interview_record?.visibility = View.GONE
                return
            }
            lin_interview_record?.visibility = View.VISIBLE
            interviewRecordAdapter?.setData(interviewStatusList)

            //4 按钮展示文案和状态
            fillInterviewBtn()
        }
    }

    private fun CInterviewDetailRes.fillInterviewBtn() {
        //1 底部造作区域是否隐藏
        if (!isShowBottomArea) {
            lin_btn_bottom.visibility = View.GONE
            return
        }

        lin_btn_bottom.visibility = View.VISIBLE
        lin_btn_bottom_inner.removeAllViews()
        var index = 0
        for (interviewBtnStyle in btnList) {
            interviewBtnStyle?.apply {
                val btn = TextView(mContext)
                index++
                btn.apply {
                    val params = LinearLayout.LayoutParams(0, ResourceUtils.getDimenSize(R.dimen.dp_46))
                    if (index > 1){
                        params.leftMargin = ResourceUtils.getDimenSize(R.dimen.dp_10)
                    }
                    params.weight = 1.0F
                    background = ResourceUtils.getDrawable(btnBackground)
                    gravity = Gravity.CENTER
                    setTextColor(ResourceUtils.getColor(btnTxtColor))
                    textSize = 16F
                    text = btnTxt
                    layoutParams = params
                    alpha = if (interviewBtnStyle.isEnable) {
                        isEnabled = true
                        1.0F
                    } else {
                        isEnabled = false
                        0.8F
                    }
                    handleBtnClick(interviewBtnStyle, btn)
                }
                lin_btn_bottom_inner.addView(btn)
            }
        }
        if (!TextUtils.isEmpty(extraText)) {
            tv_extra_msg.visibility = View.VISIBLE
            tv_extra_msg.text = extraText
        } else {
            tv_extra_msg.visibility = View.GONE
        }
    }

    private fun handleBtnClick(interviewBtnStyle: CInterviewDetailRes.CInterviewBtnStyle, btn: TextView) {
        if (interviewBtnStyle.isReceiveInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qrg")
            btn.setOnClickListener(btnAcceptClick)
            return
        }
        if (interviewBtnStyle.isCancelInterview) {
            if (interviewBtnStyle.isEnable){
                AnalyticHelper.getInstance().sendShowInfo(pageId,"1qrk")
            }else{
                AnalyticHelper.getInstance().sendShowInfo(pageId,"1qrr")
            }
            btn.setOnClickListener(btnCancelClick)
            return
        }
        if (interviewBtnStyle.isRefuseInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qri")
            btn.setOnClickListener(btnRefuseClick)
            return
        }

        if (interviewBtnStyle.isCommentInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qrs")
            btn.setOnClickListener(btnCommentClick)
            return
        }
        if (interviewBtnStyle.isScanComment) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qru")
            btn.setOnClickListener(btnScanCommentClick)
            return
        }
    }


    /***
     * 处理带竖线的工作信息逻辑，之所以使用几个TextView是为了控制不同内容显示长度差异化，没有采取VerticalCenterImageSpan
     */
    private fun CInterviewDetailRes.fillWorkInfo() {
        //工作信息
        if (!TextUtils.isEmpty(positionName)) {
            tv_position?.visibility = FrameLayout.VISIBLE
            tv_position?.text = positionName
        } else {
            tv_position?.visibility = FrameLayout.GONE
        }
        if (!TextUtils.isEmpty(workYear)) {
            tv_talent_experience?.visibility = View.VISIBLE
            tv_talent_experience?.text = workYear
        } else {
            tv_talent_experience?.visibility = FrameLayout.GONE
        }

        if (!TextUtils.isEmpty(education)) {
            tv_talent_education?.visibility = View.VISIBLE
            tv_talent_education?.text = education
        } else {
            tv_talent_education?.visibility = FrameLayout.GONE
        }

        //竖线隐藏和展示逻辑
        if (tv_position?.visibility == View.VISIBLE && tv_talent_experience?.visibility == View.VISIBLE) {
            v_interview_history_gap?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap?.visibility = View.GONE
        }
        if (tv_talent_experience?.visibility == View.VISIBLE && tv_talent_education?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
        if (tv_position?.visibility == View.VISIBLE && tv_talent_education?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
    }

    private fun CInterviewDetailRes.fillInterview() {

        if (!TextUtils.isEmpty(linkMan)) {
            lin_contact_title?.visibility = View.VISIBLE
            tv_interview_contact_content?.text = linkMan
        } else {
            lin_contact_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(interviewTime)) {
            lin_time_title?.visibility = View.VISIBLE
            tv_interview_time_content?.text = interviewTime
        } else {
            lin_time_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(interviewType)) {
            lin_form_title?.visibility = View.VISIBLE
            tv_interview_form_content?.text = interviewType
        } else {
            lin_form_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(address)) {
            lin_address_title?.visibility = View.VISIBLE
            tv_interview_address_content?.text = address
        } else {
            lin_address_title?.visibility = View.GONE
        }
        if (!TextUtils.isEmpty(addInfo)) {
            lin_remark_title?.visibility = View.VISIBLE
            tv_interview_remark_content?.text = addInfo
        } else {
            lin_remark_title?.visibility = View.GONE
        }
    }

    fun cAcceptInterview(interviewId: Int) {
        InterviewNetManager.cAcceptInterview(interviewId, object : OnAdapterCommonListenerImpl<Any, HttpResponse<Any>>(this) {
            override fun onSuccess(t: Any?) {
                super.onSuccess(t)
                OkBus.getInstance().onEvent(EventTags.FLUSH_INTERVIEW_LIST)
                getInterviewDetail()
            }

            override fun isCareResponse(): Boolean {
                return false
            }
        })
    }

    fun cRefuseInterview(interviewId: Int) {
        InterviewNetManager.cRefuseInterview(interviewId, object : OnAdapterCommonListenerImpl<Any, HttpResponse<Any>>(this) {
            override fun onSuccess(t: Any?) {
                super.onSuccess(t)
                OkBus.getInstance().onEvent(EventTags.FLUSH_INTERVIEW_LIST)
                getInterviewDetail()
            }

            override fun isCareResponse(): Boolean {
                return false
            }
        })
    }

    fun cCancelInterview(interviewId: Int) {
        InterviewNetManager.cCancelInterview(interviewId, object : OnAdapterCommonListenerImpl<Any, HttpResponse<Any>>(this) {
            override fun onSuccess(t: Any?) {
                super.onSuccess(t)
                OkBus.getInstance().onEvent(EventTags.FLUSH_INTERVIEW_LIST)
                getInterviewDetail()
            }

            override fun isCareResponse(): Boolean {
                return false
            }
        })
    }

    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance().unRegister(eventFlush)
    }

    override fun getPageId() = "1qrc"
}