package com.alpha.lagouapk.ui.interview

import androidx.recyclerview.widget.LinearLayoutManager
import android.view.View
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.interview.CInterviewScheduleReq
import com.alpha.lagouapk.bean.interview.CInterviewScheduleRes
import com.alpha.lagouapk.bean.interview.InterviewWaitRes
import com.alpha.lagouapk.manager.net.CInterviewNetManager
import com.alpha.lagouapk.observer.EventTags
import com.alpha.lagouapk.tools.IntentUtils
import com.lagou.commonlibs.utils.TimeUtils
import com.alpha.lagouapk.ui.interview.adapter.CInterviewScheduleAdapter
import com.common.bean.json.InterviewCalendarDayRes
import com.common.bean.json.InterviewTimeRes
import com.common.utils.SpUserNotClearUtils
import com.common.widget.interview.CalenderExpandPopupFactory
import com.common.widget.interview.ICalenderExpandView
import com.common.widget.popup.InterviewCalenderPopup
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListListenerImpl
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.lagouee.bean.jsonbean.interview.InterviewTimeReq
import com.lagou.lagouee.manager.net.InterviewNetManager
import com.lagou.lagouee.ui.resume.list.interview.InterviewDecoration
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.activity_interview_schedule_b.*
import kotlinx.android.synthetic.main.layout_interview_calendar_change.*

/**
 * @date 创建时间：2020/7/24
 * @author 作者：codeman
 * @Description  描述：C端 新面试日程独立页面
 * @version
 */

@RouterRule(CInterviewScheduleActivity.URI)
class CInterviewScheduleActivity : BaseActivity() {

    var scheduleAdapter: CInterviewScheduleAdapter? = null
    private val interviewListRequest = CInterviewNetManager.InterviewListRequest()
    private var interviewDays = listOf<String>()
    private var serverTimeStamp = System.currentTimeMillis()
    private var selectCalendarDay: InterviewCalendarDayRes? = null

    /***
     * 当前日历viewpager页码
     */
    private var currentIndex = -1
    private var isInitRequest = true

    private var tvEmptyTopTitle: TextView? = null

    private val eventFlushList = Event {
        requestNextPage(true)
    }

    private val eventFlushOther = Event {
        requestInterviewWaitInfo()
    }


    companion object {
        const val URI = "lagou://lagou.com/interview_schedule?[date]={date}"
    }

    init {
        if (SpUserNotClearUtils.getInstance().serverTimeStamp != 0L) {
            serverTimeStamp = SpUserNotClearUtils.getInstance().serverTimeStamp
        }
    }

    private val onAdapterCommonListener = object :
            OnAdapterCommonListListenerImpl<List<Any>, HttpResponse<List<Any>>, Boolean>(this) {

        override fun onSuccess(t: List<Any>?, first: Boolean?) {
            super.onSuccess(t, first)
            isInitRequest = false
            showNormalStyle()
            recycle_interview.completeOnSuccess(true)
            first?.let {
                scheduleAdapter?.updateList(t, it)
            }
        }

        override fun onNoMore(t: List<Any>?, first: Boolean?) {
            super.onNoMore(t, first)
            isInitRequest = false
            showNormalStyle()
            recycle_interview.completeOnSuccess(false)
            first?.let { scheduleAdapter?.updateList(t, it) }
        }

        override fun onNoData(t: List<Any>?, first: Boolean?) {
            super.onNoData(t, first)
            isInitRequest = false
            showNormalStyle()
            recycle_interview.completeOnSuccess(false)
            first?.let { scheduleAdapter?.updateList(t, it) }
        }

        override fun onError(errorBean: HttpResponse<List<Any>>?) {
            super.onError(errorBean)
            isInitRequest = false
            showNormalStyle()
            if (isActive){
                recycle_interview.completeOnFailure()
            }
        }
        override fun onNoInternet() {
            super.onNoInternet()
            isInitRequest = false
            if (isActive){
                recycle_interview.completeOnFailure()
                wifi.visibility = View.VISIBLE
                coordinator_content.visibility = View.GONE
            }
        }
    }

    private val onInterviewTimesListener = object :
            OnAdapterCommonListenerImpl<InterviewTimeRes, HttpResponse<InterviewTimeRes>>(this) {

        override fun onSuccess(interviewTimes: InterviewTimeRes?) {
            super.onSuccess(interviewTimes)
            interviewTimes?.let {
                it.days?.apply {
                    interviewDays = it.days
                    initInterviewCalendar()
                }
            }
        }

        override fun onError(errorBean: HttpResponse<InterviewTimeRes>?) {
            super.onError(errorBean)
            initInterviewCalendar()
        }

        override fun onNoInternet() {
            super.onNoInternet()
            initInterviewCalendar()
        }

        override fun isShowToast() = false
    }

    /***
     * 面试确认信息
     */
    private val onInterviewWaitListener = object :
            OnAdapterCommonListenerImpl<InterviewWaitRes, HttpResponse<InterviewWaitRes>>(this) {
        override fun onSuccess(interviewWaitRes: InterviewWaitRes?) {
            super.onSuccess(interviewWaitRes)
            if (interviewWaitRes != null){
                tvEmptyTopTitle?.text = interviewWaitRes.text
                scheduleAdapter?.updateTitle(interviewWaitRes.text)
            }else {
                tvEmptyTopTitle?.text = ""
                scheduleAdapter?.updateTitle("")
            }
        }

        override fun isCareResponse() = false

        override fun isShowToast() = false
    }

    override fun getContentLayoutId() = R.layout.activity_interview_schedule_c

    override fun init() {
        initRecycleView()
        initListener()
        requestInterviewTimes()
        requestInterviewWaitInfo()
        requestNextPage(true)
    }

    private fun initRecycleView() {
        recycle_interview.apply {
            layoutManager = LinearLayoutManager(context)
            itemAnimator = null
            addItemDecoration(InterviewDecoration(context))
            //面试日程列表点击，
            setOnItemClickListener { _, _, position ->
                AnalyticHelper.getInstance().sendClickInfo("1qr9")
                scheduleAdapter?.let {
                    val interviewBean: CInterviewScheduleRes.CInterviewInfo? =
                            scheduleAdapter?.getItem(position) as? CInterviewScheduleRes.CInterviewInfo
                    interviewBean?.apply {
                        IntentUtils.startCInterviewDetailActivity(this@CInterviewScheduleActivity, id)
                    }
                }
            }

            setOnLoadMoreListener {
                if(!isInitRequest){
                    // 加载更多
                    requestNextPage(false)
                }
            }

            val emptyView = recycle_interview.generateChildView(R.layout.layout_no_interview_record_new)
            setEmptyView(emptyView)
            tvEmptyTopTitle = emptyView.findViewById(R.id.tv_top_title)
            tvEmptyTopTitle?.visibility = View.VISIBLE
            scheduleAdapter = CInterviewScheduleAdapter(context)

            adapter = scheduleAdapter
        }
    }

    private fun initListener() {
        ltitle_bar.setLeftImgListener {
            AnalyticHelper.getInstance().sendClickInfo("1qr3")
            finish()
        }

        wifi.setReLoadListener {
            requestNextPage(true)
        }

        calendar_fold_view.setIInterviewCalendar(object : InterviewCalenderPopup.IInterviewCalendar {
            override fun onScrollCalendar(
                    pageNum: Int,
                    calendarDays: List<InterviewCalendarDayRes>?,
                    month: String?, year: String?) {
                tv_select_calendar_left.text = month
                tv_select_calendar.text = year

                if (currentIndex != -1){
                    if (pageNum < currentIndex){
                        handleLeftChange()
                    }else if (pageNum > currentIndex){
                        handleRightChange()
                    }
                }
                currentIndex = pageNum
            }

            override fun onFoldCalendar(
                    calendarDayRes: InterviewCalendarDayRes?,
                    calendarDays: List<InterviewCalendarDayRes>?) {
                selectCalendarDay = calendarDayRes
                requestNextPage(true)
            }
        })
        calendar_fold_view.setCalendarExpandView(CalenderExpandPopupFactory(InterviewCalenderPopup(
            this, ltitle_bar, calendar_fold_view
        )))
        //calendar_fold_view.setLocationView(ltitle_bar)
        frame_before_month.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qr4")
            calendar_fold_view.beforeCalendarMonth()
        }

        frame_after_month.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qr5")
            calendar_fold_view.afterCalendarMonth()
        }

        OkBus.getInstance()
                .register(EventTags.FLUSH_INTERVIEW_LIST, eventFlushList)
                .register(EventTags.FLUSH_INTERVIEW_LIST, eventFlushOther)
    }

    private fun initInterviewCalendar() {
        calendar_fold_view?.fillUi(serverTimeStamp, interviewDays, 0L)
    }


    private fun showNormalStyle(){
        wifi.visibility = View.GONE
        coordinator_content.visibility = View.VISIBLE
    }


    /***
     * 请求下一页
     * codeman
     */
    private fun requestNextPage(firstPage: Boolean){
        var interviewListReq = CInterviewScheduleReq()
        if (selectCalendarDay == null) {
            interviewListReq.startTime = TimeUtils.convertYearMonthDayTime(serverTimeStamp)
        } else {
            selectCalendarDay?.let { it ->
                interviewListReq.startTime = TimeUtils.convertYearMonthDayTime(it.timeStamp)
            }
        }
        interviewListReq.endTime = TimeUtils.getGoalTime(1, interviewListReq.startTime)
        //interviewListReq.endTime = TimeUtils.getGoalTime(1000, interviewListReq.startTime)
        //interviewListReq.startTime = TimeUtils.getGoalTime(-1000, interviewListReq.startTime)
        interviewListRequest.getInterviewList(interviewListReq, firstPage, onAdapterCommonListener)
    }

    /***
     * 有面试的时间段
     */
    private fun requestInterviewTimes() {
        val interviewTimeReq = InterviewTimeReq()
        interviewTimeReq.startTime = TimeUtils.getGoalMonthStamp(serverTimeStamp, -6)
        interviewTimeReq.endTime = TimeUtils.getGoalMonthStamp(serverTimeStamp, 5)
        InterviewNetManager.getCInterviewTimes(interviewTimeReq, onInterviewTimesListener)
    }

    /**
     * 面试待确认信息
     */
    private fun requestInterviewWaitInfo(){
        InterviewNetManager.getCInterviewWaitInfo(onInterviewWaitListener)
    }

    private fun handleRightChange() {
        if (calendar_fold_view.isMaxIndex()) {
            image_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_unclick)
            frame_after_month.isEnabled = false
        } else {
            image_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_nor)
            frame_after_month.isEnabled = true
        }

        image_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_nor)
        frame_before_month.isEnabled = true
    }

    private fun handleLeftChange() {
        if (calendar_fold_view.isMinIndex()) {
            image_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_unclick)
            frame_before_month.isEnabled = false
        } else {
            image_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_nor)
            frame_before_month.isEnabled = true
        }

        image_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_nor)
        frame_after_month.isEnabled = true
    }

    override fun getPageId(): String {
        return "1qr2"
    }

    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance().unRegister(eventFlushList)
                           .unRegister(eventFlushOther)
    }
}