package com.alpha.lagouapk.ui.interview.view

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.interview.CInterviewScheduleRes
import com.alpha.lagouapk.tools.IntentUtils
import com.lagou.annotation.aspect.SingleClick
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.StringUtil
import kotlinx.android.synthetic.main.item_interview_schedule_c.view.*

/**
 * @author 作者：codeman
 * @date 创建时间：2020/7/23
 * @Description 描述：新面试日程卡片页页
 */
class CNewInterviewCardView(context: Context, attrs: AttributeSet?) : FrameLayout(context, attrs) {
    init {
        LayoutInflater.from(context).inflate(R.layout.item_interview_schedule_c, this)
    }

    fun fillUi(bean: CInterviewScheduleRes.CInterviewInfo?){
        bean?.apply {
            //1 基本信息包含头像、姓名等
            tv_company_name?.text = companyName
            tv_interview_model?.text = interviewType
            image_company_logo?.apply {
                ImageLoadUtils.with(context)
                        .load(companyLogo)
                        .bitmapTransform(RoundTransform(3F))
                        .placeholder(R.drawable.occupy_logo)
                        .error(R.drawable.occupy_logo).into(image_company_logo)
            }

            if (!TextUtils.isEmpty(positionName)){
                tv_interview_position?.visibility = View.VISIBLE
                tv_interview_position?.text = positionName
            }else{
                tv_interview_position?.visibility = View.GONE
            }
            if (!TextUtils.isEmpty(salary)){
                tv_interview_salary?.visibility = View.VISIBLE
                tv_interview_salary?.text = salaryInfo
            }else{
                tv_interview_salary?.visibility = View.GONE
            }
            if (tv_interview_position?.visibility == View.VISIBLE
                    && tv_interview_salary?.visibility == View.VISIBLE){
                v_interview_history_gap?.visibility = View.VISIBLE
            }else{
                v_interview_history_gap?.visibility = View.GONE
            }

            tv_recruiter_info?.text = StringUtil.jointString("·", hrName, hrPositionName)

            //4 点击事件
            image_chat?.setOnClickListener{
                AnalyticHelper.getInstance().sendClickInfo("1qra")
                //4.1 去Im聊天
                handleChatRepeatClick()
            }
//            image_video?.setOnClickListener{
//                //4.2 去打电话
//                handlePhoneRepeatClick()
//            }
            tv_invite_interview.text = lastStatus
        }
    }

    @SingleClick
    fun CInterviewScheduleRes.CInterviewInfo.handlePhoneRepeatClick() {
        talentPhone?.let {
            BaseUtils.dialNumber(context, it)
        }
    }

    @SingleClick
    fun CInterviewScheduleRes.CInterviewInfo.handleChatRepeatClick() {
        IntentUtils.startChatActivity(context, hrId, positionId.toLong())
    }

}