package com.alpha.lagouapk.ui.login.guidePerfect

import android.content.Intent
import android.os.Bundle
import android.text.InputFilter
import android.view.View
import android.view.ViewGroup
import android.view.inputmethod.EditorInfo
import androidx.core.widget.NestedScrollView
import com.ApiService
import com.alpha.lagouapk.R
import com.alpha.lagouapk.UserRoleManager
import com.alpha.lagouapk.bean.EducationExperienceBean
import com.alpha.lagouapk.bean.PositionTypeVo
import com.alpha.lagouapk.bean.ResumeBaseInfo
import com.alpha.lagouapk.bean.position.PositionLabelGroup
import com.alpha.lagouapk.tools.ComUtil
import com.alpha.lagouapk.tools.CommonDef
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.ui.login.bean.ExpectInfo
import com.alpha.lagouapk.ui.login.bean.PositionTypeAndTagsBean
import com.alpha.lagouapk.ui.login.bean.PostcardInfoBean
import com.alpha.lagouapk.ui.login.perfect.EditInfoCode
import com.alpha.lagouapk.ui.login.perfect.EditInfoDialog
import com.alpha.lagouapk.ui.resume.edit.v2.ResumePositionTagActivity
import com.common.SensitiveLogic
import com.common.manager.PositionTypeManager
import com.common.utils.CommonIntentUtils.Companion.startTouristWebActivity
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.baselib.util.BarUtil
import com.lagou.commonlibs.utils.DateUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.commonlibs.utils.wheelstrategy.BirthdayWheelStrategy
import com.lagou.commonlibs.utils.wheelstrategy.DataWheelStrategy
import com.lagou.commonlibs.utils.wheelstrategy.EducationLevelStrategy
import com.lagou.commonlibs.utils.wheelstrategy.SalaryWheelStrategy
import com.lagou.commonlibs.view.EditItemView
import com.lagou.commonlibs.view.MaxInputWatcher
import com.lagou.commonlibs.view.WheelDialog
import com.lagou.commonlibs.view.filter.EmojiFilter
import com.lagou.component.ui.dialog.listener.LgDialogListener
import com.lagou.lagouee.utils.DataServer
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import com.lxj.xpopup.XPopup
import kotlinx.android.synthetic.main.activity_register_postcard.*
import java.util.*

/**
 * 注册流程中的名片页
 */
class PostcardActivity:BaseActivity(),View.OnClickListener {
    companion object{
        const val DEFAULT_SALARY_HIGH = "100K以上"
        const val PLS_PERFECT_INFO = "请完善相关信息"
        const val SOURCE_REGISTER = 1
        const val SOURCE_POSITION_DETAIL = 2;
    }
    private var isNeedCheckInfoByName = true
    override fun getContentLayoutId(): Int = R.layout.activity_register_postcard
    //职位三级类code
    private var mPositionCodes = arrayOfNulls<String>(3)
    //职位标签
    private var mPositionLabels : ArrayList<PositionLabelGroup.Label?>? = null
    //页面来源
    private var mSource = SOURCE_REGISTER
    override fun init() {
        mSource = intent?.extras?.getInt(IntentUtils.INTENT_KEY_PAGE_SOURCE) ?: SOURCE_REGISTER
        this.initViewBySource()
        this.initStatusBar()
        this.initListener()
        this.requestPostcardInfo()
    }

    private fun initViewBySource(){
        mTitleBar.tvRight.visibility = if (mSource == SOURCE_REGISTER) View.VISIBLE else View.GONE
        mTvNextStep.text = if (mSource == SOURCE_REGISTER) ResourceUtils.getString(R.string.next_step) else ResourceUtils.getString(R.string.complete)
    }

    private fun initStatusBar() {
        BarUtil.transparentStatusBar(this)
        mStatusBar.layoutParams = mStatusBar.layoutParams.apply { height = BarUtil.getStatusBarHeight(this@PostcardActivity) }
    }

    private fun initListener() {
        mTitleBar.setLeftImgListener { onBackPressed() }
        mTitleBar.setRightTvListener { jump() }
        initNameListener()
        mScrollView.setOnScrollChangeListener(NestedScrollView.OnScrollChangeListener { _, _, scrollY, _, _ ->
            val bgColor = if (scrollY == 0) ResourceUtils.getColor(R.color.transparent) else ResourceUtils.getColor(R.color.color_00b38a)
            mStatusBar.setBackgroundColor(bgColor)
            mTitleBar.setBackgroundColor(bgColor)
        })
        setClickViews(mEditUserCityItem,mEditSchoolNameItem,mEditEducationItem,mEditWorkYearItem,
            mEditCompanyItem,mEditPositionNameItem,mEditPositionTypeItem,mEditExpectSalaryItem,mEditPositionLabelItem,mTvNextStep,mEditBirthdayItem)
    }

    /**
     * 跳过，需要先判断是否达到了名片
     */
    private fun jump(){
        AnalyticHelper.getInstance().sendClickInfo("q1u1c","v1u1h")
        checkIsPostcardPerfect(object:CheckIsPostcardPerfectCallback{
            override fun onPostcardPerfect(isPerfect: Boolean,isCanDeliver:Boolean) {
                if (isActivityDestroyed){
                    return
                }
                if (isPerfect){
                    //已经完善,进入首页
                    enterMainActivity(this@PostcardActivity)
                    return
                }
                //未完善，跳转到游客模式
                startTouristWebActivity(this@PostcardActivity)
            }

        })
    }

    /**
     * 姓名初始化设置
     */
    private fun initNameListener(){
        val inputWatcher = MaxInputWatcher(10).apply {
            setIsCalTextLength(true)
            setInputType(MaxInputWatcher.INPUT_TYPE_DOUBLE)
            setMaxInputListener(object:MaxInputWatcher.OnMaxInputListener{
                override fun equalMaxLength(isEqual: Boolean) {
                    if (isEqual){
                        ToastUtil.showCenter(mContext, resources.getString(R.string.name_input_limit))
                    }
                }

                override fun onTextChanged(s: String?) {
                    isNeedCheckInfoByName = if (s.isNullOrEmpty()){
                        checkInfoIsPerfect()
                        true
                    }else{
                        if (isNeedCheckInfoByName){
                            checkInfoIsPerfect()
                        }
                        false
                    }
                }

                override fun showLengthTip(length: Int, text: String?) {}

            })
        }
        val onFocusChangeListener = { _:View, hasFocus:Boolean ->
            PostcardViewHelper.setLineState(
                if (hasFocus) PostcardViewHelper.LineState.GREEN
                else PostcardViewHelper.LineState.NORMAL,mEditUserNameItem.lineBottom)
        }
       mEditUserNameItem.editText.apply {
           imeOptions = EditorInfo.IME_ACTION_DONE
           filters = arrayOf<InputFilter>(EmojiFilter())
           addTextChangedListener(inputWatcher)
           setOnFocusChangeListener(onFocusChangeListener)
           setOnClickListener{
               PostcardViewHelper.setLineState(
                   if (hasFocus()) PostcardViewHelper.LineState.GREEN
                   else PostcardViewHelper.LineState.NORMAL,mEditUserNameItem.lineBottom)
           }
        }
        setEditTextHideByTouchOther(true, null, mEditUserNameItem.editText)
    }

    override fun onClick(v: View?) {
        when(v?.id){
            //所在城市
            R.id.mEditUserCityItem -> IntentUtils.startCityListActivity(mContext)
            //学校名称
            R.id.mEditSchoolNameItem -> inputDialogListener(EditInfoCode.TYPE_SCHOOL, mEditSchoolNameItem.content)
            //学历
            R.id.mEditEducationItem -> educationItemClick()
            //首次参加工作时间
            R.id.mEditWorkYearItem -> workDateItemClick()
            //最近就职的公司
            R.id.mEditCompanyItem -> inputDialogListener(EditInfoCode.TYPE_COMPANY, mEditCompanyItem.content)
            //职位名称
            R.id.mEditPositionNameItem -> IntentUtils.startSelectPositionAndTagsActivity(this,mEditPositionNameItem.content,IntentUtils.REQUEST_CODE_POSITION_NAME)
            //职位类别
            R.id.mEditPositionTypeItem -> IntentUtils.startExpectPositionActivity(mContext)
            //职位标签
            R.id.mEditPositionLabelItem -> requestPositionLabels()
            //期望薪资
            R.id.mEditExpectSalaryItem -> salaryItemClick()
            //出生日期点击
            R.id.mEditBirthdayItem -> birthdayClick()
            //下一步
            R.id.mTvNextStep -> commit()
        }
    }

    /**
     * 出生日期点击
     */
    private fun birthdayClick() {
        val curBirthday = mEditBirthdayItem.content
        val defaultBirth = (DateUtils.getCurrentYear() - 22).toString() + ".06.15"
        val birthday = if (curBirthday.isNullOrEmpty()) defaultBirth else curBirthday
        var arrSize = birthday.split(".").size
        val dateFormat = if (arrSize == 3)  "yyyy.MM.dd" else "yyyy.MM"
        val strategy = BirthdayWheelStrategy(DateUtils.dateToUnixTimestamp(birthday, dateFormat))
        val options = strategy.data
        WheelDialog(this).apply {
            mWheelStrategy = strategy
            builder(ResourceUtils.getString(R.string.birthday), mEditBirthdayItem.id,options, strategy.curSelectData,strategy.getLimit(options), WheelDialog.MIN)
            setOnDataPicListener { _, data ->
                if (data == null || data.size < 3){
                    return@setOnDataPicListener
                }
                val date = StringUtil.jointString(".",data.asList())
                mEditBirthdayItem.content = date
                checkInfoIsPerfect()
            }
        }.show()
    }

    /**
     * 期望薪资点击
     */
    private fun salaryItemClick(){
        val curSalary = mEditExpectSalaryItem.content
        val curSalaryList = if (curSalary.isNullOrEmpty() || curSalary.split("-").size != 2){
            DataServer.getDefaultSalary()
        } else {
            if (curSalary.toUpperCase(Locale.ROOT) == DEFAULT_SALARY_HIGH){
                arrayListOf(GuideExpectJobActivity.DEFAULT_SALARY_HIGH,"")
            }else{
                arrayListOf(curSalary.substringBefore("-"),curSalary.substringAfter("-"))
            }
        }
        WheelDialog(this).apply {
            mWheelStrategy = SalaryWheelStrategy()
            builder(DataServer.getSalaryArrC(),curSalaryList)
            setOnDataPicListener { _, data ->
                if (data.size < 2){
                    return@setOnDataPicListener
                }
                mEditExpectSalaryItem.content = if (data[0] == DEFAULT_SALARY_HIGH) data[0] else "${data[0]}-${data[1]}"
                checkInfoIsPerfect()
            }
            show()
        }
    }

    /**
     * 首次参加工作时间L
     */
    private fun workDateItemClick(){
        val options = ComUtil.getTwoCulumnOptions(4,CommonDef.EDIT_TYPE_BASE)
        val curList = ComUtil.getJoinWorkTime(mEditWorkYearItem.content)
        val resumeBaseInfo = ResumeBaseInfo()
        resumeBaseInfo.birthday = mEditBirthdayItem.content
        val limitList = ComUtil.getLimit(4,CommonDef.EDIT_TYPE_BASE,resumeBaseInfo,null,null,null)
        WheelDialog(this).apply{
            mWheelStrategy = DataWheelStrategy()
            builder(resources.getString(R.string.first_job_time),R.id.mEditWorkYearItem,options,curList,limitList,WheelDialog.MAX).setOnDataPicListener(object : WheelDialog.onDataPicListener{
                override fun onDataPic(key: Int, data: Array<out String>?) {
                    if (data == null || data.size < 2){
                        return
                    }

                    var workDate = ""
                    val noWorkText = resources.getString(R.string.no_work_exp)
                    if (data[0] == noWorkText){
                        workDate = noWorkText
                        mEditPositionTypeItem.titleName = ResourceUtils.getString(R.string.expect_position_type)
                        if (workDate != mEditWorkYearItem.content){
                            resetViewByWorkDateType()
                            hideViews(mEditCompanyItem,mEditPositionNameItem,mEditPositionLabelItem).showViews(mEditPositionTypeItem)
                        }
                    }else{
                        workDate = StringUtil.jointString(".",data[0].trim(),data[1].trim())
                        mEditPositionTypeItem.titleName = ResourceUtils.getString(R.string.position_type_n)
                        //具体的工作时间
                        if (mEditWorkYearItem.content.isNullOrEmpty() || mEditWorkYearItem.content == noWorkText){
                            //如果之前选的是暂无工作经历，那么需要丢弃之前选的最近就职公司、职位名称、职位类型、职位标签
                            resetViewByWorkDateType()
                            hideViews(mEditPositionLabelItem,mEditPositionTypeItem).showViews(mEditCompanyItem,mEditPositionNameItem)
                        }
                    }
                    mEditWorkYearItem.content = workDate
                    checkInfoIsPerfect()
                }

            }).show()
        }
    }

    /**
     * 具体时间->暂无工作经历 or 暂无工作经历 -> 具体时间
     * 清空职位类别，细分标签、职位名称、最近就职的公司
     */
    private fun resetViewByWorkDateType(){
        mEditPositionTypeItem.content = null
        mEditPositionLabelItem.content = null
        mEditPositionNameItem.content = null
        mEditCompanyItem.content = null

        mPositionLabels = null
        mPositionCodes[0] = null
        mPositionCodes[1] = null
        mPositionCodes[2] = null

    }
    /**
     * 学历点击事件
     */
    private fun educationItemClick(){
       val options =  ComUtil.getTwoCulumnOptions(2, CommonDef.PerfectType.PERFECT_EDUCATION_LEVEL)
        val curList = if (mEditEducationItem.content.isNullOrEmpty() or !mEditEducationItem.content.contains(EducationExperienceBean.BEN_KE_SEPARATOR)){
            arrayListOf<String>(EducationExperienceBean.BEN_KE,EducationExperienceBean.TONG_ZHAO)
        } else{
            mEditEducationItem.content.split(EducationExperienceBean.BEN_KE_SEPARATOR)
        }
        WheelDialog(this).apply {
            mWheelStrategy = EducationLevelStrategy()
            builder(resources.getString(R.string.edu_education),R.id.li_education_level, options, curList, arrayListOf(), WheelDialog.MAX).setOnDataPicListener(object:WheelDialog.onDataPicListener{
                override fun onDataPic(key: Int, data: Array<out String>?) {
                   if (data == null || data.isEmpty()){
                       return
                   }
                    mEditEducationItem.content = if (data.size == 2) StringUtil.jointString(
                        EducationExperienceBean.BEN_KE_SEPARATOR,
                        data[0],data[1]
                    ) else data[0]
                    checkInfoIsPerfect()
                }

            }).show()
        }
    }

   private fun inputDialogListener(editCode:Int,editContent:String?){
        val editInfoDialog = EditInfoDialog(this, editCode, editContent)
        XPopup.Builder(this)
            .moveUpToKeyboard(false)
            .asCustom(editInfoDialog)
            .show()
        editInfoDialog.setOnResultListener { result ->
            when(editCode){
                EditInfoCode.TYPE_SCHOOL -> mEditSchoolNameItem.content = result
                EditInfoCode.TYPE_COMPANY -> mEditCompanyItem.content = result
            }
            checkInfoIsPerfect()
        }
    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode != RESULT_OK) {
            return
        }
       data?.let{ it ->
           it.extras?.let {bundle: Bundle ->
               when(requestCode){
                   //城市
                   IntentUtils.REQUEST_CODE_CITIES -> {
                       val city = bundle.getString("city")
                       mEditUserCityItem.content = city

                   }
                   //职位类别
                   IntentUtils.REQUEST_CODE_EXPECT_WORK -> {
                       val positionTypeVo = bundle.getSerializable(PositionTypeManager.POSITION_TYPE) as? PositionTypeVo
                       positionTypeVo?.let { pt ->
                           val positionName =  pt.positionNameList?.elementAtOrNull(2)
                           if (!positionName.isNullOrEmpty()){
                               mEditPositionTypeItem.content = positionName
                           }
                           //搜索时是否匹配到标签
                            mPositionLabels = if ((pt.searchMatchedLabelForType3 == null)) null else arrayListOf(pt.searchMatchedLabelForType3)
                            mEditPositionLabelItem.content = pt.searchMatchedLabelForType3?.name
                           //职位三级分类code
                           mPositionCodes[0] = pt.positionCodeList?.elementAtOrNull(0)
                           mPositionCodes[1] = pt.positionCodeList?.elementAtOrNull(1)
                           mPositionCodes[2] = pt.positionCodeList?.elementAtOrNull(2)
                           //调用接口检测是否有标签，如果有就跳转到细分标签页
                            requestPositionLabels()
                       }
                   }
                   //职位标签
                   IntentUtils.REQUEST_CODE_POSITION_LABEL -> {
                       val selectLabels: ArrayList<PositionLabelGroup.Label?>? =  bundle.getSerializable(ResumePositionTagActivity.KEY_SELECTED_TAGS) as? ArrayList<PositionLabelGroup.Label?>
                       mPositionLabels = selectLabels
                       mEditPositionLabelItem.content =
                           selectLabels?.filterNotNull()?.joinToString("、") { it.name }

                   }
                   //职位名称
                   IntentUtils.REQUEST_CODE_POSITION_NAME -> {
                        val positionNameTypeAndTags: PositionTypeAndTagsBean? = bundle.getSerializable(IntentUtils.INTENT_KEY_DATA) as? PositionTypeAndTagsBean
                        mEditPositionTypeItem.visibility = View.VISIBLE
                       mPositionCodes[0] = positionNameTypeAndTags?.expectJobInfo?.newPositionCode1
                       mPositionCodes[1] = positionNameTypeAndTags?.expectJobInfo?.newPositionCode2
                       mPositionCodes[2] = positionNameTypeAndTags?.expectJobInfo?.newPositionCode3

                       mPositionLabels = positionNameTypeAndTags?.expectJobInfo?.tagCodes?.filterIndexed { index, _ -> index < 3 } as? ArrayList<PositionLabelGroup.Label?>
                       mEditPositionNameItem.content = positionNameTypeAndTags?.positionName
                       mEditPositionTypeItem.content = positionNameTypeAndTags?.expectJobInfo?.newPositionName3
                       mEditPositionLabelItem.content = mPositionLabels?.filterNotNull()?.joinToString("、"){it.name}
                       requestPositionLabels()
                   }
               }
               checkInfoIsPerfect()
           }

       }
    }

    /**
     * 请求职位标签接口
     */
    private fun requestPositionLabels() {
        showLoading()
        ApiService.api.getTagRelation(mPositionCodes[1],mPositionCodes[2]).enqueue(object:
            BaseCallback<ArrayList<PositionLabelGroup>>() {
            override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<ArrayList<PositionLabelGroup>>?) {
                if (isActivityDestroyed){
                    return
                }
                hideLoading()
                mEditPositionLabelItem.visibility = if (response?.content.isNullOrEmpty()) View.GONE else View.VISIBLE
                if (mEditPositionLabelItem.visibility == View.VISIBLE){
                    IntentUtils.startPositionLabelNoCustomActivity(this@PostcardActivity,response?.content,mPositionLabels,ResumePositionTagActivity.VALUE_FROM_GUIDE_EXPECT_JOB)
                }
            }

            override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<ArrayList<PositionLabelGroup>>?) {
                if (isActivityDestroyed){
                    return
                }
                hideLoading()
                mEditPositionLabelItem.visibility = View.GONE
            }
        })
    }

    /**
     * 请求名片信息
     */
    private fun requestPostcardInfo(){
        showLoading()
        ApiService.api.fetchPostcardInfo().enqueue(object:BaseCallback<PostcardInfoBean>(false){
            override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<PostcardInfoBean>?) {
                if (isActivityDestroyed) {
                    return
                }
                hideLoading()
                val postcardInfoBean: PostcardInfoBean? = response?.content
                mPositionCodes[0] = postcardInfoBean?.expectJobInfo?.newPositionCode1
                mPositionCodes[1] = postcardInfoBean?.expectJobInfo?.newPositionCode2
                mPositionCodes[2] = postcardInfoBean?.expectJobInfo?.newPositionCode3
                mPositionLabels = postcardInfoBean?.expectJobInfo?.tagCodes
                postcardInfoBean?.let {
                    fillView(postcardInfoBean)
                }
            }

            override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<PostcardInfoBean>?) {
               if (isActivityDestroyed){
                   return
               }
                hideLoading()
            }

        })
    }

    /**
     * 填充View
     */
    private fun fillView(bean: PostcardInfoBean) {
        mEditUserNameItem.content = bean.userName
        mEditUserCityItem.content = bean.city
        mEditSchoolNameItem.content = bean.schoolName
        mEditEducationItem.content = bean.getEducationWithSuffix()
        mEditWorkYearItem.content = bean.joinWorkTime
        mEditCompanyItem.content = bean.companyName
        mEditPositionNameItem.content = bean.positionName
        mEditPositionTypeItem.content = bean.expectJobInfo?.newPositionName3
        mEditPositionLabelItem.content = mPositionLabels?.filterNotNull()?.filterIndexed { index, _ -> index < 3 }?.joinToString("、"){ it.name }
        mEditExpectSalaryItem.content = bean.expectJobInfo?.expectSalary
        mEditBirthdayItem.content = bean.birthday
        if (bean.positionName.isNullOrEmpty().not()){
            //如果职位名称不为空，需要将职位类别展示出来
            showViews(mEditPositionNameItem,mEditPositionTypeItem)
            mEditPositionLabelItem.visibility = if (mEditPositionLabelItem.content.isNullOrEmpty()) View.GONE else View.VISIBLE
        }
        if (bean.joinWorkTime.isNullOrEmpty().not()){
            if (bean.joinWorkTime == ResourceUtils.getString(R.string.no_work_exp)){
                //暂无工作经历
                mEditPositionTypeItem.titleName = ResourceUtils.getString(R.string.expect_position_type)
                resetViewByWorkDateType()
                hideViews(mEditCompanyItem,mEditPositionNameItem,mEditPositionLabelItem).showViews(mEditPositionTypeItem)
            }else{
                //有具体的工作时间
                showViews(mEditCompanyItem,mEditPositionNameItem)
            }
        }

        checkInfoIsPerfect()
    }

    /**
     * 提交保存，下一步
     */
    private fun commit() {
       val isNotPerfect = checkInfoIsPerfect(isShowRedLine = true, isCommit = true)
        if (isNotPerfect){
            return
        }
       val userName = SensitiveLogic.SensitiveKey.RESUME_USER_NAME_WARN.name
       val schoolName = SensitiveLogic.SensitiveKey.RESUME_EDU_SCHOOL_NAME_WARN.name
       val companyName = SensitiveLogic.SensitiveKey.RESUME_WORK_COMPANY_NAME_WARN.name
       val positionName = SensitiveLogic.SensitiveKey.RESUME_WORK_POSITION_NAME_WARN.name
       val map = mapOf(
           userName to mEditUserNameItem.content,
           schoolName to mEditSchoolNameItem.content,
           companyName to mEditCompanyItem.content,
           positionName to mEditPositionNameItem.content
       )
       SensitiveLogic.checkExistSensitiveKey(map, object:SensitiveLogic.CheckSensitiveCallback{
               override fun checkFinish(keyList: ArrayList<String>?) {
                   if (!keyList.isNullOrEmpty()){
                       if (keyList.contains(userName) || keyList.contains(schoolName)
                           || keyList.contains(companyName) || keyList.contains(positionName)){
                           ToastUtil.showCenter(this@PostcardActivity, ResourceUtils.getString(R.string.content_warn))
                       }
                       PostcardViewHelper.setLineState(if(keyList.contains(userName)) PostcardViewHelper.LineState.RED
                       else PostcardViewHelper.LineState.NORMAL, mEditUserNameItem.lineBottom)

                       PostcardViewHelper.setLineState(if(keyList.contains(schoolName)) PostcardViewHelper.LineState.RED
                       else PostcardViewHelper.LineState.NORMAL,mEditSchoolNameItem.lineBottom)

                       PostcardViewHelper.setLineState(if(keyList.contains(companyName)) PostcardViewHelper.LineState.RED
                       else PostcardViewHelper.LineState.NORMAL,mEditCompanyItem.lineBottom)

                       PostcardViewHelper.setLineState(if(keyList.contains(positionName)) PostcardViewHelper.LineState.RED
                       else PostcardViewHelper.LineState.NORMAL,mEditPositionNameItem.lineBottom)

                       return
                   }

                   PostcardViewHelper.setLineState(PostcardViewHelper.LineState.NORMAL, mEditUserNameItem.lineBottom)
                   PostcardViewHelper.setLineState(PostcardViewHelper.LineState.NORMAL, mEditSchoolNameItem.lineBottom)
                   PostcardViewHelper.setLineState(PostcardViewHelper.LineState.NORMAL, mEditCompanyItem.lineBottom)
                   PostcardViewHelper.setLineState(PostcardViewHelper.LineState.NORMAL, mEditPositionNameItem.lineBottom)
                   //敏感词校验完成，进行下一步保存名片信息
                   savePostcardInfo()
               }
           })
    }

    /**
     * 保存用户名片
     */
    private fun savePostcardInfo(){
        //用户身份，1-学生身份，2-职场人身份
        val postcardInfoBean = PostcardInfoBean()
        postcardInfoBean.userIdentity = ResumeBaseInfo.WORKER_INT
        postcardInfoBean.userName = mEditUserNameItem.content
        postcardInfoBean.city = mEditUserCityItem.content
        postcardInfoBean.schoolName = mEditSchoolNameItem.content
        postcardInfoBean.education = mEditEducationItem.content.substringBefore(EducationExperienceBean.BEN_KE_SEPARATOR,mEditEducationItem.content)
        postcardInfoBean.joinWorkTime = mEditWorkYearItem.content
        postcardInfoBean.companyName = mEditCompanyItem.content
        postcardInfoBean.positionName = mEditPositionNameItem.content
        postcardInfoBean.setIsUnifiedEntrance(mEditEducationItem.content.substringAfter(EducationExperienceBean.BEN_KE_SEPARATOR,""))
        postcardInfoBean.expectJobInfo = ExpectInfo(
            newPositionCode1 = mPositionCodes[0],
            newPositionCode2 = mPositionCodes[1],
            newPositionCode3 = mPositionCodes[2],
            expectSalary = mEditExpectSalaryItem.content,
            tagCodes = mPositionLabels
        )
        postcardInfoBean.birthday = mEditBirthdayItem.content
        showLoading()
        ApiService.api.savePostcardInfo(postcardInfoBean).enqueue(object:BaseCallback<Any>(){
            override fun onSuccess(p0: HttpRequest<*>?, p1: HttpResponse<Any>?) {
                UserRoleManager.getInstance().isChanging = false
                if (isActivityDestroyed){
                    return
                }
                hideLoading()
                if (mSource == SOURCE_REGISTER){
                    //为了复用完善教育经历、工作经历的页面，需要拉取一下最新的简历信息，用来展示页面信息
                    syncResumeAndEnterGuideEducation(this@PostcardActivity)
                }else{
                    finish()
                }
            }

            override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<Any>?) {
                super.onFailure(request, response)
                if (isActivityDestroyed){
                    return
                }
                hideLoading()
            }

        })
    }

    /**
     * 校验信息是否完善
     * @param isShowRedLine 是否展示itemView底部的红线
     */
    fun checkInfoIsPerfect(isShowRedLine:Boolean = false,isCommit:Boolean = false):Boolean{
        //存储的每个item是否完善
        val editItemFields = hashMapOf<EditItemView,Boolean>()
        getNotPerfectFields(mScrollContentParent,editItemFields)
        val isNotPerfect = editItemFields.any { !it.value }
        mTvNextStep.alpha = if (isNotPerfect) 0.3f else 1.0f
        if (isCommit && isNotPerfect){
            val notPerfectFields = editItemFields.filterValues { !it }.map { it.key }
            val notPerfectTip = if (notPerfectFields.size == 1) "请完善${notPerfectFields[0].titleName}" else PLS_PERFECT_INFO
            ToastUtil.showCenter(this,notPerfectTip)
        }
        if (isShowRedLine){
            editItemFields.forEach {
               PostcardViewHelper.setLineState(if (it.value) PostcardViewHelper.LineState.NORMAL else PostcardViewHelper.LineState.RED,it.key.lineBottom)
            }
        }
        return isNotPerfect
    }
    private fun getNotPerfectFields(parent:ViewGroup, editItemFields:MutableMap<EditItemView,Boolean>){
        val childCount = parent.childCount
        for (index in 0 until childCount){
            val childView = parent.getChildAt(index)
            if (childView.visibility != View.VISIBLE){
                continue
            }
            when(childView){
                is EditItemView -> {
                    if (childView.id == R.id.mEditEducationItem){
                        //学历，本科若没选择统招or非统招，也算作不完善
                        editItemFields[childView] = !(childView.isEmpty
                                || (childView.content.contains(EducationExperienceBean.BEN_KE) && !childView.content.contains(EducationExperienceBean.TONG_ZHAO)))
                    }else{
                        editItemFields[childView] = !childView.isEmpty
                    }

                }
                is ViewGroup -> getNotPerfectFields(childView,editItemFields)
            }
        }
    }

    override fun isEnableCommonBarSetting() = false

    override fun onBackPressed() {
        DialogUtils.showExitPostcardDialog(supportFragmentManager, object : LgDialogListener() {
            override fun onLeft() {
                finish()
            }
        })
    }

    override fun getPageId() = "q1u1c"
}