package com.alpha.lagouapk.ui.search

import android.content.Context
import android.graphics.Color
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.TextView
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.SearchTopNewsBean
import com.alpha.lagouapk.tools.DensityUtil
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.widget.decoration.DividerItemDecoration
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ClickInfo
import com.lagou.baselib.analytic.bean.json.ShowLogInfo
import com.lagou.commonlibs.utils.DeviceUtils
import kotlinx.android.synthetic.main.layout_search_news_rank.view.*

/**
 *
 * @Author:         leon
 * @CreateDate:     2/1/21 10:41 AM
 * @Description:搜索新闻排行
 */

class SearchTopNewsRankView (val mContext: Context, attrs: AttributeSet?) : FrameLayout(mContext,attrs) {
    var recyclerView: RecyclerView = RecyclerView(context)
    var analyticShowArray = mutableListOf<Int>()
    init {
        recyclerView.apply {
            clipToPadding = false
            setPadding(DensityUtil.dip2px(15f), 0, DensityUtil.dip2px(15f), 0)
            layoutManager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
            addItemDecoration(DividerItemDecoration(context, DividerItemDecoration.VERTICAL_LIST, DensityUtil.dip2px(13f), Color.TRANSPARENT))
        }
        LRSnapHelper(LRSnapHelper.TYPE_SNAP_START).attachToRecyclerView(recyclerView)
        addView(recyclerView)
    }

    fun bindData(data: List<SearchTopNewsBean>?) {
        if (data.isNullOrEmpty()) {
            visibility = View.GONE
            return
        }
        analyticShowArray.clear()
        visibility = View.VISIBLE
        recyclerView.adapter = NewsAdapter(data)
    }

    inner class NewsAdapter(private val list: List<SearchTopNewsBean>?) : RecyclerView.Adapter<NewsAdapter.TopNewsViewHolder>() {
        var itemWidth = 0;

        init {
            itemWidth = if (list?.size ?: 0 > 1) (DeviceUtils.getScreenWidth() * 0.68f).toInt() else DeviceUtils.getScreenWidth() - DensityUtil.dip2px(30f)
        }

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): TopNewsViewHolder {
            val searchTopNewsRankItemView = SearchTopNewsRankItemView(mContext,attrs = null)
            searchTopNewsRankItemView.layoutParams = LayoutParams(itemWidth, LayoutParams.WRAP_CONTENT)
            return TopNewsViewHolder(searchTopNewsRankItemView)
        }

        override fun getItemCount(): Int {
            return list?.size ?: 0
        }

        override fun onBindViewHolder(holder: TopNewsViewHolder, position: Int) {
            if (holder.itemView is SearchTopNewsRankItemView) {
                list?.get(position)?.let {
                    holder.itemView.bindItem(it)
                    if (it.id !in analyticShowArray) {
                        val showLogInfo = ShowLogInfo()
                        showLogInfo.setAddress_Id("1ryu").setPage_Id("1rtm").addShowProp("module_id", it.id)
                        AnalyticHelper.getInstance().sendShowInfo(showLogInfo)
                        analyticShowArray.add(it.id)
                    }
                }
            }
        }

        inner class TopNewsViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView)
    }


    inner class SearchTopNewsRankItemView(context: Context, attrs: AttributeSet?) : FrameLayout(context,attrs) {
        init {
            LayoutInflater.from(context).inflate(R.layout.layout_search_news_rank, this)
        }
        fun bindItem(data: SearchTopNewsBean) {
            data?.let {
                tvTitle.text = data.title
                tvSubTitle.text = data.subTitle
                rvNewsRank.adapter = SearchTopNewsItemAdapter(data.id,data.titleList)
            }

        }

        inner class SearchTopNewsItemAdapter(private val moduleId:Int,private val itemList: MutableList<SearchTopNewsBean.TitleListBean>?) : RecyclerView.Adapter<NewsRankItemViewHolder>() {
            override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): NewsRankItemViewHolder {
                return NewsRankItemViewHolder(LayoutInflater.from(mContext).inflate(R.layout.item_search_news_rank, parent, false))
            }

            override fun getItemCount(): Int {
                return itemList?.size ?: 0
            }

            override fun onBindViewHolder(holder: NewsRankItemViewHolder, position: Int) {
                val titleBean: SearchTopNewsBean.TitleListBean? = itemList?.get(position)
                holder.tvNewsSequence.apply {
                    text = (position + 1).toString()
                    textSize = if (position > 2) 12f else 10f
                    setTextColor(if (position > 2) ContextCompat.getColor(mContext,R.color.color_666666) else ContextCompat.getColor(mContext,R.color.white))
                    background = if (position > 2) null else ContextCompat.getDrawable(mContext,R.drawable.bg_r2_solid_ff7655)
                }

                holder.tvNewsTitle.apply {
                    text = titleBean?.title
                    setTextColor(if (position > 2) ContextCompat.getColor(mContext,R.color.color_666666) else Color.parseColor("#FF7655"))
                }

                holder.tvNewsLabel.apply {
                    text = titleBean?.articalLabel
                    visibility = if (TextUtils.isEmpty(text)) View.GONE else View.VISIBLE
                    setTextColor(if (position > 2) ContextCompat.getColor(mContext,R.color.color_999999) else Color.parseColor("#FF8367"))
                    background = if (position > 2) ContextCompat.getDrawable(mContext,R.drawable.bg_border2_cccccc) else ContextCompat.getDrawable(mContext,R.drawable.bg_border2_ffbeaf)
                }
                holder.itemView.setOnClickListener {
                    val clickInfo = ClickInfo().apply{
                        address_id = "1ryv"
                        page_id = "1rtm"
                        addClick_props("module_id",moduleId)
                        addClick_props("content_id",(position + 1))
                        addClick_props("content_text",titleBean?.title)
                    }
                    AnalyticHelper.getInstance().sendClickInfo(clickInfo)
                    IntentUtils.startLagouWebViewActivity(mContext, titleBean?.jumpUrl)
                }
            }

        }

        inner class NewsRankItemViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
            val tvNewsSequence = itemView.findViewById<TextView>(R.id.tvNewsSequence)
            val tvNewsTitle = itemView.findViewById<TextView>(R.id.tvNewsTitle)
            val tvNewsLabel = itemView.findViewById<TextView>(R.id.tvNewsLabel)
        }
    }
}