package com.alpha.lagouapk.widget

import android.content.Context
import android.view.Gravity
import android.view.View
import android.widget.ImageView
import androidx.fragment.app.FragmentManager
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.AdVoBean
import com.alpha.lagouapk.tools.IntentUtils
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ClickInfo
import com.lagou.baselib.analytic.bean.json.PVLogInfo
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.ui.dialog.BaseDialogFragment
import com.lagou.commonlibs.utils.GlideUtil
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.component.ui.banner.BannerView
import com.lagou.component.ui.banner.SimpleBannerCallback

/**
 * @author 作者：ryan.lei
 * @date 创建时间：2021/12/21 12:11
 * @Description 描述：通用多广告弹窗
 **/
class MultiAdDialog : BaseDialogFragment() {
    private var mDialogBanner: BannerView? = null
    private var mIvClose: ImageView? = null
    private var mListener: OnAdDialogListener? = null
    private var mMultiAdBeans: List<AdVoBean>? = null

    companion object {
        /**
         * 最多支持多少帧广告图左右滑动
         */
        private const val LOOP_AD_CAPACITY = 3

        fun getInstance(multiAdList: List<AdVoBean>): MultiAdDialog {
            val dialog = MultiAdDialog()
            dialog.mMultiAdBeans = multiAdList
            return dialog
        }
    }

    override fun getLayoutId(): Int {
        return R.layout.dialog_multi_ad
    }

    override fun initView(view: View?) {
        super.initView(view)
        mDialogBanner = view?.findViewById(R.id.view_dialog_banner)
        mIvClose = view?.findViewById(R.id.iv_dialog_close)
    }

    override fun initListener() {
        super.initListener()
        mIvClose?.setOnClickListener {
            mListener?.onAdDialogDismiss()
            dismiss()
        }
    }

    override fun fillUI() {
        super.fillUI()
        if (ListUtil.isEmpty(mMultiAdBeans) || activity == null) {
            return
        }
        mDialogBanner?.setBannerCallback(object : SimpleBannerCallback<AdVoBean>() {
            override fun onItemClick(context: Context, bean: AdVoBean, position: Int) {
                IntentUtils.startLagouWebViewActivity(getContext(), bean.url)
                //点击埋点
                val info = ClickInfo()
                info.page_id = bean.pageId
                info.address_id = bean.aId
                info.addClick_props("ad_id", bean.adId)
                AnalyticHelper.getInstance().sendClickInfo(info)
                dismiss()
            }

            override fun setImage(imageView: ImageView, bean: AdVoBean) {
                if (GlideUtil.isValidContextForGlide(context) && bean.pictureList != null && bean.pictureList.isNotEmpty()) {
                    ImageLoadUtils.with(context)
                        .load(bean.pictureList[0])
                        .bitmapTransform(RoundTransform(8))
                        .error(R.drawable.bg_corner_f2f2f2_r3)
                        .into(imageView)
                }
            }

            override fun onItemShow(context: Context, bean: AdVoBean, position: Int) {
                super.onItemShow(context, bean, position)
                //曝光埋点
                val pvLogInfo = PVLogInfo()
                pvLogInfo.page_id = bean.pageId
                pvLogInfo.addBrowse_props("ad_id", bean.adId)
                AnalyticHelper.getInstance().sendExploreInfo(pvLogInfo)
            }
        })
        mDialogBanner?.setBannerList(mMultiAdBeans)
    }

    override fun show(manager: FragmentManager?) {
        super.show(manager)
    }

    override fun getGravity(): Int {
        return Gravity.CENTER
    }

    fun setOnAdDialogListener(listener: OnAdDialogListener) {
        mListener = listener
    }

    interface OnAdDialogListener {
        /**
         * 关闭
         */
        fun onAdDialogDismiss()
    }
}