package com.common

import com.ApiService
import com.common.bean.CheckSensitiveReqBean
import com.common.bean.CheckSensitiveResBean
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse

/**
 * 检验是否有敏感词
 */
object SensitiveLogic {
    enum class SensitiveKey {
        //个人资料-姓名
        RESUME_USER_NAME_WARN,

        //个人资料-邮箱
        RESUME_EMAIL_WARN,
        //通用内容（个人优势等）
        RESUME_ADVANTAGE_WARN,
        //other
        CONTENT_WARN,

        //工作经历-公司名称
        RESUME_WORK_COMPANY_NAME_WARN,
        //工作经历-所属部门
        RESUME_WORK_DEPARTMENT_WARN,
        //工作经历-职位名称
        RESUME_WORK_POSITION_NAME_WARN,
        //工作经历-技能标签
        RESUME_WORK_SKILL_LABELS_WARN,
        //工作经历-内容
        RESUME_WORK_CONTENT_WARN,

        //教育经历-学校名称
        RESUME_EDU_SCHOOL_NAME_WARN,
        //教育经历-专业名称
        RESUME_EDU_MAJOR_NAME_WARN,

        //项目经历-项目名称
        RESUME_PROJECT_NAME_WARN,
        //项目经历-项目描述
        RESUME_PROJECT_REMARK_WARN,
        //项目经历-你的成就
        RESUME_PROJECT_DUTY_REMARK_WARN,
        //项目经历-项目链接
        RESUME_PROJECT_URL_WARN,

        //社交主页
        RESUME_SOCIAL_ACCOUNT_URL_WARN,


        //公司信息-公司介绍
        COMPANY_FULL_INTRO_WARN,

        //公司信息-一句话介绍
        COMPANY_SHORT_INTRO_WARN,

        //我的信息-姓名
        B_ME_NAME_WARN,

        //我的信息-职位
        B_ME_JOB_WARN,

        //发布职位-职位名称
        POSITION_NAME_WARN,

        //发布职位-职位描述
        POSITION_DETAIL_WARN,

        //发布职位-职位亮点
        POSITION_ADVANTAGE_WARN,

        //发布职位-人选加分项
        POSITION_ADD_SCORE_WARN,

        //发布职位-所属部门
        POSITION_DEPARTMENT_WARN,

        //发布职位-工作地址
        POSITION_WORK_ADDRESS_WARN,

        //发布职位-职位细分标签
        POSITION_SKILL_TAG_WARN,

        //发布职位-行业标签
        POSITION_INDUSTRY_TAG_WARN
    }

    fun checkExistSensitiveKey(words: Map<String, String>, callback: CheckSensitiveCallback?) {
        if (words.isNullOrEmpty()) {
            callback?.checkFinish(null)
            return
        }
        val requestBean = CheckSensitiveReqBean(words)
        ApiService.api.checkSensitiveKey(requestBean)
            .enqueue(object : BaseCallback<CheckSensitiveResBean>(false) {
                override fun onSuccess(
                    request: HttpRequest<*>?,
                    response: HttpResponse<CheckSensitiveResBean>?
                ) {
                    val checkList = response?.content?.checkList
                    callback?.checkFinish(checkList)
                }

                override fun onFailure(
                    request: HttpRequest<*>?,
                    response: HttpResponse<CheckSensitiveResBean>?
                ) {
                    callback?.checkFinish(null)
                }

            })
    }

    interface CheckSensitiveCallback {
        fun checkFinish(keyList: ArrayList<String>?)
    }
}