package com.common.bean

import android.net.Uri
import android.os.Parcelable
import com.common.utils.CommonVideoUtil
import kotlinx.android.parcel.IgnoredOnParcel
import kotlinx.android.parcel.Parcelize

/**
 * @date： Crate by wangjunwei on 2022/7/12
 * @description：视频文件整合bean
 **/
@Parcelize
data class VideoRes(
    var duration: Long,
    var size: Long,
    val uri: Uri? = null,
    var name: String? = "",
    var destPath: String = "",
    var videoUrl: String = "",
    var coverUrl: String = ""
) : Parcelable {

    /**
     * 支持压缩的最大视频大小
     */
    @IgnoredOnParcel
    val MAX_SIZE = 800 * 1024 * 1024

    fun isExceedSize(): Boolean {
        return size > MAX_SIZE
    }

    /**
     *  判断当前的视频是否是不支持的格式
     *  目前只支持MP4、MOV
     */
    fun isUnSupportFormat(): Boolean{
        return !CommonVideoUtil.isSupportFormat(name)
    }

    /**
     * 处理视频时长，为minute:second格式
     */
    fun handleDuration():String{
        val tempSecond = duration / 1000
        val minute = tempSecond / 60
        val secondInt = tempSecond % 60
        var secondStr = secondInt.toString()
        if (secondInt < 10){
            secondStr = "0$secondStr"
        }
        return "$minute:$secondStr"
    }
}