package com.common.chat.item

import android.content.Context
import android.graphics.Typeface
import android.util.AttributeSet
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.IntentUtils
import com.common.chat.item.base.ChatItem
import com.common.chat.manager.ChatManager
import com.common.utils.CommonIntentUtils
import com.lagou.chat.chatlibrary.bean.ChatMsgBase
import com.lagou.chat.chatlibrary.bean.json.JMsgAddress
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.socketchannel.util.SPUtil

/**
 * 发送地址
 */
class MapAddressItem @JvmOverloads constructor(context: Context, attr: AttributeSet? = null, defStyleResId: Int = 0):ChatItem(context){
    private var mVipFlag: ImageView? = null
    private var mTvAddressDetail:TextView? = null
    private var tvTitle:TextView? = null
    private var mAddressInfo:JMsgAddress? = null
    override fun getLayoutId(): Int = if (mLayoutRight) R.layout.chat_item_address_right else R.layout.chat_item_address_left

    override fun initView() {
        mContentLayout = findViewById(R.id.chat_item_content_layout)
        mDate = findViewById(R.id.chat_item_address_date)
        mAvatar = findViewById(R.id.chat_item_address_avatar)
        mTvAddressDetail = findViewById(R.id.tv_address_detail)
        msgLayout = findViewById(R.id.chat_item_msg_container)
        mRecallWrap = findViewById(R.id.tv_recall_msg_text)
        tvTitle = findViewById(R.id.tv_address_title)

        tvTitle?.typeface = tvTitle?.paint?.setTypeface(Typeface.defaultFromStyle(Typeface.BOLD))
        if (mLayoutRight) {
            mVipFlag = findViewById(R.id.chat_item_vip_flag)
            initState()
        }
        msgLayout.setOnLongClickListener(OnLongClickMsgListener())
        msgLayout.setOnClickListener {
            if (mLayoutRight) {
                CommonIntentUtils.startMapPreviewActivity(context, mAddressInfo?.lat ?: 0.0, mAddressInfo?.lng ?: 0.0)
            } else {
                IntentUtils.startMapActivity(context, mTvAddressDetail?.text?.toString(), mAddressInfo?.lat?.toString(), mAddressInfo?.lng?.toString())
            }
        }
    }


    override fun updateView() {
        val addressInfo:JMsgAddress? = mChatMsg.msgAddress
        this.mAddressInfo = addressInfo
        if (addressInfo == null){
            visibility = View.GONE
            return
        }
        visibility = View.VISIBLE
        mTvAddressDetail?.text = StringUtil.jointString(" ",addressInfo.city,addressInfo.district,addressInfo.detailAddress)
        tvTitle?.text = addressInfo.title
        if(mLayoutRight){
            mVipFlag?.visibility = if (SPUtil.isVIP()) VISIBLE else GONE
            updateSendState()
        }
        updateRecallView()
    }

    /**
     * 更新撤回消息
     */
    private fun updateRecallView(){
        mRecallWrap.visibility = if (mChatMsg.state == ChatMsgBase.MsgState.RECALL) VISIBLE else GONE
        mContentLayout.visibility = if (mChatMsg.state == ChatMsgBase.MsgState.RECALL) GONE else VISIBLE
        if (mRecallWrap is TextView) {
            val isSender = ChatManager.getInstance().transIsSender(mChatMsg)
            (mRecallWrap as TextView).text = resources.getString(R.string.msg_recall_text, if (isSender) "你" else "对方")
        }
    }
}