package com.common.integrate.faceverify

import android.app.Activity
import com.alpha.lagouapk.BuildConfig
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.face.FaceUserCallback

/**
 * @date 创建时间：2019-08-01
 * @author 作者：codeman
 * @Description  描述：
 * @version
 */
abstract class FaceUserCallbackCenter(private val activity: Activity) : FaceUserCallback<Int>() {

    /***
     * 目前默认是重试3次
     */
    override fun retryVerify() = 3

    /***
     * 产品要求当满足以下状态码时需要降级到百度人脸识别
     */
    private val downgradeMap = mapOf(4200 to listOf("ILLEGAL_PARAMETER", "BIZ_TOKEN_DENIED", "AUTHENTICATION_FAIL", "MOBILE_PHONE_NOT_SUPPORT", "SDK_TOO_OLD"),
            6000 to listOf("NOT_ADD_RESOURCE", "FACE_INIT_FAIL", "ONVALID_BUNDLEID"),
            6200 to listOf("ERROR_UNKNOWN"))

    private val errorMsgMap = mapOf("LIVENESS_FINISH" to "活体检测完成", "ILLEGAL_PARAMETER" to "传入的参数不合法", "BIZ_TOKEN_DENIED" to "传入的biz_token不符合要求",
            "AUTHENTICATION_FAIL" to "鉴权失败", "MOBILE_PHONE_NOT_SUPPORT" to "手机不在支持列表里", "SDK_TOO_OLD" to "SDK版本过旧，已经不被支持",
            "USER_CANCEL" to "用户取消活体检测", "NOT_ADD_RESOURCE" to "未添加资源包", "NO_CAMERA_PERMISSION" to "APP没有获取相机权限", "DEVICE_NOT_SUPPORT" to "APP未找到可用的相机设备",
            "FACE_INIT_FAIL" to "SDK活体检测启动失败", "NETWORK_ERROR" to "连不上互联网，请检查网络连接状态", "ONVALID_BUNDLEID" to "APP信息验证失败，请检测bundleID设置",
            "LIVENESS_FAILURE" to "活体检测失败", "GO_TO_BACKGROUND" to "应用退到后台，活体检测失败", "ERROR_UNKNOWN" to "未知错误", "LIVENESS_TIME_OUT" to "操作超时，由于用户在长时间没有进行操作")

    override fun isDebug() = BuildConfig.DEBUG

    override fun languageType() = FaceConstant.ZH

    override fun host() = FaceConstant.HOST_CHINA

    override fun authType() = FaceConstant.AUTH_TYPE_FACE

    override fun downgradeStrategy() = downgradeMap

    override fun errorStateMsg(errorState: String?) = errorMsgMap[errorState]

    override fun getActivity() = activity

    override fun showToast(message: String?) {
        message?.let {
            ToastUtil.show(activity, it)
        }
    }
}