package com.common.integrate.pay

import android.os.Message
import com.alpha.lagouapk.R
import com.alpha.lagouapk.UserRoleManager
import com.common.bean.PayTypeInfo
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.OnUiRelativeListener
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.inter.OnSingleMethodListener
import com.lagou.commonlibs.ui.dialog.inter.ADismissListener
import com.lagou.commonlibs.utils.LogUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.lagouee.bean.jsonbean.business.CreateGoodsOrderReq
import com.lagou.lagouee.bean.jsonbean.business.GoodsBuyPushRes
import com.lagou.lagouee.bean.jsonbean.business.NewGoodsPayCheckRes
import com.lagou.lagouee.manager.net.BusinessNetManager
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.lagouee.widget.FullLoadingDialog
import com.lagou.pay.common.inter.SpecialPayCallBack
import com.lagou.socketchannel.http.HttpResponse

/**
 * @date 创建时间：2019-09-27
 * @author 作者：codeman
 * @Description  描述：承载商业化购买webview代理，也是一个支付订单成功后查询具体商品是否兑换成功的过渡页
 *                    原生承担所有流程，a 创建商品订单 b 尝试用勾豆支付 c 不够再掉起支付流程  d 支付成功后的兑换流程
 * @version
 */

class BusinessPayProxy(private val activity: BaseActivity?) : Event {

    private var trialMemberDialog: FullLoadingDialog? = null

    private var loadingDialog: FullLoadingDialog? = null

    companion object {
        /***
         * 完全原生支付入口
         * @param useScenes 支付场景
         * @param goodsOrderReq 创建商品支付订单需要的信息，安东尼提供
         */
        fun startNativePay(useScenes: String, goodsOrderReq: CreateGoodsOrderReq, businessPayProxy: BusinessPayProxy?, prePayCallBack: SpecialPayCallBack?) {
            BusinessNetManager.createGoodsOrder(useScenes, goodsOrderReq, businessPayProxy?.activity, prePayCallBack)
        }
    }

    fun onCreate() {
        //业务方注册使用场景需要的等待loading注册
        OkBus.getInstance()
                .register(BEventTags.PAY_SUCCESS_TRIAL_LOADING, this)
    }

    fun onDestroy() {
        loadingDialog?.dismiss()
        //关闭页面取消客户端支付成功后注册服务器确认支付消息事件
        OkBus.getInstance().unRegister(this)
    }


    override fun call(msg: Message?) {
        msg?.let {
            var payTypeInfo = msg.obj as? PayTypeInfo?
            when (msg.what) {
                BEventTags.PAY_SUCCESS_TRIAL_LOADING -> handlePaySuccessLoading(msg,
                        PaySuccessServerEnsure(payTypeInfo), BEventTags.PAY_SUCCESS_TRIAL_USER)
                else -> {
                    LogUtils.i("BusinessPayProxy", "支付event事件tag异常回调 msg.what = " + msg.what)
                }
            }
        }
    }

    /***
     * 支付异常弹窗回调事件
     */
    fun leftClick(){

    }
    fun rightClick(){

    }

    /***
     * 支付订单成功，但是兑换商品还没告知成功，等待服务器处理loading
     */
    private fun handlePaySuccessLoading(msg: Message?, paySeverEvent: Event, successBackUseTag: Int) {
        activity?.let{
            //1 注意注册该事件的时机，客户端支付成功后注册服务器确认支付消息事件
            OkBus.getInstance().register(BEventTags.PAY_SUCCESS_BUSINESS_SERVER, paySeverEvent)

            loadingDialog = when (successBackUseTag) {
                BEventTags.PAY_SUCCESS_TRIAL_LOADING -> trialMemberDialog
                else -> null
            }
            if (loadingDialog == null) {
                loadingDialog = FullLoadingDialog.getInstance(ResourceUtils.getString(R.string.in_the_account))
                loadingDialog?.setFailListener(OnSingleMethodListener<Boolean> {
                    //2 超时后取消客户端支付成功后注册服务器确认支付消息事件
                    OkBus.getInstance().unRegister(paySeverEvent)
                    if (msg?.obj is PayTypeInfo) {
                        var payTypeInfo = msg.obj as PayTypeInfo?
                        //3 等待超时，主动调取接口拉取
                        BusinessNetManager.checkDirectBusiness(payTypeInfo?.goodsOrder,
                                CheckOnAdapterCommonListenerImpl(activity, successBackUseTag, payTypeInfo), this)
                    }else {
                        loadingDialog?.dismiss()
                    }
                })
            }

            loadingDialog?.show(activity.supportFragmentManager)
        }
    }

    /***
     * 支付成功后，5s内没收到服务器消息，主动查询结果，作进一步处理
     * 之所以用内部类，是考虑到并发支付校验的情况，每种校验必须唯一对应一个回调
     */
    private inner class CheckOnAdapterCommonListenerImpl(relativeListener: OnUiRelativeListener?, val successBackTag: Int, val payTypeInfo: PayTypeInfo?)
        : OnAdapterCommonListenerImpl<NewGoodsPayCheckRes, HttpResponse<NewGoodsPayCheckRes>>(relativeListener) {

        override fun onSuccess(shopGoodsPayCheckRes: NewGoodsPayCheckRes) {
            super.onSuccess(shopGoodsPayCheckRes)
            loadingDialog?.dismiss()
            if (!shopGoodsPayCheckRes.isSuccessDialog()){
                ToastUtil.show(activity, shopGoodsPayCheckRes.orderResultDesc)
                handleServerSuccess(shopGoodsPayCheckRes.userId, successBackTag, payTypeInfo)
            }else {
                //属于VIP购买的都弹窗
                DialogUtils.showPaySuccessDialog(shopGoodsPayCheckRes, activity, object : ADismissListener<String>() {
                    override fun onImageClose() {
                        super.onImageClose()
                        handleServerSuccess(shopGoodsPayCheckRes.userId, successBackTag, payTypeInfo)
                    }
                    override fun onDirect() {
                        super.onDirect()
                        handleServerSuccess(shopGoodsPayCheckRes.userId, successBackTag, payTypeInfo)
                    }
                    override fun onLeft() {
                        super.onLeft()
                        IntentUtils.startLagouWebViewActivity(activity, shopGoodsPayCheckRes.getSuccessBtnUrl())
                        handleServerSuccess(shopGoodsPayCheckRes.userId, successBackTag, payTypeInfo)
                    }
                })
            }
        }

        override fun onError(errorBean: HttpResponse<NewGoodsPayCheckRes>) {
            super.onError(errorBean)
            loadingDialog?.dismiss()
        }

        override fun onNoInternet() {
            super.onNoInternet()
            loadingDialog?.dismiss()
        }

        override fun isShowToast(): Boolean {
            return false
        }
    }

    /***
     * 服务器确认支付成功并且兑换对应的商品成功
     */
    private inner class PaySuccessServerEnsure(val payTypeInfo: PayTypeInfo?) : Event {
        override fun call(msg: Message?) {
            msg?.let {
                var goodsBuyResponse = msg.obj as? GoodsBuyPushRes
                goodsBuyResponse?.let {
                    //5s内收到服务端支付确认消息，则不在调用校验兑换商品是否成功接口
                    loadingDialog?.setContinueLCheckPublish(false)
                    handleServerSuccess(goodsBuyResponse.pd_userId, goodsBuyResponse.paySuccessState, payTypeInfo)
                }
            }
        }
    }

    /***
     * 服务器确认支付成功并且兑换对应的商品成功
     * a 收到服务器推送
     * b 等5s没收到推送，自己调用/shop/goodsOrder/check/{orderNo}查询
     */
    private fun handleServerSuccess(userId: Int?, successBackUseTag: Int?, payTypeInfo: PayTypeInfo?) {

        activity?.let {
            if (userId?.toLong() != UserRoleManager.getInstance().userId) {
                return
            }

            //1 收到服务端支付确认消息，则关闭loading弹窗
            loadingDialog?.dismiss()

            //2 服务器确认支付消息，判断当前支付的商品类型，通过EventBus发送到各个业务方，触发后续操作
            // 和H5不一样的是，确认兑换成功后，通知使用方做后续操作（关闭页面  跳转等等）
            successBackUseTag?.let {
                OkBus.getInstance().onEvent(successBackUseTag, payTypeInfo)
            }

            //3 收到服务器消息后取消客户端支付成功后注册服务器确认支付消息事件
            OkBus.getInstance().unRegister(this)
        }
    }
}