package com.common.integrate.pay.apply

import android.text.TextUtils
import com.common.integrate.pay.PayUseScenesKey
import com.common.webview.LagouWebviewActivity
import com.lagou.annotation.apt.APayBack
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ClickInfo
import com.lagou.commonlibs.event.OkBus
import com.lagou.lagouee.observer.BEventTags
import com.lagou.pay.common.base.BasePayDelegate
import com.lagou.pay.common.bean.PayVerify

/**
 * @date 创建时间：2019-09-09
 * @author 作者：codeman
 * @Description  描述：沟通点数购买使用方回调，对于支付流程而言使用方只关注该回调
 *                    至于支付成功后具体的业务场景需要各使用方自行处理
 * @version
 */
@APayBack(
        PayUseScenesKey.BUSINESS_CHAT_POINT,
        BuyChatImpl.VIP_SCENE
        )
class BuyChatImpl(private var payDelegate: BasePayDelegate?) : BasePackCallback() {


    companion object {
        const val VIP_SCENE = (PayUseScenesKey.ProductType.PRODUCT_VIP_MEMBER
                + PayUseScenesKey.SEPARATOR + PayUseScenesKey.SceneType.SCENE_CHAT)
    }


    override fun onFlushRelevant() {
        //1 刷新当前h5页面
        val webviewActivity = payDelegate?.baseActivity as? LagouWebviewActivity
        webviewActivity?.let {
            if(webviewActivity.isActive){
                webviewActivity.mWebViewDelegate?.reload()
            }
        }
    }
    
    override fun onSuccess(verify: PayVerify) {
        payDelegate?.postSuccessDelayTask {
            OkBus.getInstance().onEvent(BEventTags.PAY_SUCCESS_COMMUNICATE_LOADING, payDelegate?.extraParams)
        }
    }

    override fun onFailure(goodsOrderNo: String?, mOrderNo: String?) {

    }

    override fun onUnknown(goodsOrderNo: String?, mOrderNo: String?) {

    }

    override fun onGetOrderNo(orderNo: String?) {

    }

    override fun onReport() {
        val clickInfo = ClickInfo()
                .setPage_id("1mxe")
                .setAddress_id("1p3c")
                .addClick_props("source_tab", sourceTab)
        AnalyticHelper.getInstance().sendClickInfo(clickInfo)
    }

    override fun getBuyButtonClickAid() = "1p3d"

    override fun isVipBuy(): Boolean {
        return if (payDelegate == null) {
            false
        } else TextUtils.equals(VIP_SCENE, payDelegate?.useScenes)
    }

}
