package com.common.integrate.qrcode

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.util.Base64
import com.common.bean.json.QrcodeResult
import com.lagou.commonlibs.utils.BitmapUtils
import com.lagou.commonlibs.utils.DeviceUtils
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import me.devilsen.czxing.code.BarcodeReader
import me.devilsen.czxing.code.CodeResult

/**
 * @date： Crate by wangjunwei on 2023/2/28
 * @description：二维码处理管理类
 **/
class QrcodeManager {

    companion object {
        /***
         * 从图片提取二维码
         */
        suspend fun identifyPictureQrcode(
            encodeBase64Code: String,
            isShowToast: Boolean?
        ): QrcodeResult? {
            var qrcodeResult: QrcodeResult? = null
            //需要做bitmap转换，比较耗时放到子线程
            withContext(Dispatchers.IO) {
                try {
                    val base64Code = Base64.decode(encodeBase64Code, Base64.DEFAULT)
                    val bitmap = BitmapUtils.roughScaleBitmap(
                        base64Code,
                        DeviceUtils.getScreenWidth(), DeviceUtils.getScreenHeight()
                    ) ?: null
                    val codeResult = identifyBitmapQrcode(bitmap)
                    qrcodeResult = QrcodeResult(codeResult, bitmap, isShowToast)
                }catch (e: Exception){
                    e.printStackTrace()
                }
            }

            return qrcodeResult
        }

        suspend fun identifyPictureQrcode(resourceId: Int, context: Context): QrcodeResult? {
            var qrcodeResult: QrcodeResult? = null
            //需要做bitmap转换，比较耗时放到子线程
            withContext(Dispatchers.IO) {
               try {
                   val bitmap = BitmapFactory.decodeResource(context.resources, resourceId) ?: null
                   val codeResult = identifyBitmapQrcode(bitmap)
                   qrcodeResult = QrcodeResult(codeResult, bitmap, false)
               }catch (e: Exception){
                   e.printStackTrace()
               }
            }
            return qrcodeResult
        }

        private fun identifyBitmapQrcode(bitmap: Bitmap?): CodeResult? {
            try {
                return BarcodeReader.getInstance().read(bitmap)
            }catch (e: Exception){
                e.printStackTrace()
            }

            return null
        }
    }
}