package com.common.integrate.wx

import android.os.Message
import com.alpha.lagouapk.ui.login.bean.OauthGetResp
import com.alpha.lagouapk.ui.login.bean.OauthStateResp
import com.common.manager.net.CommonNetManager
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.utils.LogUtils
import com.lagou.socketchannel.http.HttpResponse

/**
 * @date 创建时间：2019-11-28
 * @author 作者：codeman
 * @Description  描述：微信绑定流程基类
 *                    绑定完成后给出回调，业务方做进一步处理
 * @version
 */

abstract class BaseWxBindEvent(activity: BaseActivity?, onWxBindCallback: OnWxBindCallback<OauthGetResp>) : Event{

    protected var baseActivity: BaseActivity? = null
    protected var onWxBindCallback: OnWxBindCallback<OauthGetResp>? = null

    init {
        baseActivity = activity
        this.onWxBindCallback = onWxBindCallback
    }

    override fun call(msg: Message?) {
        val code = msg?.obj as String
        checkWxState(code)
    }

    /**
     * 1 先请求https://gate.lagou.com/v1/entry/account/oauth/settings
     *   判断微信是否绑定
     */
    private fun checkWxState(code: String) {
        CommonNetManager.getOauthSetting(object : OnAdapterCommonListenerImpl<List<OauthStateResp>, HttpResponse<List<OauthStateResp>>>(baseActivity) {
            override fun onSuccess(oauthGetResps: List<OauthStateResp>?) {
                super.onSuccess(oauthGetResps)
                sendWXCodeSuc(isBindWx(oauthGetResps), code)
            }
        })
    }

    private fun sendWXCodeSuc(isAlreadyBindWx: Boolean, code: String) {
        //1 如果已经绑定，则先解绑，再重新绑定新的微信号
        if (isAlreadyBindWx) {//已绑定
            onCurrentHasBind(code)
        } else {
            //未绑定，获取OauthGetResp，然后用该账户登录绑定
            CommonNetManager.checkWxState(code, object : OnAdapterCommonListenerImpl<OauthGetResp, HttpResponse<OauthGetResp>>(baseActivity) {
                override fun onSuccess(oauthGetResp: OauthGetResp?) {
                    super.onSuccess(oauthGetResp)
                    pureBindWx(oauthGetResp)
                }
            })
        }
    }

    fun pureBindWx(oauthGetResp: OauthGetResp?) {
        LogUtils.i("WalletWxBindEvent", " --- pureBindWx ---")
        oauthGetResp?.let {
            CommonNetManager.bindWx(oauthGetResp, object : OnAdapterCommonListenerImpl<Any, HttpResponse<Any>>(baseActivity) {
                override fun onSuccess(t: Any?) {
                    super.onSuccess(t)
                    onToBindSuccess(oauthGetResp)
                }

                override fun isCareResponse(): Boolean {
                    return false
                }
            })
        }
    }

    open fun onCurrentHasBind(code: String) {
    }

    open fun onToBindSuccess(oauthGetResp: OauthGetResp?) {
        onWxBindCallback?.onToBindSuccess(oauthGetResp)
    }

    fun isBindWx(oauthGetResps: List<OauthStateResp>?) : Boolean{
        if(oauthGetResps == null || oauthGetResps.isEmpty()){
            return false
        }
        for (oauthGetResp in oauthGetResps){
            if (oauthGetResp.isAlreadyBind){
                return true
            }
        }
        return false
    }
}
