package com.common.manager.net

import android.content.Context
import androidx.annotation.Nullable
import com.ApiService
import com.alpha.lagouapk.LagouApplication
import com.alpha.lagouapk.bean.course.DownloadEduRes
import com.alpha.lagouapk.tools.SPUtils
import com.alpha.lagouapk.ui.login.bean.OauthGetResp
import com.alpha.lagouapk.ui.login.bean.OauthStateResp
import com.common.bean.json.CommonEntryConfig
import com.common.integrate.apm.QualityManager
import com.common.integrate.oaid.OaidUtils
import com.common.manager.db.CommonDbManager
import com.common.utils.PdfUtils
import com.lagou.baselib.net.httpnetback.AdapterBaseCallBack
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.Constant
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse

/**
 * @date 创建时间：2019-11-28
 * @author 作者：codeman
 * @Description  描述：B C端共用请求接口
 * @version
 */
class CommonNetManager {

    companion object {

        /**
         * 通过code请求当前微信绑定情况
         */
        fun checkWxState(code: String,
                         listener: OnAdapterCommonListenerImpl<OauthGetResp, HttpResponse<OauthGetResp>>) {
            if (!listener.isActive) {
                return
            }
            listener.showLoading()
            ApiService.api.sendWXCode(code, Constant.OAUTH_TYPE,
                    Constant.WECHAT_APP_ID).protect().enqueue(object : AdapterBaseCallBack<OauthGetResp>(listener) {
                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<OauthGetResp>?) {
                    listener.onSuccess(response?.content)
                }
            })
        }

        /**
         * 绑定微信
         *
         * @param oauthGetResp token等值
         * @param listener
         */
        fun bindWx(@Nullable oauthGetResp: OauthGetResp, listener: OnAdapterCommonListenerImpl<Any, HttpResponse<Any>>) {
            if (!listener.isActive) {
                return
            }

            listener.showLoading()
            val oauthToken = oauthGetResp.oauthToken
            ApiService.api.bind(oauthToken, Constant.OAUTH_TYPE).protect().enqueue(object : AdapterBaseCallBack<Any>(listener) {
                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<Any>?) {
                    listener.onSuccess(response?.content)
                    ToastUtil.show(listener.baseActivity, "成功绑定：${oauthGetResp.bindedNickName}")
                }

                override fun onAdapterFail(request: HttpRequest<*>?, response: HttpResponse<Any>?) {
                    super.onAdapterFail(request, response)
                    ToastUtil.show(listener.baseActivity, "绑定失败！")
                }
            })
        }

        /**
         * 获取当前绑定状态
         */
        fun getOauthSetting(listener: OnAdapterCommonListenerImpl<List<OauthStateResp>, HttpResponse<List<OauthStateResp>>>) {

            ApiService.api.oauthState.protect().enqueue(object : AdapterBaseCallBack<List<OauthStateResp>>(listener) {

                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<List<OauthStateResp>>?) {
                    listener.onSuccess(response?.content)
                }
            })
        }

        /**
         * 引导下载教育APP
         */
        fun requestDownEduApp(listener: OnAdapterCommonListenerImpl<DownloadEduRes, HttpResponse<DownloadEduRes>>) {

            if (!listener.isActive) {
                return
            }

            ApiService.api.requestDownEduApp().enqueue(object : AdapterBaseCallBack<DownloadEduRes>(listener) {
                override fun onAdapterSuccess(request: HttpRequest<*>?, response: HttpResponse<DownloadEduRes>?) {
                    listener.onSuccess(response?.content)
                }
            })
        }

        /***
         * 通用开关配置接口
         */
        fun executeCommonConfig(context: Context) {
            ApiService.api.generalConfig.enqueue(object : BaseCallback<CommonEntryConfig>(false) {
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<CommonEntryConfig>?) {
                    ThreadUtil.io {
                        CommonDbManager.getInstance().saveCommonConfig(response?.content)
                    }
                    QualityManager.getInstance().functionsInit(response?.content, context)
                    SPUtils.isShow3xExposure = response?.content?.isShow3xExposure == true
                    //ApplicationHelper.isCheckSafe = response?.content?.isCheckSafe == true
                    PdfUtils.getInstance().initData(response?.content)
                    OaidUtils.getInstance().initData(response?.content)
                    if (response?.content?.clearImageCache?.isRealOpen == true) {
                        ImageLoadUtils.clearImageDiskCache(LagouApplication.getLagouApplication())
                    }
                }

                override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<CommonEntryConfig>?) {
                    ThreadUtil.io {
                        val config = CommonDbManager.getInstance().commonConfig
                        ThreadUtil.ui {
                            QualityManager.getInstance().functionsInit(config, context)
                            SPUtils.isShow3xExposure = config?.isShow3xExposure == true
                            //ApplicationHelper.isCheckSafe = config?.isCheckSafe == true
                            PdfUtils.getInstance().initData(config)
                            OaidUtils.getInstance().initData(config)
                        }
                    }
                }
            })
        }

        /***
         * 补丁执行情况上报
         * @param packId 补丁id
         * @param status 0 下发（更新） 1 撤销 3 激活
         */
        fun hotPatchReport(packId: Int, status: Int) {
            ApiService.api.hotPatchReport(packId, status).enqueue(object : BaseCallback<Any?>(false) {
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                }
            })
        }
    }
}