package com.common.ui

import android.text.Editable
import android.text.TextUtils
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.alpha.lagouapk.R
import com.common.CommonEventTags
import com.common.bean.json.RechargeInfoRes
import com.common.integrate.pay.PayUseScenesKey
import com.common.integrate.pay.UsePayManager
import com.common.manager.net.BCNetManager
import com.common.widget.CustomTextWatcher
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.inter.OnSingleMethodListener
import com.lagou.commonlibs.utils.text.EditDigitalFilter
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.lagouee.utils.analytic.AnalyticUtilsB
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.activity_bean_recharge.*

/**
 * @date 创建时间：2019-08-16
 * @author 作者：codeman
 * @Description  描述：勾豆充值页面
 * @version
 */

@RouterRule("lagouhr://lagou.com/bean_recharge", "lagou://lagou.com/bean_recharge")
class BeanRechargeActivity : BaseActivity() {

    private var rechargeInfo: RechargeInfoRes? = null

    private val rechargeTw = object : CustomTextWatcher() {
        override fun afterTextChanged(s: Editable?) {
            super.afterTextChanged(s)
            setRechargeBtnState(s)
        }
    }

    private val rechargeSuccessEvent = Event {
        //充值成功后，支付组件分发消息
        //it?.let { it ->
        //    LogUtils.i("BeanRechargeActivity", "充值勾豆成功 msg.obj = ", it.obj)
        //}

        /***
         * 刷新对应的webview页面
         */
        OkBus.getInstance().onEvent(CommonEventTags.FLUSH_COMMON_WEBVIEW_PAGE)
        finish()
    }

    override fun getContentLayoutId() = R.layout.activity_bean_recharge

    override fun init() {
        ltitle_bar.setLeftImgListener {
            finish()
        }
        ltitle_bar.setRightTvListener {
            //消费明细，接入h5
            rechargeInfo?.let {
                IntentUtils.startLagouWebViewActivity(mContext, rechargeInfo?.detailLink)
            }
        }
        fed_recharge_num.addTextChangedListener(rechargeTw)
        fed_recharge_num.filters = arrayOf(EditDigitalFilter(9999))
        tv_recharge_confirm.setOnClickListener {
            AnalyticUtilsB.beanRechargeClick()
            //立即充值
            UsePayManager.rechargePay(fed_recharge_num.text?.toString(), PayUseScenesKey.RECHARGE_BEAN, this)
        }

        OkBus.getInstance().register(BEventTags.PAY_SUCCESS_BEAN_USER, rechargeSuccessEvent)

        preRechargeInfo(null)
    }

    private fun preRechargeInfo(callback: OnSingleMethodListener<Any>?) {
        BCNetManager.preRecharge(object : OnAdapterCommonListenerImpl<RechargeInfoRes, HttpResponse<RechargeInfoRes>>(this) {
            override fun onSuccess(t: RechargeInfoRes?) {
                super.onSuccess(t)
                handleRechargeInfo(t)
            }

            override fun onCallBack() {
                super.onCallBack()
                callback?.onCallBack(null)
            }
        })
    }

    private fun handleRechargeInfo(t: RechargeInfoRes?) {
        t?.let {
            rechargeInfo = t
            //1 剩余勾豆
            ftv_bean_num.text = t.accountBalance.toString()
            //3 充值按钮展示文案
            tv_recharge_confirm.text = t.rechargeButtonText
            //2 值说明文案
            lin_information.visibility = View.VISIBLE
            t.information?.let {
                if (t.information.size > 0) {
                    lin_information.removeAllViews()
                    for (tip in t.information) {
                        if (TextUtils.isEmpty(tip)) {
                            continue
                        }
                        val tvInfo = TextView(mContext)
                        val params: LinearLayout.LayoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, LinearLayout.LayoutParams.WRAP_CONTENT);
                        params.topMargin = resources.getDimension(R.dimen.dp_3).toInt()
                        tvInfo.layoutParams = params
                        tvInfo.textSize = 12F
                        tvInfo.setTextColor(ContextCompat.getColor(mContext, R.color.color_999999))
                        tvInfo.text = tip
                        lin_information.addView(tvInfo)
                    }
                    return
                }

                lin_information.visibility = View.GONE
            }
        }
    }

    fun setRechargeBtnState(s: Editable?) {
        tv_recharge_confirm.isEnabled = !TextUtils.isEmpty(s)
        if (TextUtils.isEmpty(s)) {
            tv_recharge_confirm.alpha = 0.3f
        } else {
            tv_recharge_confirm.alpha = 1.0f
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        UsePayManager.onDestroy(javaClass.canonicalName)
        OkBus.getInstance().unRegister(rechargeSuccessEvent)
    }

    override fun getPageId() = "1nby"
}