package com.common.ui

import android.app.Activity
import android.content.Intent
import android.graphics.Bitmap
import android.net.Uri
import com.alpha.lagouapk.R
import com.common.utils.CommonIntentUtils
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.utils.SDCardUtils
import com.yalantis.ucrop.UCrop
import com.yalantis.ucrop.UCropFragment
import com.yalantis.ucrop.UCropFragmentCallback
import kotlinx.android.synthetic.main.activity_common_crop.*
import java.io.File

/**
 * @date： Crate by wangjunwei on 2022/8/4
 * @description：裁剪通用页面
 **/
class CommonCropActivity : BaseActivity(), UCropFragmentCallback {

    private val TAG = "CommonCropActivity"
    private var uri: Uri? = null
    private var name: String? = null

    private var fragment: UCropFragment? = null

    companion object {

        /**
         * 原始图像uri
         */
        const val KEY_ORIGINAL_IMAGE_URI = "original_image_uri"
        const val KEY_ORIGINAL_IMAGE_NAME = "original_image_name"

        /**
         * 裁剪结果返回出去
         */
        const val KEY_CROP_RESULT = "crop_result"
        fun startCropActivity(activity: BaseActivity?, originalUri: Uri?, name: String?) {
            activity?.let {
                val intent = Intent(it, CommonCropActivity::class.java)
                intent.putExtra(KEY_ORIGINAL_IMAGE_URI, originalUri)
                intent.putExtra(KEY_ORIGINAL_IMAGE_NAME, name)
                CommonIntentUtils.startActivityForResultNoException(activity, intent, UCrop.REQUEST_CROP)
            }
        }
    }

    override fun getContentLayoutId() = R.layout.activity_common_crop

    override fun init() {
        uri = intent?.getParcelableExtra(KEY_ORIGINAL_IMAGE_URI)
        name = intent?.getStringExtra(KEY_ORIGINAL_IMAGE_NAME)

        uri?.let {
            var uCrop = UCrop.of(it, Uri.fromFile(File(SDCardUtils.getInternalStorageImageDir(this).path, name)))
            uCrop = uCrop.withAspectRatio(1f, 1f)
            val options = UCrop.Options()
            options.setCompressionFormat(Bitmap.CompressFormat.PNG)
            options.setHideBottomControls(true)
            options.setFreeStyleCropEnabled(false)
            options.setCompressionQuality(80)
            options.setCropGridColumnCount(0)
            options.setCropGridRowCount(0)
            uCrop = uCrop.withOptions(options)
            setupFragment(uCrop)
        }
        initListener()
    }

    private fun initListener() {
        tv_select.setOnClickListener {
            //选取裁剪好的图像
            fragment?.cropAndSaveImage()
        }
        ltitle_bar.setLeftImgListener {
            finish()
        }
    }

    private fun setupFragment(uCrop: UCrop) {
        fragment = uCrop.getFragment(uCrop.getIntent(this).extras)
        fragment?.let {
            supportFragmentManager.beginTransaction().add(R.id.frame_container, it)
                .commitAllowingStateLoss()
        }
    }

    override fun loadingProgress(p0: Boolean) {

    }

    override fun onCropFinish(result: UCropFragment.UCropResult?) {
        when (result?.mResultCode) {
            RESULT_OK -> handleCropResult(result.mResultData)
            UCrop.RESULT_ERROR -> handleCropError(result.mResultData)
        }
    }

    private fun handleCropError(mResultData: Intent?) {
        //图片裁剪出现错误
    }

    private fun handleCropResult(mResultData: Intent?) {
        mResultData?.let {
            val resultUri = UCrop.getOutput(mResultData)
            val intent = Intent()
            intent.putExtra(KEY_CROP_RESULT, resultUri)
            setResult(Activity.RESULT_OK , intent)
            finish()
        }
    }

}