package com.common.ui.adapter

import android.annotation.SuppressLint
import android.app.Activity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.IntentUtils
import com.common.adapter.BaseRecycleAdapter
import com.common.adapter.BaseViewHolder
import com.common.adapter.listener.OnItemClick
import com.common.bean.RightsSetBean
import com.common.manager.RightsManager
import com.lagou.commonlibs.privacy.PrivacyPermissionKey
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ToastUtil

/**
 * @author 作者：codeman
 * @date 创建时间：6/2/21 20:12
 * @Description 描述：隐私权限设置适配器
 */
class RightsSetAdapter(activity: Activity) : BaseRecycleAdapter<RightsSetBean, RightsSetAdapter.RightsViewHolder>(activity) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        val itemView = LayoutInflater.from(mActivity).inflate(R.layout.adapter_right_set, parent,false)
        val holder:RightsViewHolder = RightsViewHolder(itemView)
        holder.itemView.setOnClickListener {
            val adapterPosition = holder.adapterPosition
            if (ListUtil.isListIndexLegal(mList,adapterPosition)){
                onItemClick(mList[adapterPosition])
            }
        }
        return holder
    }

    @SuppressLint("WrongConstant")
    private fun onItemClick(rightsSetBean: RightsSetBean?){
        rightsSetBean?.let {
            when(it.systemRightsKey){
                //打开相机设置
                PrivacyPermissionKey.CAMERA -> IntentUtils.startCameraSceneRightsActivity(mActivity,it.systemRightsKey)
                PrivacyPermissionKey.EXTERNAL_STORAGE -> IntentUtils.startCameraSceneRightsActivity(mActivity,it.systemRightsKey)
                PrivacyPermissionKey.RECORD_AUDIO -> IntentUtils.startCameraSceneRightsActivity(mActivity,it.systemRightsKey)
                PrivacyPermissionKey.MANAGE_OVERLAY_PERMISSION ->IntentUtils.startSettingDetail(mActivity)
                PrivacyPermissionKey.INSTALL -> IntentUtils.startSettingDetail(mActivity)
            }
        }
    }

    class RightsViewHolder(itemView: View) : BaseViewHolder<RightsSetBean>(itemView){

        var rightContent: TextView? = itemView.findViewById(R.id.tv_right_content)
        var rightState: TextView? = itemView.findViewById(R.id.tv_right_state)
        var rightSubContent:TextView? = itemView.findViewById(R.id.tv_right_sub_content)

        override fun onBindViewHolder(view: View?, rightsSetBean: RightsSetBean?, position: Int, onItemClick: OnItemClick<*>?) {
            rightsSetBean?.apply {
                rightContent?.text = title
                rightSubContent?.visibility = if (this.content.isNullOrEmpty()) View.GONE else View.VISIBLE
                rightSubContent?.text = this.content
                rightState?.text = showStateTxt()
                rightState?.setTextColor(showStateColor)
            }
        }

        override fun getTitle() = "隐私权限设置ViewHolder"
    }
}