package com.common.ui.collect

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.common.adapter.listener.OnItemClick
import com.common.bean.CollectManifestBean
import com.common.utils.ViewUtils
import com.lagou.commonlibs.utils.ResourceUtils

class CollectInfoAdapter(private val context: Context): RecyclerView.Adapter<CollectInfoAdapter.CollectInfoViewHolder>() {
    private var mData:List<CollectManifestBean>? = null
    fun setData(data:List<CollectManifestBean>?){
        this.mData = data
        notifyDataSetChanged()
    }
    override fun onCreateViewHolder(p0: ViewGroup, p1: Int): CollectInfoViewHolder {
        return CollectInfoViewHolder(LayoutInflater.from(context).inflate(R.layout.item_collect_user_info,p0,false))
    }

    override fun onBindViewHolder(viewHolder: CollectInfoViewHolder, position: Int) {
        val collectBean = mData?.get(position)
        collectBean?.let {bean ->
            viewHolder.tvCollectModuleTitle.text = bean.collectModule
            viewHolder.tvCollectPurposeContent.text = bean.collectPurpose
            viewHolder.tvCollectSceneContent.text = bean.collectScene
            viewHolder.tvCollectStateContent.text = bean.collectState
            if (bean.collectDetail.isNullOrEmpty()){
                ViewUtils.setViewGone(viewHolder.tvCollectDetailTitle,viewHolder.tvCollectDetailContent)
            }else{
                ViewUtils.setViewVisibility(viewHolder.tvCollectDetailTitle,viewHolder.tvCollectDetailContent)
                viewHolder.tvCollectDetailContent.text = bean.collectDetail
            }
            viewHolder.tvCollectContent.text = bean.collectLink
            if (bean.collectLink == SEE_COLLECT_DETAIL){
                //查看详情，可跳转到下一步
                viewHolder.ivCollectContentIndicator.visibility = View.VISIBLE
                viewHolder.tvCollectContent.setTextColor(ResourceUtils.getColor(R.color.color_00b38a))
                ViewUtils.setViewsClick(View.OnClickListener {
                    //查看详情
                    mItemClickListener?.onClick(bean,position)
                },viewHolder.ivCollectContentIndicator,viewHolder.tvCollectContent)
            }else{
                viewHolder.ivCollectContentIndicator.visibility = View.GONE
                viewHolder.tvCollectContent.setTextColor(ResourceUtils.getColor(R.color.color_666666))
            }
        }


    }

    private var mItemClickListener:OnItemClick<CollectManifestBean>? = null
    fun setOnItemClickListener(onItemClick:OnItemClick<CollectManifestBean>?){
        this.mItemClickListener = onItemClick
    }
    override fun getItemCount() = mData?.size ?: 0

    class CollectInfoViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView){
        val tvCollectModuleTitle:TextView = itemView.findViewById(R.id.tvCollectModuleTitle)
        val tvCollectPurposeContent:TextView = itemView.findViewById(R.id.tvCollectPurposeContent)
        val tvCollectSceneContent:TextView = itemView.findViewById(R.id.tvCollectSceneContent)
        val tvCollectStateContent:TextView = itemView.findViewById(R.id.tvCollectStateContent)
        val tvCollectDetailTitle:TextView = itemView.findViewById(R.id.tvCollectDetailTitle)
        val tvCollectDetailContent:TextView = itemView.findViewById(R.id.tvCollectDetailContent)
        val tvCollectContent:TextView = itemView.findViewById(R.id.tvCollectContent)
        val ivCollectContentIndicator:ImageView = itemView.findViewById(R.id.ivCollectContentIndicator)
    }
}