package com.common.ui.collect

import androidx.lifecycle.ViewModel
import com.ApiService
import com.alpha.lagouapk.UserRoleManager
import com.alpha.lagouapk.ui.login.bean.LoginUserinfoB
import com.alpha.lagouapk.ui.login.bean.LoginUserinfoC
import com.common.bean.CollectManifestBean
import com.common.bean.InformationCollectBean
import com.common.bean.InformationCollectItemBean
import com.common.integrate.oaid.OaidUtils
import com.common.inter.Callback
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.utils.DeviceUtils
import com.lagou.lagouee.bean.UserInfoBean
import com.lagou.lagouee.manager.net.MineNetManager
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow
import kotlinx.coroutines.flow.flowOn

class UserInfoCollectViewModel:ViewModel() {
    /**
     * 顶部标题
     */
    fun getTitle(collectType:Int):String{
        var centerTxt = when(collectType){
            UserInfoManifestDetailActivity.BASE_INFO -> COLLECT_BASE_INFO_TITLE
            UserInfoManifestDetailActivity.IDENTITY_INFO -> COLLECT_IDENTITY_TITLE
            UserInfoManifestDetailActivity.USE_INFO -> COLLECT_USE_INFO_TITLE
            UserInfoManifestDetailActivity.DEVICE_INFO -> COLLECT_DEVICE_INFO_TITLE
            else -> ""
        }
        return centerTxt
    }

    /**
     * 不同模块收集到的不同信息数据
     * @param collectType
     * @param serverCollectInfoList
     */
    private fun getCollectInfoData(collectType: Int,serverCollectInfoMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val isC = UserRoleManager.getInstance().isCUser
        return when(collectType){
            UserInfoManifestDetailActivity.BASE_INFO ->  if (isC) getCBaseInfoCollect(serverCollectInfoMap) else  getBBaseInfoCollect()
            UserInfoManifestDetailActivity.IDENTITY_INFO -> if (isC) emptyList() else  getBUserIdentityInfoCollect(serverCollectInfoMap)
            UserInfoManifestDetailActivity.USE_INFO -> if (isC) getCUseInfoCollect(serverCollectInfoMap) else getBUseInfoCollect(serverCollectInfoMap)
            UserInfoManifestDetailActivity.DEVICE_INFO -> getDeviceInfoCollect(serverCollectInfoMap)
            else -> emptyList()
        }
    }

    /**
     * 获取设备信息
     */
    private fun getDeviceInfoCollect(serverCollectMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val deviceInfoList = mutableListOf<CollectManifestBean>()
        val oaid:String? = OaidUtils.getInstance().oaid
        val oaidState = if (oaid.isNullOrEmpty()) HAD_NOT_COLLECT else HAD_COLLECT
        val oaidDetail = if (oaid.isNullOrEmpty()) NO_COLLECT_DETAIL else oaid
        val oaidInfo = CollectManifestBean(collectModule = BC_DEVICE_OAID_NAME, collectPurpose = BC_DEVICE_OAID_PURPOSE,
            collectScene = BC_DEVICE_SCENE, collectState = oaidState, collectLink = oaidDetail )

        val osInfo = CollectManifestBean(collectModule = BC_DEVICE_OS_NAME, collectPurpose = BC_DEVICE_PURPOSE,
            collectScene = BC_DEVICE_SCENE, collectState = HAD_COLLECT, collectLink = "android" )

        val osVersion:String? = DeviceUtils.getOsReleaseVersion()
        val osVersionState = if (osVersion.isNullOrEmpty()) HAD_NOT_COLLECT else HAD_COLLECT
        val osVersionDetail = if (osVersion.isNullOrEmpty()) NO_COLLECT_DETAIL else osVersion
        val osVersionInfo = CollectManifestBean(collectModule = BC_DEVICE_OS_VERSION_NAME, collectPurpose = BC_DEVICE_PURPOSE,
            collectScene = BC_DEVICE_SCENE, collectState = osVersionState, collectLink = osVersionDetail )

        val deviceStyle:String? = DeviceUtils.getDeviceModel()
        val deviceStyleState = if (deviceStyle.isNullOrEmpty()) HAD_NOT_COLLECT else HAD_COLLECT
        val deviceStyleDetail = if (deviceStyle.isNullOrEmpty()) NO_COLLECT_DETAIL else deviceStyle
        val deviceStyleInfo = CollectManifestBean(collectModule = BC_DEVICE_STYLE_NAME, collectPurpose = BC_DEVICE_PURPOSE,
            collectScene = BC_DEVICE_SCENE, collectState = deviceStyleState, collectLink = deviceStyleDetail )

        val serverIpInfo:InformationCollectItemBean? = serverCollectMap?.get(USER_IP_ADDRESS)
        val ipState:String = getCollectState(serverIpInfo)
        val ipDetail:String = if (ipState == HAD_NOT_COLLECT) NO_COLLECT_DETAIL else (serverIpInfo?.content ?: NO_COLLECT_DETAIL)
        val ipInfo = CollectManifestBean(collectModule = BC_DEVICE_IP_NAME,collectModuleKey = USER_IP_ADDRESS, collectPurpose = BC_DEVICE_OAID_PURPOSE,
            collectScene = BC_DEVICE_SCENE, collectState = ipState, collectLink = ipDetail )
        deviceInfoList.add(oaidInfo)
        deviceInfoList.add(osInfo)
        deviceInfoList.add(osVersionInfo)
        deviceInfoList.add(deviceStyleInfo)
        deviceInfoList.add(ipInfo)
        return deviceInfoList
    }

    /**
     * B端使用过程信息
     */
    private fun getBUseInfoCollect(serverCollectMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val useList = mutableListOf<CollectManifestBean>()
        val serverTradeInfo:InformationCollectItemBean? = serverCollectMap?.get(B_TRADE_RECORD)
        val businessTradeInfo = CollectManifestBean(collectModule = B_USE_TRADE_NAME, collectModuleKey = B_TRADE_RECORD, collectPurpose = B_USE_TRADE_PURPOSE,
            collectScene = B_USE_TRADE_SCENE, collectState = getCollectState(serverTradeInfo), collectLink = getCollectDetail(serverTradeInfo) )

        val serverCollectResumeInfo:InformationCollectItemBean? = serverCollectMap?.get(B_RESUME_COLLECTION)
        val collectResumeInfo = CollectManifestBean(collectModule = B_USE_COLLECT_RESUME_NAME, collectModuleKey = B_RESUME_COLLECTION, collectPurpose = B_USE_COLLECT_RESUME_PURPOSE,
            collectScene = B_USE_COLLECT_RESUME_SCENE, collectState = getCollectState(serverCollectResumeInfo), collectLink = getCollectDetail(serverCollectResumeInfo) )

        val serverVerMaterialInfo:InformationCollectItemBean? = serverCollectMap?.get(B_AUTH_FILE)
        val verMaterialInfo = CollectManifestBean(collectModule = B_USE_VER_MATERIAL_NAME, collectModuleKey = B_AUTH_FILE, collectPurpose = B_USE_VER_MATERIAL_PURPOSE,
            collectScene = B_USE_VER_MATERIAL_SCENE, collectState = getCollectState(serverVerMaterialInfo), collectLink = NO_COLLECT_DETAIL )

        val runAppsInfo = CollectManifestBean(collectModule = BC_USE_RUN_APPS_NAME, collectPurpose = BC_USE_RUN_APPS_PURPOSE,
            collectScene = BC_USE_RUN_APPS_SCENE, collectState = HAD_COLLECT, collectLink = NO_COLLECT_DETAIL )
        useList.add(businessTradeInfo)
        useList.add(collectResumeInfo)
        useList.add(verMaterialInfo)
        useList.add(runAppsInfo)
        return useList
    }

    /**
     * C端使用过程信息
     */
    private fun getCUseInfoCollect(serverCollectMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val useList = mutableListOf<CollectManifestBean>()
        val serverTradeInfo:InformationCollectItemBean? = serverCollectMap?.get(C_TRADE_RECORD)
        val businessTradeInfo = CollectManifestBean(collectModule = C_USE_TRADE_NAME, collectModuleKey = C_TRADE_RECORD, collectPurpose = C_USE_TRADE_PURPOSE,
            collectScene = C_USE_TRADE_SCENE, collectState = getCollectState(serverTradeInfo), collectLink = getCollectDetail(serverTradeInfo) )

        val serverCollectPositionInfo:InformationCollectItemBean? = serverCollectMap?.get(C_POSITION_COLLECTION)
        val collectPositionInfo = CollectManifestBean(collectModule = C_USE_COLLECT_POSITION_NAME, collectModuleKey = C_POSITION_COLLECTION, collectPurpose = C_USE_COLLECT_POSITION_PURPOSE,
            collectScene = C_USE_COLLECT_POSITION_SCENE, collectState = getCollectState(serverCollectPositionInfo), collectLink = getCollectDetail(serverCollectPositionInfo) )

        val serverAttentionCompanyInfo:InformationCollectItemBean? = serverCollectMap?.get(C_COMPANY_ATTENTION)
        val attentionCompanyInfo = CollectManifestBean(collectModule = C_USE_ATTENTION_COMPANY_NAME, collectModuleKey = C_COMPANY_ATTENTION, collectPurpose = C_USE_ATTENTION_COMPANY_PURPOSE,
            collectScene = C_USE_ATTENTION_COMPANY_SCENE, collectState = getCollectState(serverAttentionCompanyInfo), collectLink = getCollectDetail(serverAttentionCompanyInfo) )

        val runAppsInfo = CollectManifestBean(collectModule = BC_USE_RUN_APPS_NAME, collectPurpose = BC_USE_RUN_APPS_PURPOSE,
            collectScene = BC_USE_RUN_APPS_SCENE, collectState = HAD_COLLECT, collectLink = NO_COLLECT_DETAIL )
        useList.add(businessTradeInfo)
        useList.add(collectPositionInfo)
        useList.add(attentionCompanyInfo)
        useList.add(runAppsInfo)
        return useList
    }

    /**
     * B端身份信息
     */
    private fun getBUserIdentityInfoCollect(serverCollectMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val identityList = mutableListOf<CollectManifestBean>()
        val serverIdentity:InformationCollectItemBean? = serverCollectMap?.get(B_ID_CARD_NUMBER)
        val identityState:String = getCollectState(serverIdentity)
        val identityDetail:String = if (identityState == HAD_NOT_COLLECT) NO_COLLECT_DETAIL else (serverIdentity?.content ?: NO_COLLECT_DETAIL)
        val identityInfo = CollectManifestBean(collectModule = B_IDENTITY_ID_NAME, collectModuleKey = B_ID_CARD_NUMBER, collectPurpose = VER_IDENTITY,
            collectScene = VER_IDENTITY_SCENE, collectState = identityState, collectLink = identityDetail)

        val serverUserName:InformationCollectItemBean? = serverCollectMap?.get(B_REAL_NAME)
        val userNameState:String = getCollectState(serverUserName)
        val userNameDetail:String = if (userNameState == HAD_NOT_COLLECT) NO_COLLECT_DETAIL else (serverUserName?.content ?: NO_COLLECT_DETAIL)
        val userNameInfo = CollectManifestBean(collectModule = B_IDENTITY_USER_NAME, collectModuleKey = B_REAL_NAME, collectPurpose = VER_IDENTITY,
            collectScene = VER_IDENTITY_SCENE, collectState = userNameState, collectLink = userNameDetail )
        identityList.add(identityInfo)
        identityList.add(userNameInfo)
        return identityList
    }

    /**
     * B端基本信息收集
     */
    private fun getBBaseInfoCollect(): List<CollectManifestBean> {
        val baseInfoCollectList = mutableListOf<CollectManifestBean>()
        val accountInfo = CollectManifestBean(collectModule = B_BASE_ACCOUNT_NAME,collectModuleKey = B_ACCOUNT,
            collectPurpose = B_BASE_ACCOUNT_PURPOSE,collectScene = B_BASE_ACCOUNT_SCENE, collectState = HAD_COLLECT,
            collectDetail = B_BASE_ACCOUNT_DETAIL, collectLink = SEE_COLLECT_DETAIL)

        val personalInfo = CollectManifestBean(collectModule = B_BASE_PERSONAL_NAME,collectModuleKey = B_PERSONAL_INFO,
            collectPurpose = B_BASE_PERSONAL_PURPOSE,collectScene = B_BASE_PERSONAL_SCENE, collectState = HAD_COLLECT,
            collectDetail = B_BASE_PERSONAL_DETAIL, collectLink = SEE_COLLECT_DETAIL)
        baseInfoCollectList.add(accountInfo)
        baseInfoCollectList.add(personalInfo)
        return baseInfoCollectList
    }

    /**
     * C端基本信息收集
     */
    private fun getCBaseInfoCollect(serverCollectMap:MutableMap<String,InformationCollectItemBean>?): List<CollectManifestBean> {
        val baseInfoCollectList = mutableListOf<CollectManifestBean>()
        val personalInfo  = CollectManifestBean(collectModule = C_BASE_PERSONAL_NAME,collectModuleKey = C_PERSONAL_INFO,
            collectPurpose = C_BASE_PERSONA_PURPOSE,collectScene = C_BASE_PERSONA_SCENE, collectState = HAD_COLLECT,
            collectDetail = C_BASE_PERSONA_DETAIL, collectLink = SEE_COLLECT_DETAIL)
        val serverExpectInfo:InformationCollectItemBean? = serverCollectMap?.get(C_EXPECT_JOB)
        val expectInfo  = CollectManifestBean(collectModule = C_BASE_EXPECT_NAME,collectModuleKey = C_EXPECT_JOB,
            collectPurpose = C_BASE_EXPECT_PURPOSE,collectScene = C_BASE_EXPECT_SCENE, collectState = getCollectState(serverExpectInfo), collectLink = getCollectDetail(serverExpectInfo))

        val serverAdvantage:InformationCollectItemBean? = serverCollectMap?.get(C_SELF_DESCRIPTION)
        val advantageInfo  = CollectManifestBean(collectModule = C_BASE_ADVANTAGE_NAME,collectModuleKey = C_SELF_DESCRIPTION,
            collectPurpose = C_BASE_ADVANTAGE_PURPOSE,collectScene = C_BASE_ADVANTAGE_SCENE, collectState = getCollectState(serverAdvantage), collectLink = getCollectDetail(serverAdvantage))

        val serverWork:InformationCollectItemBean? = serverCollectMap?.get(C_WORK_EXPERIENCE)
        val workInfo  = CollectManifestBean(collectModule = C_BASE_WORK_NAME,collectModuleKey = C_WORK_EXPERIENCE,
            collectPurpose = C_BASE_WORK_PURPOSE,collectScene = C_BASE_WORK_SCENE, collectDetail = C_BASE_WORK_DETAIL, collectState = getCollectState(serverWork), collectLink = getCollectDetail(serverWork))

        val serverEdu:InformationCollectItemBean? = serverCollectMap?.get(C_EDUCATION_EXPERIENCE)
        val eduInfo  = CollectManifestBean(collectModule = C_BASE_EDU_NAME,collectModuleKey = C_EDUCATION_EXPERIENCE,
            collectPurpose = C_BASE_EDU_PURPOSE,collectScene = C_BASE_EDU_SCENE, collectState = getCollectState(serverEdu), collectLink = getCollectDetail(serverEdu))

        val serverSocial:InformationCollectItemBean? = serverCollectMap?.get(C_SOCIAL_ACCOUNT)
        val socialInfo  = CollectManifestBean(collectModule = C_BASE_SOCIAL_NAME,collectModuleKey = C_SOCIAL_ACCOUNT,
            collectPurpose = C_BASE_SOCIAL_PURPOSE,collectScene = C_BASE_SOCIAL_SCENE, collectState = getCollectState(serverSocial), collectLink = getCollectDetail(serverSocial))

        val serverAttach:InformationCollectItemBean? = serverCollectMap?.get(C_NEAR_BY)
        val attachResumeInfo  = CollectManifestBean(collectModule = C_BASE_ATTACH_NAME,collectModuleKey = C_NEAR_BY,
            collectPurpose = C_BASE_ATTACH_PURPOSE,collectScene = C_BASE_ATTACH_SCENE, collectState = getCollectState(serverAttach), collectLink = getCollectDetail(serverAttach))

        val serverPhotoWorks:InformationCollectItemBean? = serverCollectMap?.get(C_PICTURE_WORKS)
        val photoWorksInfo  = CollectManifestBean(collectModule = C_BASE_PHOTO_WORKS_NAME,collectModuleKey = C_PICTURE_WORKS,
            collectPurpose = C_BASE_PHOTO_WORKS_PURPOSE,collectScene = C_BASE_PHOTO_WORKS_SCENE, collectState = getCollectState(serverPhotoWorks), collectLink = getCollectDetail(serverPhotoWorks))

        val serverAccount:InformationCollectItemBean? = serverCollectMap?.get(C_ACCOUNT)
        val accountInfo  = CollectManifestBean(collectModule = C_BASE_ACCOUNT_NAME,collectModuleKey = C_ACCOUNT,
            collectPurpose = C_BASE_ACCOUNT_PURPOSE,collectScene = C_BASE_ACCOUNT_SCENE, collectState = getCollectState(serverAccount), collectLink = getCollectDetail(serverAccount))

        val serverHomeAddress:InformationCollectItemBean? = serverCollectMap?.get(C_USER_LOCATION)
        val addressInfo  = CollectManifestBean(collectModule = C_BASE_ADDRESS_NAME,collectModuleKey = C_USER_LOCATION,
            collectPurpose = C_BASE_ADDRESS_PURPOSE,collectScene = C_BASE_ADDRESS_SCENE, collectState = getCollectState(serverHomeAddress), collectLink = NO_COLLECT_DETAIL)
        baseInfoCollectList.add(personalInfo)
        baseInfoCollectList.add(expectInfo)
        baseInfoCollectList.add(advantageInfo)
        baseInfoCollectList.add(workInfo)
        baseInfoCollectList.add(eduInfo)
        baseInfoCollectList.add(socialInfo)
        baseInfoCollectList.add(attachResumeInfo)
        baseInfoCollectList.add(photoWorksInfo)
        baseInfoCollectList.add(accountInfo)
        baseInfoCollectList.add(addressInfo)
        return baseInfoCollectList
    }

    private fun getCollectState(bean:InformationCollectItemBean?):String{
        return if(bean?.collect == true){
            if (bean.num > 0){
                HAD_COLLECT + "${bean.num}条"
            }else{
                HAD_COLLECT
            }
        }else{
            HAD_NOT_COLLECT
        }
    }

    private fun getCollectDetail(bean:InformationCollectItemBean?):String{
        return if(bean?.collect == true) SEE_COLLECT_DETAIL else NO_COLLECT_DETAIL
    }


    fun getBUserInfo():Flow<UserInfoBean> {
        return flow<UserInfoBean> {
            val userData = MineNetManager.getCacheUserData()
            val userInfoBean : UserInfoBean = UserInfoBean()
            userData?.let {
                userInfoBean.setmMineIcon(it.userHeadUrl)
                userInfoBean.setmMineName(it.username)
                userInfoBean.setmMineMail(it.userEmail)
                userInfoBean.setmPositionName(it.userTitle)
                userInfoBean.setmMineCompanyFull(it.companyFullName)
                userInfoBean.hunterExplain = it.hunterExplain
                userInfoBean.wechat = it.wechat
            }
            emit(userInfoBean)
        }.flowOn(Dispatchers.IO)
    }

    /**
     * 从服务端获取收集信息
     */
    fun getCollectionInfoFromServer(collectType:Int,callback:Callback<List<CollectManifestBean>>){
        val isC = UserRoleManager.getInstance().isCUser
        val type:String = when(collectType){
            UserInfoManifestDetailActivity.BASE_INFO -> if(isC) C_USER_BASE else B_USER_BASE
            UserInfoManifestDetailActivity.USE_INFO -> if (isC) C_USER_USE_PROCESS else B_USER_USE_PROCESS
            UserInfoManifestDetailActivity.IDENTITY_INFO -> B_USER_IDENTITY //C端没有身份信息
            UserInfoManifestDetailActivity.DEVICE_INFO -> USER_EQUIPMENT
            else -> ""
        }
        ApiService.api.fetchInformationCollect(type).enqueue(object:
            BaseCallback<InformationCollectBean>(){
            override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<InformationCollectBean>?) {
                val bean: InformationCollectBean? = response?.content
                if (bean == null || bean.list.isNullOrEmpty()){
                    callback.onCallback(null)
                    return
                }
                var map = mutableMapOf<String,InformationCollectItemBean>()
                bean.list.forEach insde@{
                    if (it.key.isNullOrEmpty()){
                        return@insde
                    }
                    map[it.key] = it
                }
                callback.onCallback(getCollectInfoData(collectType,map))
            }

            override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<InformationCollectBean>?) {
                super.onFailure(request, response)
                callback.onCallback(null)
            }

        })
    }

    /**
     * 获取注册时间
     */
    fun getRegisterTime(callback: (registerTime: String?) -> Unit){
        val isC = UserRoleManager.getInstance().isCUser
        if (isC){
            ApiService.api.fetchUserinfoC().enqueue(object:BaseCallback<LoginUserinfoC>(false){
                override fun onSuccess(p0: HttpRequest<*>?, response: HttpResponse<LoginUserinfoC>?) {
                    val registerTime =  response?.content?.registerTime
                    callback.invoke(registerTime)
                }
            })
        }else{
            ApiService.api.fetchUserinfoB().enqueue(object:BaseCallback<LoginUserinfoB>(false){
                override fun onSuccess(p0: HttpRequest<*>?, response: HttpResponse<LoginUserinfoB>?) {
                    val registerTime =  response?.content?.registerTime
                    callback.invoke(registerTime)
                }
            })
        }

    }


}