package com.common.ui.collect

import android.content.Intent
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.lifecycleScope
import com.alpha.lagouapk.R
import com.alpha.lagouapk.manager.ResumeManager
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.ui.user.MineAttentedCompanyActivity
import com.alpha.lagouapk.ui.user.collection.CollectionActivity
import com.alpha.lagouapk.widget.decoration.DividerItemDecoration
import com.common.adapter.listener.OnItemClick
import com.common.bean.CollectManifestBean
import com.common.inter.Callback
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.resume.ResumeState
import kotlinx.android.synthetic.main.activity_userinfo_manifest_detail.*
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch

/**
 * 个人信息收集清单落地页
 */
class UserInfoManifestDetailActivity:BaseActivity(),OnItemClick<CollectManifestBean> {
    companion object{
        const val BASE_INFO = 1//包括基本信息
        const val IDENTITY_INFO = 2//身份信息
        const val USE_INFO = 3//使用过程信息
        const val DEVICE_INFO = 4 //设备信息
        const val KEY_COLLECT_INFO = "key_collect_info"
    }
    private  var mCollectInfoType = BASE_INFO
    private lateinit var userInfoViewModel:UserInfoCollectViewModel
    private lateinit var mAdapter:CollectInfoAdapter
    override fun getContentLayoutId() = R.layout.activity_userinfo_manifest_detail
    override fun init() {
        userInfoViewModel = ViewModelProvider(this)[UserInfoCollectViewModel::class.java]
        mCollectInfoType = intent.getIntExtra(KEY_COLLECT_INFO, BASE_INFO)
        titleBar.setCenterTvTxt(userInfoViewModel.getTitle(mCollectInfoType))
        rvInfoList.apply {
            addItemDecoration(
                DividerItemDecoration(this@UserInfoManifestDetailActivity,
                    DividerItemDecoration.HORIZONTAL_LIST, ResourceUtils.getDimenSize(R.dimen.dp_05),
                    ResourceUtils.getColor(R.color.color_e8e9eb))
            )
            mAdapter = CollectInfoAdapter(this@UserInfoManifestDetailActivity)
            mAdapter.setOnItemClickListener(this@UserInfoManifestDetailActivity)
            adapter = mAdapter
        }
        titleBar.setLeftImgListener { finish() }
        showLoading()
        userInfoViewModel.getCollectionInfoFromServer(mCollectInfoType,object:Callback<List<CollectManifestBean>>{
            override fun onCallback(data: List<CollectManifestBean>?) {
                if (isActivityDestroyed){
                    return
                }
                hideLoading()
                mAdapter.setData(data)
            }

        })
    }

    override fun onClick(collectBean: CollectManifestBean?, position: Int) {
        when(collectBean?.collectModuleKey){
            //C端
            C_PERSONAL_INFO -> {
                //hasWorkExperience -1：默认值，1：已有工作经历，0：尚无工作经历
                val experienceBeanList = ResumeManager.getInstance().resumeBean.workExperiences
                val hasWorkExperience = if ((experienceBeanList?.size ?: -1)  > 0) 1 else 0
                IntentUtils.startResumeEditSelfInfo(this,ResumeManager.getInstance().resumeBean.baseInfo, hasWorkExperience, "")
            }
            C_EXPECT_JOB -> IntentUtils.startMultiExpectJobActivity(this)
            C_SELF_DESCRIPTION,C_WORK_EXPERIENCE,C_EDUCATION_EXPERIENCE,C_SOCIAL_ACCOUNT,C_PICTURE_WORKS -> IntentUtils.startResumeEditActivity(this)
            C_NEAR_BY -> IntentUtils.startAttachmentResumeListActivity(this)
            C_ACCOUNT -> IntentUtils.startMineAccount(this)
            C_TRADE_RECORD -> IntentUtils.startLagouWebViewActivityHideTitle(this,BUSINESS_TRADE_DETAIL_URL)
            C_POSITION_COLLECTION -> IntentUtils.startActivityNoException(this, Intent(this, CollectionActivity::class.java))
            C_COMPANY_ATTENTION -> IntentUtils.startActivityNoException(this, Intent(this, MineAttentedCompanyActivity::class.java))
            //B端
            B_ACCOUNT -> IntentUtils.startMineAccount(this)
            B_PERSONAL_INFO -> {
                lifecycleScope.launch {
                    userInfoViewModel.getBUserInfo().collectLatest {
                        com.lagou.lagouee.utils.IntentUtils.startMyInformationActivity(this@UserInfoManifestDetailActivity,it)
                    }
                }
            }
            B_TRADE_RECORD -> IntentUtils.startLagouWebViewActivityHideTitle(this,BUSINESS_TRADE_DETAIL_URL)
            B_RESUME_COLLECTION -> com.lagou.lagouee.utils.IntentUtils.startCVProgressActivity(this, ResumeState.STATE_RESUME_COLLECT, ResourceUtils.getString(R.string.my_collect))
        }
    }
}