package com.common.ui.collect

import android.content.Intent
import android.view.View
import androidx.lifecycle.ViewModelProvider
import com.alpha.lagouapk.R
import com.alpha.lagouapk.UserRoleManager
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.tools.config.MessageConfig
import com.alpha.lagouapk.ui.resume.preview.PreviewActivity
import com.alpha.lagouapk.ui.user.MineAttentedCompanyActivity
import com.alpha.lagouapk.ui.user.collection.CollectionActivity
import com.common.ui.collect.DeviceAppInfoActivity.Companion.TYPE_DEVICE_INFO
import com.common.ui.collect.DeviceAppInfoActivity.Companion.TYPE_OTHER_INFO
import com.common.utils.ViewUtils
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.resume.ResumeState
import com.lagou.lagouee.utils.IntentUtils.startCVProgressActivity
import kotlinx.android.synthetic.main.activity_user_info_manifest_export.*

/**
 * 个人信息查阅和导出
 */
class UserInfoManifestExportActivity:BaseActivity(),View.OnClickListener {
    private lateinit var userInfoViewModel:UserInfoCollectViewModel
    override fun getContentLayoutId() = R.layout.activity_user_info_manifest_export

    override fun init() {
        userInfoViewModel = ViewModelProvider(this)[UserInfoCollectViewModel::class.java]
        setUiByBC()
        setRegisterTime()
        ViewUtils.setViewsClick(this,liPersonalMaterial,liAccountSafe,liDeliverRecord,liCollectRecord,
            liAttentionRecord,liConsumeRecord,liRechargeRecord,liDeviceInfo,llOtherInfo)
        userInfoExportTitleBar.setLeftImgListener { finish() }
    }

    private fun setUiByBC() {
        val isC = UserRoleManager.getInstance().isCUser
        if (isC){
            liPersonalMaterial.visibility = View.VISIBLE
            liDeliverRecord.visibility = View.VISIBLE
            liAttentionRecord.visibility = View.VISIBLE
            liCollectRecord.setShowBottomLine(true)
        }else{
            liPersonalMaterial.visibility = View.GONE
            liDeliverRecord.visibility = View.GONE
            liAttentionRecord.visibility = View.GONE
            liCollectRecord.setShowBottomLine(false)
        }
    }

    /**
     * 设置注册时间
     */
    private fun setRegisterTime() {
        userInfoViewModel.getRegisterTime{
            if (isActivityDestroyed){
                return@getRegisterTime
            }
            liRegisterTime.value = it
        }
    }

    override fun onClick(v: View?) {
        when(v?.id){
            R.id.liPersonalMaterial -> IntentUtils.startResumePreviewActivity(this,PreviewActivity.FROM_PRIVACY_PERSONAL_MATERIAL)
            R.id.liAccountSafe -> IntentUtils.startMineAccount(this)
            R.id.liDeliverRecord -> IntentUtils.startDeliverListActivity(this,MessageConfig.ResumeStateTabType.ALL)
            R.id.liCollectRecord -> {
                if (UserRoleManager.getInstance().isCUser){
                    IntentUtils.startActivityNoException(this, Intent(this, CollectionActivity::class.java))
                }else{
                    startCVProgressActivity(this, ResumeState.STATE_RESUME_COLLECT, ResourceUtils.getString(R.string.my_collect))
                }
            }
            R.id.liAttentionRecord -> IntentUtils.startActivityNoException(this, Intent(this, MineAttentedCompanyActivity::class.java))
            R.id.liConsumeRecord -> IntentUtils.startLagouWebViewActivityHideTitle(this,BUSINESS_TRADE_DETAIL_URL)
            R.id.liRechargeRecord -> IntentUtils.startLagouWebViewActivityHideTitle(this,BUSINESS_TRADE_DETAIL_URL)
            R.id.liDeviceInfo -> startActivity(Intent(this,DeviceAppInfoActivity::class.java).putExtra(IntentUtils.INTENT_KEY_TYPE,TYPE_DEVICE_INFO))
            R.id.llOtherInfo -> startActivity(Intent(this,DeviceAppInfoActivity::class.java).putExtra(IntentUtils.INTENT_KEY_TYPE,TYPE_OTHER_INFO))
        }
    }
}