package com.common.ui.rights

import android.graphics.Canvas
import android.graphics.Paint
import android.graphics.Rect
import android.view.View
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.lagou.commonlibs.utils.ResourceUtils

class RightsSetItemDecoration: RecyclerView.ItemDecoration() {
    private val mDividerHeight:Int = ResourceUtils.getDimenSize(R.dimen.dp_05)

    /**
     * 绘制分割线的画笔
     */
    private var mPaint: Paint? = null
    init {
        mPaint = Paint(Paint.ANTI_ALIAS_FLAG).apply {
            style = Paint.Style.FILL
            color = ResourceUtils.getColor(R.color.color_e8e9eb)
        }

    }
    override fun getItemOffsets(
        outRect: Rect,
        view: View,
        parent: RecyclerView,
        state: RecyclerView.State
    ) {
        outRect.bottom = mDividerHeight
    }

    override fun onDraw(c: Canvas, parent: RecyclerView, state: RecyclerView.State) {
        super.onDraw(c, parent, state)
        val childCount = parent.childCount
        for (i in 0 until childCount) {
            val childView = parent.getChildAt(i)
            this.drawDivider(childView, c)
        }
    }

    /**
     *
     * @param childView
     * @param c
     */
    private fun drawDivider(childView: View, c: Canvas) {
        val left = childView.left + childView.paddingLeft
        val right: Int = childView.right
        val top = childView.bottom
        val bottom: Int = top + mDividerHeight
        mPaint?.let {
            c.drawRect(left.toFloat(), top.toFloat(), right.toFloat(), bottom.toFloat(), it)
        }
    }
}