package com.common.ui.rights

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.lagou.baselib.util.mmkv.MKVWithClearUtils
import com.lagou.annotation.aspect.SingleClick
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.bean.SceneRightsBean
import com.lagou.baselib.privacy.UpdateSwitchCallback
import com.lagou.baselib.privacy.checkSystemRightsState
import com.lagou.baselib.privacy.toggle
import com.lagou.commonlibs.privacy.PrivacyPermissionKey
import com.lagou.commonlibs.view.SwitchButton

class SceneRightsAdapter(val context: BaseActivity, private val sceneRightsData: List<SceneRightsBean>, @PrivacyPermissionKey private val systemRightsKey:String) :
    RecyclerView.Adapter<SceneRightsAdapter.SceneRightsViewHolder>() {
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): SceneRightsViewHolder {
        val sceneRightsView = LayoutInflater.from(context).inflate(R.layout.layout_scene_rights_switch, parent, false)
        val holder = SceneRightsViewHolder(sceneRightsView)
        holder.sbScene.setOnClickListener {switchButton ->
            onItemSwitchClick(switchButton as SwitchButton,holder.adapterPosition)
        }
        return holder
    }

    @SingleClick
    private fun onItemSwitchClick(switchButton:SwitchButton,adapterPosition:Int) {
        sceneRightsData[adapterPosition].sceneKey?.let {
            //打开or关闭场景权限开关
            toggle(it)
            switchButton.setState(switchButton.isOn.not())
            if (switchButton.isOn){
                //开关打开时校验系统权限是否开启，如果未开启，弹窗提示目的弹窗or告知弹窗
                checkSystemRightsState(context,systemRightsKey,object: UpdateSwitchCallback {
                    override fun onShouldUpdateAll(should: Boolean) {
                        if (should){
                            notifyDataSetChanged()
                        }
                    }
                })
            }
        }
    }


    override fun onBindViewHolder(holder: SceneRightsViewHolder, position: Int) {
        val bean = sceneRightsData[position]
        holder.tvSceneName.text = bean.sceneName
        holder.tvSceneDesc.text = bean.desc
        holder.sbScene.setState(MKVWithClearUtils.getInstance().decodeBoolean(bean.sceneKey))
    }

    override fun getItemCount() = sceneRightsData.size

    class SceneRightsViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val tvSceneName: TextView = itemView.findViewById(R.id.tvSceneRightsName)
        val tvSceneDesc: TextView = itemView.findViewById(R.id.tvSceneRightsDesc)
        val sbScene: SwitchButton = itemView.findViewById(R.id.sbSceneRights)
    }
}