package com.common.ui.rights

import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.IntentUtils
import com.alpha.lagouapk.widget.decoration.DividerItemDecoration
import com.common.bean.RightsSetBean
import com.common.manager.RightsManager
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.bean.SceneRightsBean
import com.lagou.baselib.privacy.*
import com.lagou.commonlibs.inter.OnSingleMethodNoParameterListener
import com.lagou.commonlibs.privacy.PrivacyPermissionKey
import com.lagou.commonlibs.utils.LogUtils
import com.lagou.commonlibs.utils.ResourceUtils
import kotlinx.android.synthetic.main.activity_scene_rights_setting.*
/**
 * 场景权限设置页
 */
class SceneRightsSetActivity:BaseActivity() {
    private lateinit var rightsManager:RightsManager
    private var mSystemRightsKey:String? = null
    override fun getContentLayoutId() = R.layout.activity_scene_rights_setting
    override fun init() {
        mSystemRightsKey = intent.getStringExtra(IntentUtils.INTENT_KEY_TYPE)
        rightsManager = RightsManager(mSystemRightsKey)
        mTitleBar.setCenterTvTxt(getCenterTitle())
        tvSystemRightsName.text = getSubTitle()
        tvSystemRightsDesc.text = getSystemRightsDesc()
        rvRightsList.apply {
            addItemDecoration(
                DividerItemDecoration(this@SceneRightsSetActivity,
                DividerItemDecoration.HORIZONTAL_LIST, ResourceUtils.getDimenSize(R.dimen.dp_05),
                ResourceUtils.getColor(R.color.color_e8e9eb))
            )
            adapter = SceneRightsAdapter(this@SceneRightsSetActivity,getSceneRightsData(),mSystemRightsKey ?: "")
        }
        mTitleBar.setLeftImgListener { finish() }
        rlSystemRightsHead.setOnClickListener {  IntentUtils.startSettingDetail(this@SceneRightsSetActivity) }
    }

    override fun onResume() {
        super.onResume()
        rightsManager.checkRightsStatus(applicationContext, noParameterListener)
    }

    private val noParameterListener = OnSingleMethodNoParameterListener {
        runOnUiThread{
            val bean: RightsSetBean? = rightsManager.rightsSetBeans?.firstOrNull()
            bean?.let{
                tvSystemRightsState.text = it.showStateTxt()
                tvSystemRightsState?.setTextColor(it.showStateColor)
                rvRightsList.alpha = if (it.isOpen) 1f else 0.5f
                rvRightsList.setIntercept(it.isOpen.not())
            }
        }
    }

   private fun getSceneRightsData():List<SceneRightsBean>{
       return when(mSystemRightsKey){
           PrivacyPermissionKey.CAMERA -> getCameraSceneRightsItems()
           PrivacyPermissionKey.EXTERNAL_STORAGE -> getExternalStoreRightsItems()
           PrivacyPermissionKey.RECORD_AUDIO -> getRecordRightsItems()
           else -> emptyList()
       }
   }
    private fun getCenterTitle():String{
        return when(mSystemRightsKey){
            PrivacyPermissionKey.CAMERA -> ResourceUtils.getString(R.string.camera_setting)
            PrivacyPermissionKey.EXTERNAL_STORAGE -> ResourceUtils.getString(R.string.external_store_setting)
            PrivacyPermissionKey.RECORD_AUDIO -> ResourceUtils.getString(R.string.record_audio_setting)
            else ->  ""
        }
    }
    private fun getSubTitle():String{
        return when(mSystemRightsKey){
            PrivacyPermissionKey.CAMERA -> ResourceUtils.getString(R.string.camera)
            PrivacyPermissionKey.EXTERNAL_STORAGE -> ResourceUtils.getString(R.string.external_store)
            PrivacyPermissionKey.RECORD_AUDIO -> ResourceUtils.getString(R.string.record_audio)
            else ->  ""
        }
    }
    private fun getSystemRightsDesc():String{
        return when(mSystemRightsKey){
            PrivacyPermissionKey.CAMERA -> SYSTEM_CAMERA_DESC
            PrivacyPermissionKey.EXTERNAL_STORAGE -> getSystemExternalStoreDesc()
            PrivacyPermissionKey.RECORD_AUDIO -> SYSTEM_RECORD_DESC
            else -> ""
        }
    }
}