package com.common.ui.video

import android.app.Activity
import android.content.Intent
import android.text.TextUtils
import android.view.View
import android.widget.TextView
import com.alpha.lagouapk.R
import com.common.bean.VideoRes
import com.common.guide.util.LogUtil
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.utils.LogUtils
import com.lagou.exoplayer.listener.OnVideoViewStateChangeListener
import com.lagou.exoplayer.player.BaseIjkVideoView
import com.lagou.exoplayer.player.IjkVideoView
import com.lagou.exoplayer.ui.SeamlessController

/**
 * @date： Crate by wangjunwei on 2022/7/21
 * @description：视频播放主页面
 **/
class VideoPlayActivity : BaseActivity(), OnVideoViewStateChangeListener, BaseIjkVideoView.OnFirstStartPlayListener{

    private var ijkVideoView: IjkVideoView? = null
    private var tvEnsure: TextView? = null
    private var isOnlyPlay = true

    /**
     * 本地视频链接以及流媒体
     */
    private var videoRes: VideoRes? = null
    private var seamlessController: SeamlessController? = null

    companion object {
        /**
         * 是否是播纯放页面：兼顾选中视频功能
         */
        const val KEY_IS_PLAY_VIDEO = ""

        fun startPlayActivity(activity: Activity, videoRes: VideoRes){
            startPlayActivity(activity, videoRes, true)
        }

        /***
         * 启动播放视频页面
         * @param isOnlyPlay 是否是纯播放视频页面，true是，false 除了播放视频还兼顾视频选中
         */
        fun startPlayActivity(activity: Activity, videoRes: VideoRes, isOnlyPlay: Boolean){
            var intent = Intent(activity, VideoPlayActivity::class.java)
            intent.putExtra(VideoListActivity.KEY_SELECT_VIDEO, videoRes)
            intent.putExtra(KEY_IS_PLAY_VIDEO, isOnlyPlay)
            activity.startActivityForResult(intent, VideoListActivity.SELECT_REQUEST_CODE)
        }
    }

    override fun getContentLayoutId() = R.layout.activity_play_video

    override fun init() {
        videoRes = intent?.getParcelableExtra(VideoListActivity.KEY_SELECT_VIDEO)
        isOnlyPlay = intent?.getBooleanExtra(KEY_IS_PLAY_VIDEO, true) ?: true
        seamlessController = SeamlessController(this@VideoPlayActivity)
        initVideoView()
        playLocalVideo()
    }


    private fun initVideoView() {
        ijkVideoView = findViewById(R.id.view_video)
        tvEnsure = findViewById(R.id.tv_ensure)
        ijkVideoView?.addOnVideoViewStateChangeListener(this)
        ijkVideoView?.setOnFirstStartPlayListener(this)
        tvEnsure?.visibility = if (isOnlyPlay) View.GONE else View.VISIBLE
    }

    private fun initVideo() {
        ijkVideoView?.apply {
            setScreenScale(IjkVideoView.SCREEN_SCALE_DEFAULT)
            release()
            setPlayOnMobileNetwork(false)
            setIsShowing(true)
            setAutoRotate(false)
            setRadius(false)
            videoController = seamlessController
        }
    }

    /***
     * 播放本地视频
     */
    private fun playLocalVideo(){
        initVideo()
        //1 播放视频优先使用网络连接
        //2 其次使用本地压缩后的视频
        //3 最后使用本地原始视频
        if(!TextUtils.isEmpty(videoRes?.videoUrl)){
            ijkVideoView?.url = videoRes?.videoUrl
            ijkVideoView?.start()
            return
        }

        if (!TextUtils.isEmpty(videoRes?.destPath)){
            ijkVideoView?.url = videoRes?.destPath
            ijkVideoView?.start()
            return
        }

        ijkVideoView?.url = videoRes?.uri?.toString()
        ijkVideoView?.start()
    }

    override fun onResume() {
        super.onResume()
        ijkVideoView?.resume()
    }

    override fun onPause() {
        super.onPause()
        ijkVideoView?.pause()
    }

    override fun onDestroy() {
        super.onDestroy()
        ijkVideoView?.release()
        ijkVideoView?.removeOnVideoViewStateChangeListener(this)
    }

    /**
     * 确认选中
     */
    fun ensureSelect(view: View) {
        var intent = Intent()
        intent.putExtra(VideoListActivity.KEY_SELECT_VIDEO, videoRes)
        setResult(VideoListActivity.SELECT_RESULT_CODE, intent)
        finish()
    }

    override fun onBackPressed() {
        if (ijkVideoView?.onBackPressed() == true){
            return
        }
        super.onBackPressed()
    }

    /**
     * 播放器状态
     */
    override fun onPlayerStateChanged(playerState: Int) {
        //TODO("Not yet implemented")
    }

    /**
     * 播放状态
     * 播放失败 STATE_ERROR = -1;
     * 空闲 STATE_IDLE = 0;
     * 准备中 STATE_PREPARING = 1;
     * 准备播放 STATE_PREPARED = 2;
     * 播放中 STATE_PLAYING = 3;
     * 暂停 STATE_PAUSED = 4;
     * 播放完毕 STATE_PLAYBACK_COMPLETED = 5;
     * 缓冲中 STATE_BUFFERING = 6;
     * 缓冲完成 STATE_BUFFERED = 7;
     */
    override fun onPlayStateChanged(playState: Int) {
        LogUtils.i("VideoPlayActivity", "playState = " + playState)
    }

    override fun onFirstStartPlay() {
        //TODO("Not yet implemented")
    }

    /***
     * 关闭当前页面
     */
    fun finishPage(view: View) {
        finish()
    }

    override fun getStatusBarColor(): Int {
        return R.color.color_ff000000
    }
}