package com.common.webview

import com.alpha.lagouapk.ui.login.bean.OauthGetResp
import com.common.integrate.wx.OnWxBindCallback
import com.common.integrate.wx.WalletWxBindEvent
import com.common.webview.WalletWebViewActivity.Companion.B_ROUTER_URL
import com.common.webview.WalletWebViewActivity.Companion.C_ROUTER_URL
import com.common.webview.jssdk.JsBindWxHandler
import com.lagou.annotation.apt.RouterRule
import com.lagou.audiolib.event.CourseEventTags
import com.lagou.baselib.jsbridge.JsBridgeCore
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.web.UrlConfig
import com.lagou.lagouee.observer.BEventTags
import com.lagou.socketchannel.util.GsonUtil

/**
 * @date 创建时间：2019-12-02
 * @author 作者：codeman
 * @Description  描述：拉勾钱包webview
 * @version
 */
@RouterRule(B_ROUTER_URL, C_ROUTER_URL)
class WalletWebViewActivity : LagouWebviewActivity(), OnWxBindCallback<OauthGetResp> {

    private var wxBindEvent = WalletWxBindEvent(this, this)
    private var jsBindWxHandler = JsBindWxHandler(this)

    companion object {
        const val INTENT_KEY_URL: String = WebViewDelegate.INTENT_KEY_URL
        const val B_ROUTER_URL = "lagou://lagou.com/wallet?url={url}&[title]={title}&[hideTitle]={0/1}"
        const val C_ROUTER_URL = "lagouhr://lagou.com/wallet?url={url}&[title]={title}&[hideTitle]={0/1}"
    }

    override fun initWindow() {
        intent?.apply {
            putExtra(WebViewDelegate.IS_NEED_LOGIN_URL, true)
        }
        super.initWindow()
    }

    override fun init() {
        super.init()
        OkBus.getInstance().register(BEventTags.WALLET_WX_BIND, wxBindEvent)
        // 设置原生微信绑定触发功能，供Js调用
        registerNativeMethod("bindWeChatAccount", jsBindWxHandler)
        // 设置订单同步
        registerNativeMethod("syncPurchasedOrder", object : JsBridgeCore.BaseNativeFunctionHandler(this) {
            override fun handle(data: String?, result: JsBridgeCore.NativeHandlerResult?) {
                OkBus.getInstance().onEvent(CourseEventTags.COURSE_PAY_REFRESH)
                super.handle(data, result)
            }
        });
    }


    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance().unRegister(wxBindEvent)
    }

    /***
     * 直接调用Js方法，通知Js微信绑定已经完成
     */
    override fun onCurrentHasBind(t: OauthGetResp?) {
        jsBindWxHandler.apply {
            getNativeNativeHandler()?.onResult(GsonUtil.toJson(t))
        }
    }

    override fun onToBindSuccess(t: OauthGetResp?) {
        jsBindWxHandler.apply {
            getNativeNativeHandler()?.onResult(GsonUtil.toJson(t))
        }
    }

    override fun getWebViewUrl(): String {
        return UrlConfig.URL_WALLET
    }
}