package com.common.webview.jssdk

import android.content.Context
import android.text.TextUtils
import androidx.lifecycle.lifecycleScope
import com.common.integrate.qrcode.QrCodeDetectorDialog
import com.common.integrate.qrcode.QrcodeManager
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.jsbridge.JsBridgeCore
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.launch
import org.json.JSONObject

/**
 * @date： Crate by wangjunwei on 2023/2/28
 * @description：自动识别图片二维码的bridge，包含保存图片、转发到微信、识别二维码
 **/
class JsQRCodeDetectorHandler(context: Context) :
    JsBridgeCore.BaseNativeFunctionHandler(context) {

    private  var context: Context? = null
    private val GAP = ","

    init {
        this.context = mContext.get()
    }

    override fun handle(data: String?, result: JsBridgeCore.NativeHandlerResult?) {
        //super.handle(data, result)
        if (context == null || data == null){
            result?.onResult("")
            return
        }

        parseAndIdentifyPicture(data)
        result?.onResult("")
    }

    private fun parseAndIdentifyPicture(data: String) {
        try {
            val jsonObject = JSONObject(data)
            var pic = jsonObject.optString("pic")
            val name = jsonObject.optString("name")
            val isShowToast = jsonObject.optBoolean("isShowToast")
            if (TextUtils.isEmpty(pic) || TextUtils.isEmpty(name)) {
                return
            }

            // 去掉data:image/*;base64,
            val index = pic.indexOf(GAP)
            if (index >= 0) {
                pic = pic.substring(index + 1)
            }
            val baseActivity = context as? BaseActivity
            baseActivity?.apply {
               lifecycleScope.launch(Dispatchers.Main) {
                    val qrcodeResult = QrcodeManager.identifyPictureQrcode(pic, isShowToast)
                    //1 未检测出包含二维码，包含两种情况其一不包含二维码、其二包含了未能识别出的二维码+也没有图片数据
                    if (qrcodeResult?.codeResult == null && qrcodeResult?.bitmap == null){
                        return@launch
                    }
                    //2 检测出二维码数据，长按或者点击触发弹窗（询问用户是否导航到二维码结果），参考扫码处理逻辑（ 包含四个选项，保存图片、转发到微信、识别二维码  取消）
                    //或者无二维码，但是有图片数据
                    QrCodeDetectorDialog.getInstance(qrcodeResult).show(supportFragmentManager)
                }
            }

        }catch (e: java.lang.Exception){
            e.stackTrace
        }
    }
}