package com.common.webview.jssdk

import android.content.Context
import com.alpha.lagouapk.observer.EventTags
import com.google.gson.Gson
import com.lagou.baselib.jsbridge.JsBridgeCore
import com.lagou.baselib.jsbridge.JsBridgeCore.BaseNativeFunctionHandler
import com.lagou.commonlibs.Constant
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.tencent.mm.opensdk.modelbiz.SubscribeMessage
import com.tencent.mm.opensdk.openapi.WXAPIFactory
import org.json.JSONObject


/**
 * 订阅
 */
class JsWxSubscriptionHandler(context: Context) : BaseNativeFunctionHandler(context) {
    private var mResult: JsBridgeCore.NativeHandlerResult? = null
    private val subscribeEvent = Event { msg ->
        try {
            mResult?.let {
                if (msg.obj is SubscribeReq) {
                    val req : SubscribeReq = msg.obj as SubscribeReq
                    it.onResult(Gson().toJson(req))
                }
            }
            unRegister()
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    private fun unRegister() {
        OkBus.getInstance().unRegister(subscribeEvent)
    }

    override fun handle(data: String?, result: JsBridgeCore.NativeHandlerResult?) {
        if (data.isNullOrEmpty()) {
            return super.handle(data, result)
        }
        if (mContext.get() == null){
            return super.handle(data, result)
        }
        try {
            OkBus.getInstance().register(EventTags.SEND_WX_SUBSCRIBE_CODE, subscribeEvent)
            mResult = result
            val jsonObj = JSONObject(data)
            val scene = jsonObj.optInt("scene")
            val reserved = jsonObj.optString("reserved")

            val req = SubscribeMessage.Req()
            req.scene = scene
            req.templateID = Constant.WECHAT_TEMPLATE_ID
            req.reserved = reserved
            val createWXAPI = WXAPIFactory.createWXAPI(mContext.get(), Constant.WECHAT_APP_ID)
            createWXAPI.sendReq(req)
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}