package com.common.widget.interview

import android.animation.Animator
import android.animation.AnimatorListenerAdapter
import android.animation.AnimatorSet
import android.animation.ObjectAnimator
import android.content.Context
import android.graphics.Rect
import androidx.viewpager.widget.ViewPager
import androidx.recyclerview.widget.RecyclerView
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.recyclerview.widget.GridLayoutManager
import androidx.viewpager.widget.PagerAdapter
import com.alpha.lagouapk.R
import com.common.bean.json.InterviewCalendarDayRes
import com.common.manager.InterviewCalendarManager
import com.common.ui.adapter.InterviewCalendarDayAdapter
import com.common.ui.adapter.InterviewWeekAdapter
import com.common.widget.popup.InterviewCalenderPopup
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.lagouee.ui.interview.BInterviewScheduleActivity
import com.lagou.lagouee.widget.inter.DialogListener
import kotlinx.android.synthetic.main.card_interview_calendar_expand.view.*
import kotlinx.android.synthetic.main.layout_interview_calendar_expand.view.*

/**
 * @date 创建时间：2020/7/28
 * @author 作者：codeman
 * @Description  描述：面试日历
 * @version
 */
public class InterviewCalenderExpandView : FrameLayout {

//    private var calenderFoldView: ICalenderFoldView? = null;
    private var calenderFoldView: InterviewCalenderFoldView? = null;

    /***
     * 服务器时间戳
     */
    private var serverTimeStamp = 0L;

    /**
     * 日历选中回调
     */
    private var iInterviewCalendar: InterviewCalenderPopup.IInterviewCalendar? = null


    private var allCalendars: MutableMap<Int, List<InterviewCalendarDayRes>>? = null

    /***
     * 1 日历pageAdapter
     */
    private var calendarAdapter: CalendarPageAdapter? = null

    /***
     *2  月份到viewPager下标的映射
     */
    private var monthMapIndex = mutableMapOf<Int, Int>()

    /***
     * 1 被选中日历的下标
     */
    private var selectCalendarIndex = -1
    private var selectCalendarDayRes: InterviewCalendarDayRes? = null

    /***
     * 2 下标到日历适配器的映射
     */
    private var indexMapAdapter = mutableMapOf<Int, InterviewCalendarDayAdapter>()

    private var showCalendarAnim: ObjectAnimator? = null
    private var showCalendarAlphaAnim: ObjectAnimator? = null
    private var showLayerAlphaAnim: ObjectAnimator? = null

    private var hideCalendarAnim: ObjectAnimator? = null
    private var hideCalendarAlphaAnim: ObjectAnimator? = null
    private var hideLayerAlphaAnim: ObjectAnimator? = null

    private var showSetAnim: AnimatorSet? = null
    private var dismissSetAnim: AnimatorSet? = null

    private var listener: DialogListener? = null
    private var showTabLayerAlphaAnim: ObjectAnimator? = null
    private var hideTabLayerAlphaAnim: ObjectAnimator? = null

    /**
     * 是否要同步到折叠日历
     */
    private var isApplyFold: Boolean = false

    /***
     * 当前日历viewpager页码
     */
    private var currentIndex = -1


    companion object {
        val ANIM_DURATION = 400L

        /**
         * 动画相关
         */
        var dp_270: Float = 0F
        var dp_65: Float = 0F
    }

    constructor(context: Context): super(context){

    }

    constructor(context: Context, attributeSet: AttributeSet): super(context, attributeSet){

    }

    constructor(context: Context, attributeSet: AttributeSet, defStyleAttr: Int): super(context, attributeSet, defStyleAttr){

    }

    init {
        dp_270 = context.resources.getDimension(R.dimen.dp_270)
        dp_65 = context.resources.getDimension(R.dimen.dp_65)
        LayoutInflater.from(context).inflate(R.layout.card_interview_calendar_expand, this, true)
        initWeekRecycle()
        initCalendarViewPager()
        initListener()
        //fillUi()
    }

    fun setCalenderFoldView(calenderFoldView: InterviewCalenderFoldView?) {
        this.calenderFoldView = calenderFoldView
        iInterviewCalendar = calenderFoldView?.getIInterviewCalendar()

    }

    fun showAnim() {
        try {
            if (showSetAnim == null) {
                return
            }
            if (showSetAnim?.isRunning == true) {
                return
            }

            showSetAnim?.start()
        }catch (e: Exception){
            e.printStackTrace()
        }
    }

    fun hideAnim() {
        try {
            if (dismissSetAnim == null) {
                return
            }

            if (dismissSetAnim?.isRunning == true) {
                return
            }
            dismissSetAnim?.start()
        }catch (e: Exception){
            e.printStackTrace()
        }
    }

    fun beforeCalendar(isExpand: Boolean) {
        if (isMinIndex()){
            return
        }
        vm_pager.currentItem = vm_pager.currentItem - 1
        if (isExpand){
            showAnim()
        }
    }

    fun afterCalendar(isExpand: Boolean) {
        if (isMaxIndex()){
            return
        }
        vm_pager.currentItem = vm_pager.currentItem + 1
        if (isExpand){
            showAnim()
        }
    }

    /***
     * 同步折叠日历数据
     */
    fun syncFoldCalendar(calendarDay: InterviewCalendarDayRes, isApplyFold: Boolean) {
        this.isApplyFold = isApplyFold
        //2 选中的数据不同时，同步状态
        val index = InterviewCalendarManager.syncExpandFromFoldCalendar(calendarDay, allCalendars)
        if (index != -1) {
            allCalendars?.let { it1 -> calendarAdapter?.setData(it1) }
            vm_pager.currentItem = index
        }
    }

    private fun initListener() {
        vm_layer.setOnClickListener {
            hideAnim()
        }
        lin_calendar.setOnClickListener {

        }
        vm_pager.addOnPageChangeListener(object : ViewPager.SimpleOnPageChangeListener() {
            override fun onPageSelected(position: Int) {
                calendarAdapter?.apply {
                    var interviewCalendarDays = getIndexCalendars(position)
                    var month = InterviewCalendarManager.getMonth(interviewCalendarDays)
                    var year = InterviewCalendarManager.getYearMonth(interviewCalendarDays)
                    tv_expand_select_calendar_left.text = month
                    tv_expand_select_calendar.text = year
                    //3 同步给折叠日历数据
                    if (isApplyFold){
                        calenderFoldView?.syncFoldCalendar(interviewCalendarDays?.get(0))
                    }
                    isApplyFold = true

                    //4 切换操作按钮状态
                    if (currentIndex != -1){
                        if (position < currentIndex){
                            handleLeftChange()
                        }else if (position > currentIndex){
                            handleRightChange()
                        }
                    }
                    currentIndex = position
                }
            }
        })
        frame_expand_before_month.setOnClickListener {
            if (context is BInterviewScheduleActivity){
                AnalyticHelper.getInstance().sendClickInfo("1qq6")
            }else {
                AnalyticHelper.getInstance().sendClickInfo("1qr4")
            }
            beforeCalendar(false)
        }
        frame_expand_after_month.setOnClickListener {
            if (context is BInterviewScheduleActivity){
                AnalyticHelper.getInstance().sendClickInfo("1qq7")
            }else {
                AnalyticHelper.getInstance().sendClickInfo("1qr5")
            }
            afterCalendar(false)
        }
        frame_flag.setOnClickListener {
            if (context is BInterviewScheduleActivity){
                AnalyticHelper.getInstance().sendClickInfo("1qqa")
            }else {
                AnalyticHelper.getInstance().sendClickInfo("1qr8")
            }
            hideAnim()
        }
    }

    private fun handleRightChange() {
        if (isMaxIndex()) {
            image_expand_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_unclick)
            frame_expand_after_month.isEnabled = false
        } else {
            image_expand_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_nor)
            frame_expand_after_month.isEnabled = true
        }

        image_expand_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_nor)
        frame_expand_before_month.isEnabled = true
    }

    private fun handleLeftChange() {
        if (isMinIndex()) {
            image_expand_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_unclick)
            frame_expand_before_month.isEnabled = false
        } else {
            image_expand_before_month.setImageResource(R.drawable.schedule_month_ic_arrowleft_nor)
            frame_expand_before_month.isEnabled = true
        }

        image_expand_after_month.setImageResource(R.drawable.schedule_month_ic_arrowright_nor)
        frame_expand_after_month.isEnabled = true
    }


    private fun initWeekRecycle() {
        recycle_title?.apply {
            layoutManager = GridLayoutManager(context, 7)
            itemAnimator = null
            adapter = InterviewWeekAdapter(context)
        }
    }

    private fun initCalendarViewPager() {
        vm_pager?.apply {
            calendarAdapter = CalendarPageAdapter(context)
            adapter = calendarAdapter
            offscreenPageLimit = 1
        }
    }

    /***
     * 填充日历UI
     */
    fun fillUi() {
        calenderFoldView?.let {
            serverTimeStamp = it.getServerTimeStamp()
        }
        calendarAdapter?.apply {
            ThreadUtil.compute {
                allCalendars = InterviewCalendarManager.createExtendCalendarDays(
                        serverTimeStamp,
                        calenderFoldView?.getInterviewTimeList(),
                        monthMapIndex
                )
                ThreadUtil.ui {
                    allCalendars?.let {
                        setData(it)
                    }
                    val index =
                            monthMapIndex[InterviewCalendarManager.getCurrentMonth(serverTimeStamp)]
                    index?.let {
                        selectCalendarIndex = it
                        vm_pager.currentItem = it
                    }
                }
            }
        }
    }

    fun initAnim(popupHeight: Int) {
        //1 展示动画
        showCalendarAnim =
                ObjectAnimator.ofFloat(lin_calendar, "translationY", -popupHeight.toFloat(), 0f)
        showCalendarAlphaAnim = ObjectAnimator.ofFloat(lin_calendar, "alpha", 0.0f, 1.0f)
        showLayerAlphaAnim = ObjectAnimator.ofFloat(vm_layer, "alpha", 0.0f, 1.0f)
        showSetAnim = AnimatorSet()
        showSetAnim?.apply {
            duration = ANIM_DURATION
            if (showTabLayerAlphaAnim == null) {
                playTogether(showCalendarAnim, showCalendarAlphaAnim, showLayerAlphaAnim)
            } else {
                playTogether(
                    showCalendarAnim,
                    showCalendarAlphaAnim,
                    showLayerAlphaAnim,
                    showTabLayerAlphaAnim
                )
            }
            addListener(object : AnimatorListenerAdapter() {
                override fun onAnimationStart(animation: Animator?) {
                    super.onAnimationStart(animation)
                    visibility = View.VISIBLE
                    vm_layer.visibility = View.VISIBLE
                    listener?.show()
                }

                override fun onAnimationEnd(animation: Animator?) {
                    super.onAnimationEnd(animation)
                }
            })
        }

        //隐藏动画
        hideCalendarAnim =
                ObjectAnimator.ofFloat(lin_calendar, "translationY", 0f, -popupHeight.toFloat())
        hideCalendarAlphaAnim = ObjectAnimator.ofFloat(lin_calendar, "alpha", 1f, 0f)
        hideLayerAlphaAnim = ObjectAnimator.ofFloat(vm_layer, "alpha", 1.0f, 0.0f)
                .setDuration(ANIM_DURATION)
        dismissSetAnim = AnimatorSet()
        dismissSetAnim?.apply {
            duration = ANIM_DURATION
            if (hideTabLayerAlphaAnim == null) {
                playTogether(hideCalendarAnim, hideLayerAlphaAnim, hideLayerAlphaAnim)
            } else {
                playTogether(
                    hideCalendarAnim,
                    hideLayerAlphaAnim,
                    hideLayerAlphaAnim,
                    hideTabLayerAlphaAnim
                )
            }
            addListener(object : AnimatorListenerAdapter() {
                override fun onAnimationStart(animation: Animator?) {
                    super.onAnimationStart(animation)
                }

                override fun onAnimationEnd(animation: Animator?) {
                    super.onAnimationEnd(animation)
                    visibility = View.GONE
                    vm_layer.visibility = View.GONE
                    translationY = 0f
                    listener?.hide()
                }
            })
        }
    }

    fun setListener(listener: DialogListener?) {
        this.listener = listener
    }

    inner class CalendarPageAdapter(context: Context) : PagerAdapter() {

        private val recycleViews: MutableMap<RecyclerView, InterviewCalendarDayAdapter> =
                mutableMapOf()
        private var calendars: MutableMap<Int, List<InterviewCalendarDayRes>> = mutableMapOf()
        private val context: Context = context

        fun setData(calendars: MutableMap<Int, List<InterviewCalendarDayRes>>) {
            this.calendars = calendars
            //recycleViews.clear()
            notifyDataSetChanged()
        }

        fun getIndexCalendars(position: Int): List<InterviewCalendarDayRes>? {
            return calendars[position]
        }

        override fun getItemPosition(`object`: Any): Int {
            return POSITION_NONE
        }

        override fun isViewFromObject(view: View, `object`: Any): Boolean {
            return view == `object`
        }

        override fun getCount(): Int {
            return calendars.size
        }

        override fun instantiateItem(container: ViewGroup, position: Int): Any {
            val recyclerView: RecyclerView = findViewByPosition(position)
            val adapter: InterviewCalendarDayAdapter? = recycleViews[recyclerView]
            container.addView(recyclerView)
            onBindView(position, adapter)
            return recyclerView
        }

        private fun onBindView(position: Int, adapter: InterviewCalendarDayAdapter?) {
            if (calendars[position] == null) {
                return
            }
            adapter?.setData(calendars[position])
        }

        private fun findViewByPosition(position: Int): RecyclerView {
            recycleViews.forEach {
                val recyclerView = it.key
                if (recyclerView.tag is Int) {
                    val tag = recyclerView.tag as? Int
                    if (tag == position && recyclerView.parent == null) {
                        return it.key
                    }
                }
            }
            val recyclerView: RecyclerView =
                    LayoutInflater.from(context)
                            .inflate(R.layout.layout_recycleview, null) as RecyclerView
            var interviewCalendarAdapter =
                    InterviewCalendarDayAdapter(context)
            indexMapAdapter[position] = interviewCalendarAdapter

            interviewCalendarAdapter.setInterviewCalendarListener { calendarDayRes, calendarDays ->
                selectCalendarDayRes = calendarDayRes
                //1 关闭动画
                hideAnim()
                //2 回调给业务方
                iInterviewCalendar?.onFoldCalendar(calendarDayRes, calendarDays)
                if (selectCalendarIndex != -1) {
                    indexMapAdapter[selectCalendarIndex]?.resetSelectData(calendarDayRes)
                }
                selectCalendarIndex = position
                //3 同步给折叠日历数据
                calenderFoldView?.syncFoldCalendar(calendarDayRes)
            }
            recyclerView.apply {
                layoutManager = GridLayoutManager(context, 7)
                itemAnimator = null
                addItemDecoration(CalendarDecoration(context))
                tag = position
                adapter = interviewCalendarAdapter
                recycleViews[recyclerView] = interviewCalendarAdapter
            }

            return recyclerView
        }

        fun getItemId(position: Int): Long {
            // 获取当前数据的hashCode
            val hashCode: Int = allCalendars?.get(position).hashCode()
            return hashCode.toLong()
        }

        override fun destroyItem(container: ViewGroup, position: Int, `object`: Any) {
            container.removeView(`object` as View?)
        }
    }


    class CalendarDecoration(context: Context) : RecyclerView.ItemDecoration() {
        private val dp_13: Int = context.resources.getDimension(R.dimen.dp_13).toInt()

        override fun getItemOffsets(outRect: Rect, itemPosition: Int, parent: RecyclerView) {
            super.getItemOffsets(outRect, itemPosition, parent)
            if (itemPosition > 6) {
                outRect.set(0, dp_13, 0, 0)
            }
        }
    }

    fun isMaxIndex() = vm_pager.currentItem == calendarAdapter?.getCount()?.let {it - 1 }

    fun isMinIndex() = vm_pager.currentItem == 0

    fun setTabLayerAnimation(
        showTabLayerAlphaAnim: ObjectAnimator?,
        hideTabLayerAlphaAnim: ObjectAnimator?
    ) {
        this.showTabLayerAlphaAnim = showTabLayerAlphaAnim
        this.hideTabLayerAlphaAnim = hideTabLayerAlphaAnim
    }
}