package com.common.widget.interview

import android.content.Context
import android.graphics.Rect
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.Window
import android.widget.FrameLayout
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager.widget.PagerAdapter
import androidx.viewpager.widget.ViewPager
import com.alpha.lagouapk.R
import com.common.bean.json.InterviewCalendarDayRes
import com.common.bean.json.InterviewCalendarFoldIndex
import com.common.manager.InterviewCalendarManager
import com.common.ui.adapter.InterviewCalendarDayAdapter
import com.common.ui.adapter.InterviewWeekAdapter
import com.common.widget.popup.InterviewCalenderPopup
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.util.BarUtil
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.lagouee.ui.interview.BInterviewScheduleActivity
import kotlinx.android.synthetic.main.card_interview_calendar_expand.view.recycle_title
import kotlinx.android.synthetic.main.card_interview_calendar_fold.view.*


/**
 * @date 创建时间：2020/08/01
 * @author 作者：codeman
 * @Description  描述：面试日历
 * @version
 */
class InterviewCalenderFoldView(context: Context, attrs: AttributeSet? = null) : FrameLayout(context, attrs), ICalenderFoldView {

    /***
     * 服务器时间戳
     */
    private var serverTimeStamp = System.currentTimeMillis()

    /***
     * 有面试的时间列表
     */
    private var interviewTimes: List<String>? = null

    /**
     * 日历选中回调
     */
    private var iInterviewCalendar: InterviewCalenderPopup.IInterviewCalendar? = null


    /**
     * 0 所有日历列表数据
     */
    private var allCalendarsMap =
            mutableMapOf<Int, MutableMap<Int, List<InterviewCalendarDayRes>>>()

    /**
     * 0.1 当前是哪个月的数据，折叠日历，每页一周
     */
    private var allCalendarIndex = 0

    /***
     * 1 日历pageAdapter
     */
    private var calendarAdapter: CalendarPageAdapter? = null

    /***
     *2  月份到每个viewPager所有的页数数据的映射
     */
    private var monthMapIndex = mutableMapOf<Int, Int>()


    /***
     * 1 被选中日历的下标
     */
    private var selectCalendarIndex = -1
    private var selectCalendarDayRes: InterviewCalendarDayRes? = null

    /***
     * 2 下标到日历适配器的映射
     */
    private var indexMapAdapter = mutableMapOf<Int, InterviewCalendarDayAdapter>()


    /***
     * 展开的日历
     */
//    private var calenderPopup: InterviewCalenderPopup? = null
    private var calenderPopupView: ICalenderExpandView? = null
//    private var calenderViewFactory: CalenderViewFactory? = null

    private var rView: View? = null
    private var locationView: View? = null

    init {
        LayoutInflater.from(context).inflate(R.layout.card_interview_calendar_fold, this, true)
        initWeekRecycle()
        initCalendarViewPager()
        initListener()
    }

    fun setCalendarExpandView(calenderPopupView: ICalenderExpandView?) {
        this.calenderPopupView = calenderPopupView
    }

    fun setIInterviewCalendar(iInterviewCalendar: InterviewCalenderPopup.IInterviewCalendar) {
        this.iInterviewCalendar = iInterviewCalendar
    }

    /***
     * 填充日历UI
     */
    fun fillUi(timeStamp: Long?, interviewTimeList: List<String>?, schemaTimeStamp: Long?) {
        timeStamp?.let {
            this.serverTimeStamp = it
        }
        this.interviewTimes = interviewTimeList
        calendarAdapter?.apply {
            ThreadUtil.compute {
                allCalendarsMap = InterviewCalendarManager.createFoldCalendarDays(
                        serverTimeStamp,
                        interviewTimes,
                        monthMapIndex
                )
                ThreadUtil.ui {
                    //1 月份映射到具体月份的日期信息
                    monthMapIndex[InterviewCalendarManager.getCurrentMonth(serverTimeStamp)]?.let {
                        allCalendarIndex = it
                    }
                    allCalendarsMap[allCalendarIndex]?.apply {
                        setData(this)
                        //2 映射到应该选择的日历页面(默认选择viewpager的哪一页)：今天或者选择的日期
                        val currentDay = InterviewCalendarManager.getCurrentDay(serverTimeStamp)
                        val calendarIndex =
                                InterviewCalendarManager.getFoldIndexOccupyDay(currentDay, this)
                        vm_pager_fold.currentItem = calendarIndex

                        //3 回调到业务方
                        var interviewCalendarDays = getIndexCalendars(0)
                        var month = InterviewCalendarManager.getMonth(interviewCalendarDays)
                        var year = InterviewCalendarManager.getYearMonth(interviewCalendarDays)
                        iInterviewCalendar?.onScrollCalendar(
                                0,
                                interviewCalendarDays,
                                month,
                                year
                        )
                    }
                }
            }
        }

        calenderPopupView?.fillUi()
    }

    /***
     * 同步折叠日历数据
     */
    fun syncFoldCalendar(calendarDay: InterviewCalendarDayRes?) {
        selectCalendarDayRes?.let {
            //1 选中的数据相同时不做处理
            calendarDay?.let { it2 ->
                if (it2.isEqualDay(it)) {
                    return
                }
            }
        }

        //2 选中的数据不同时，同步状态
        ThreadUtil.compute {
            val calendarFoldIndex: InterviewCalendarFoldIndex? = InterviewCalendarManager.syncFoldFromExpandCalendar(calendarDay, allCalendarsMap)
            ThreadUtil.ui {
                calendarFoldIndex?.let {
                    allCalendarIndex = it.outIndex
                    allCalendarsMap.get(it.outIndex)?.let { it1 ->
                        calendarAdapter?.setData(it1)
                        vm_pager_fold.currentItem = it.innerIndex
                    }
                }
                calendarDay?.let {
                    if (it.isSelect) {
                        selectCalendarDayRes = it
                    }
                }
            }
        }
    }

    /***
     * 切换折叠日历，同时同步状态到展开日历
     */
    fun beforeCalendarMonth() {
        if (isMinIndex()) {
            return
        }
        //1 同步折叠日历数据到大日历
        syncFold()
        //2 大日到上一个月，同时展开
        calenderPopupView?.beforeCalendar(true)
    }

    /***
     * 切换折叠日历，同时同步状态到展开日历
     */
    fun afterCalendarMonth() {
        if (isMaxIndex()) {
            return
        }
        //1 同步折叠日历数据到大日历
        syncFold()
        //2 大日到下一个月，同时展开
        calenderPopupView?.afterCalendar(true)
    }

    private fun syncFold(): Boolean {
        if (selectCalendarDayRes != null) {
            selectCalendarDayRes?.let {
                calenderPopupView?.syncFoldCalendar(it, false)
            }
            return true
        }
        val size = calendarAdapter?.getIndexCalendars(0)?.size
        size?.let {
            if (it > 0) {
                calendarAdapter?.getIndexCalendars(0)?.get(0)?.apply {
                    calenderPopupView?.syncFoldCalendar(this, false)
                }
            }
        }
        return false
    }

    /***
     * 仅仅展开大日历
     */
    fun onlyShowPopup() {
        calenderPopupView?.showAnim()
    }

    private fun initListener() {
        vm_pager_fold.addOnPageChangeListener(object : ViewPager.SimpleOnPageChangeListener() {
            override fun onPageSelected(position: Int) {
            }
        })
        frame_main_flag.setOnClickListener {
            calenderPopupView?.showAnim()
        }
    }

    private fun initWeekRecycle() {
        recycle_title?.apply {
            layoutManager = GridLayoutManager(context, 7)
            itemAnimator = null
            adapter = InterviewWeekAdapter(context)
        }
    }

    private fun initCalendarViewPager() {
        vm_pager_fold?.apply {
            calendarAdapter = CalendarPageAdapter(context)
            adapter = calendarAdapter
        }
    }

    inner class CalendarPageAdapter(private val context: Context) : PagerAdapter() {

        private val recycleViews: MutableMap<RecyclerView, InterviewCalendarDayAdapter> =
                mutableMapOf()
        private var calendars: MutableMap<Int, List<InterviewCalendarDayRes>> = mutableMapOf()

        fun setData(calendars: MutableMap<Int, List<InterviewCalendarDayRes>>) {
            this.calendars = calendars
            selectCalendarIndex = -1
            selectCalendarDayRes = null
            val interviewCalendarDays = getIndexCalendars(0)
            val month = InterviewCalendarManager.getMonth(interviewCalendarDays)
            val year = InterviewCalendarManager.getYearMonth(interviewCalendarDays)
            iInterviewCalendar?.onScrollCalendar(allCalendarIndex,
                    interviewCalendarDays,
                    month,
                    year
            )
            //recycleViews.clear()
            notifyDataSetChanged()
        }

        override fun getItemPosition(`object`: Any): Int {
            return POSITION_NONE
        }


        fun getIndexCalendars(position: Int): List<InterviewCalendarDayRes>? {
            return calendars[position]
        }

        override fun isViewFromObject(view: View, `object`: Any): Boolean {
            return view == `object`
        }

        override fun getCount(): Int {
            return calendars?.size
        }

        override fun instantiateItem(container: ViewGroup, position: Int): Any {
            val recyclerView: RecyclerView = findViewByPosition(position)
            val adapter: InterviewCalendarDayAdapter? = recycleViews[recyclerView]
            container.addView(recyclerView)
            onBindView(position, adapter)
            return recyclerView
        }

        private fun onBindView(position: Int, adapter: InterviewCalendarDayAdapter?) {
            if (calendars[position] == null) {
                return
            }
            adapter?.setData(calendars[position])
        }

        private fun findViewByPosition(position: Int): RecyclerView {
            recycleViews.forEach {
                val recyclerView = it.key
                if (recyclerView?.tag is Int) {
                    val tag = recyclerView?.tag as? Int
                    if (tag == position && recyclerView.parent == null) {
                        return it.key
                    }
                }
            }
            val recyclerView: RecyclerView =
                    LayoutInflater.from(context)
                            .inflate(R.layout.layout_recycleview, null) as RecyclerView
            val interviewCalendarAdapter =
                    InterviewCalendarDayAdapter(context)
            indexMapAdapter[position] = interviewCalendarAdapter

            interviewCalendarAdapter.setInterviewCalendarListener { calendarDayRes, calendarDays ->
                selectCalendarDayRes = calendarDayRes
                //1 重置当前日历的选中项
                if (selectCalendarIndex != -1) {
                    indexMapAdapter[selectCalendarIndex]?.resetSelectData(calendarDayRes)
                }
                //2 重置所有的日历数据的选中项
                //ThreadUtil.compute{
                //    InterviewCalendarManager.resetFoldCalendar(calendarDayRes, allCalendarsMap)
                //}
                //3 同步数据到展开日历
                calenderPopupView?.syncFoldCalendar(calendarDayRes, false)
                //4 回调给业务方
                iInterviewCalendar?.onFoldCalendar(calendarDayRes, calendarDays)
                selectCalendarIndex = position
            }
            recyclerView.apply {
                layoutManager = GridLayoutManager(context, 7)
                itemAnimator = null
                addItemDecoration(CalendarDecoration(context))
                tag = position
                adapter = interviewCalendarAdapter
                recycleViews[recyclerView] = interviewCalendarAdapter
            }

            return recyclerView
        }


        fun getItemId(position: Int): Long {
            // 获取当前数据的hashCode
            val hashCode: Int = allCalendarsMap.get(position).hashCode()
            return hashCode.toLong()
        }


        override fun destroyItem(container: ViewGroup, position: Int, `object`: Any) {
            container.removeView(`object` as View?)
        }
    }


    private class CalendarDecoration(context: Context) : RecyclerView.ItemDecoration() {
        private val dp_13: Int = context.resources.getDimension(R.dimen.dp_13).toInt()

        override fun getItemOffsets(outRect: Rect, itemPosition: Int, parent: RecyclerView) {
            super.getItemOffsets(outRect, itemPosition, parent)
            if (itemPosition > 6) {
                outRect.set(0, dp_13, 0, 0)
            }
        }
    }

    override fun getServerTimeStamp() = serverTimeStamp

    fun getInterviewTimeList() = interviewTimes

    override fun getIInterviewCalendar() = iInterviewCalendar

    fun isMaxIndex() = allCalendarIndex == allCalendarsMap.size - 1

    fun isMinIndex() = allCalendarIndex == 0
}