package com.lagou.lagouee.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.lagou.commonlibs.inter.OnSingleMdTwoPsListener
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.business.DateDetailListBean
import kotlinx.android.extensions.LayoutContainer
import kotlinx.android.synthetic.main.item_top_select_date.*

/**
 * Created by mihao on 2/3/23
 * 置顶职位选择日期适配器
 */
class TopPositionSelectDateAdapter(
    private val mContext: Context,
    private val mDateList: List<DateDetailListBean>?
) : RecyclerView.Adapter<TopPositionSelectDateAdapter.ViewHolder>() {

    private var onSelectListener: OnSingleMdTwoPsListener<DateDetailListBean, Int>? = null

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder =
        ViewHolder(
            LayoutInflater.from(mContext).inflate(R.layout.item_top_select_date, parent, false)
        )

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        mDateList?.get(position)?.let {
            holder.tv_day.text = it.day

            if (it.isCurrentDay) {
                holder.tv_day.setBackgroundResource(R.drawable.shape_circle_transparent)
                holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.theme_text_color))
                holder.tv_status.visibility = View.GONE
                return
            }

            if (it.isOfflineDay) {
                holder.tv_day.setBackgroundResource(R.drawable.shape_oval_e8e9eb)
                holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.white))
                holder.tv_status.setTextColor(ResourceUtils.getColor(R.color.color_999999))
                holder.tv_status.text = ResourceUtils.getString(R.string.top_offline_day)
                holder.tv_status.visibility = View.VISIBLE
                return
            }

            if (it.isReservedTop) {
                holder.tv_day.setBackgroundResource(R.drawable.shape_circle_transparent)
                holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.theme_text_color))
                holder.tv_status.setTextColor(ResourceUtils.getColor(R.color.theme_text_color))
                holder.tv_status.text = ResourceUtils.getString(R.string.top_reserved)
                holder.tv_status.visibility = View.VISIBLE
                return
            }

            if (it.isExpired) {
                holder.tv_day.setBackgroundResource(R.drawable.shape_circle_transparent)
                holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.color_999999))
                holder.tv_status.setTextColor(ResourceUtils.getColor(R.color.color_999999))
                holder.tv_status.text = ResourceUtils.getString(R.string.top_expired)
                holder.tv_status.visibility = View.VISIBLE
                return
            }

            if (it.isNotSelect) {
                holder.tv_day.setBackgroundResource(R.drawable.shape_circle_transparent)
                holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.color_999999))
            } else {
                if (it.isSelected) {
                    holder.tv_day.setBackgroundResource(R.drawable.shape_solid_circle_ff00b38a)
                    holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.white))
                } else {
                    holder.tv_day.setBackgroundResource(R.drawable.shape_circle_transparent)
                    holder.tv_day.setTextColor(ResourceUtils.getColor(R.color.color_0E0E0E))
                }
                holder.tv_day.setOnClickListener { view ->
                    onSelectListener?.onCallBack(it, position)
                }
            }
            if (it.day == "1") {
                holder.tv_status.setTextColor(ResourceUtils.getColor(R.color.color_999999))
                holder.tv_status.text = it.month
                holder.tv_status.visibility = View.VISIBLE
            } else {
                holder.tv_status.visibility = View.GONE
            }
        }
    }

    override fun getItemCount(): Int {
        return if (mDateList.isNullOrEmpty()) 0 else mDateList.size
    }

    class ViewHolder(override val containerView: View) : RecyclerView.ViewHolder(containerView),
        LayoutContainer

    fun setOnItemSelectListener(onSelectListener: OnSingleMdTwoPsListener<DateDetailListBean, Int>?) {
        this.onSelectListener = onSelectListener
    }
}