package com.lagou.lagouee.ui.business

import android.text.Html
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import butterknife.OnClick
import com.alpha.lagouapk.R
import com.alpha.lagouapk.net.HttpResult
import com.alpha.lagouapk.observer.EventTags
import com.common.widget.decoration.GridItemDecoration
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.inter.OnSingleMdTwoPsListener
import com.lagou.commonlibs.inter.OnSingleMethodListener
import com.lagou.commonlibs.ui.dialog.inter.ADismissListener
import com.lagou.commonlibs.utils.*
import com.lagou.component.ui.dialog.listener.LgDialogListener
import com.lagou.lagouee.bean.jsonbean.business.DateDetailListBean
import com.lagou.lagouee.bean.jsonbean.business.TopCardReserve
import com.lagou.lagouee.bean.jsonbean.business.TopCardSchedule
import com.lagou.lagouee.manager.net.BusinessNetManager
import com.lagou.lagouee.ui.HomeActivity
import com.lagou.lagouee.ui.adapter.TopPositionDurationAdapter
import com.lagou.lagouee.ui.dialog.business.TopSelectDateDialog
import com.lagou.lagouee.ui.rights.RightsApplyActivity
import com.lagou.lagouee.ui.rights.RightsScene
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.lagouee.utils.analytic.AnalyticUtilsB
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.activity_top_position.*

/**
 * Created by mihao on 1/31/23
 * 置顶职位
 */
class TopPositionActivity : BaseActivity() {

    /**
     * 简招职位ID
     */
    private var mdsPositionId = 0

    private var mTopCardSchedule: TopCardSchedule? = null
    private var mDurationList: ArrayList<TopCardSchedule.Durations>? = null
    private var topPositionDurationAdapter: TopPositionDurationAdapter? = null
    private var mSelectDateList: ArrayList<DateDetailListBean>? = null
    private var mSelectConsumeNum = 0.0

    companion object {
        const val KEY_POSITION_ID = "position_id"
    }

    override fun getContentLayoutId() = R.layout.activity_top_position

    override fun init() {
        mdsPositionId = intent.getIntExtra(KEY_POSITION_ID, 0)
        initListener()
        initDurationRecyclerView()
        getTopScheduleData()
    }

    private fun initListener() {
        title_bar.setLeftImgListener { finish() }
        wifi_view.setReLoadListener { getTopScheduleData() }
        iv_dialog_arrow.setOnClickListener {
            showSelectDateDialog()
        }
    }

    private fun initDurationRecyclerView() {
        mDurationList = ArrayList()
        mDurationList!!.add(
            TopCardSchedule.Durations.newInstance(
                TopCardSchedule.TopPositionDuration.ONE.toString(),
                false
            )
        )
        mDurationList!!.add(
            TopCardSchedule.Durations.newInstance(
                TopCardSchedule.TopPositionDuration.TWO.toString(),
                false
            )
        )
        mDurationList!!.add(
            TopCardSchedule.Durations.newInstance(
                TopCardSchedule.TopPositionDuration.THREE.toString(),
                false
            )
        )
        mDurationList!!.add(
            TopCardSchedule.Durations.newInstance(
                TopCardSchedule.TopPositionDuration.CUSTOM,
                false
            )
        )
        topPositionDurationAdapter = TopPositionDurationAdapter(baseActivity, mDurationList!!)
        topPositionDurationAdapter!!.setOnItemCheckListener(OnSingleMethodListener {
            if (it == null || mTopCardSchedule == null || ListUtil.isEmpty(mDurationList)) {
                return@OnSingleMethodListener
            }
            if (it.duration == TopCardSchedule.TopPositionDuration.CUSTOM) {
                if (!it.isSelect) {
                    mTopCardSchedule?.resetSelectDate()
                    mSelectDateList?.clear()
                    for (duration in mDurationList!!) {
                        duration.isSelect = false
                    }
                    it.isSelect = true
                    topPositionDurationAdapter?.notifyDataSetChanged()
                    showBottomStatus()
                }
                showSelectDateDialog()
                return@OnSingleMethodListener
            }

            if (it.isSelect) {
                return@OnSingleMethodListener
            }

            if (mTopCardSchedule?.autoSelectDay!! < SafeTypeConvert.toInt(it.duration)) {
                ToastUtil.show(baseActivity, ResourceUtils.getString(R.string.top_date_not_enough))
                return@OnSingleMethodListener
            }

            mTopCardSchedule?.resetSelectDate()
            mTopCardSchedule?.autoSelectDate(SafeTypeConvert.toInt(it.duration))
            mSelectDateList = mTopCardSchedule?.selectDateList
            for (duration in mDurationList!!) {
                duration.isSelect = false
            }
            it.isSelect = true
            topPositionDurationAdapter?.notifyDataSetChanged()
            showBottomStatus()
        })
        rv_top_duration.adapter = topPositionDurationAdapter
        rv_top_duration.layoutManager = GridLayoutManager(baseActivity, 4)
        rv_top_duration.addItemDecoration(
            GridItemDecoration(ResourceUtils.getDimenSize(R.dimen.dp_10), 4)
        )
    }

    private fun showSelectDateDialog() {
        TopSelectDateDialog().newInstance(mTopCardSchedule?.dateDetailList,
            OnSingleMdTwoPsListener { dateDetailList, isChangeSelect ->
                if (ListUtil.isEmpty(dateDetailList) || ListUtil.isEmpty(mDurationList) || mTopCardSchedule == null) {
                    return@OnSingleMdTwoPsListener
                }

                if (!isChangeSelect) {
                    if (ListUtil.isEmpty(mTopCardSchedule?.selectDateList)) {
                        for (duration in mDurationList!!) {
                            duration.isSelect = false
                        }
                        topPositionDurationAdapter?.notifyDataSetChanged()
                    }
                    return@OnSingleMdTwoPsListener
                }

                mTopCardSchedule?.dateDetailList = dateDetailList
                mSelectDateList = mTopCardSchedule?.selectDateList
                for (duration in mDurationList!!) {
                    duration.isSelect = false
                }
                if (!ListUtil.isEmpty(mSelectDateList)) {
                    mDurationList!![mDurationList!!.size - 1].isSelect = true
                }
                topPositionDurationAdapter?.notifyDataSetChanged()
                showBottomStatus()
            })
            .show(baseActivity.supportFragmentManager)
    }

    private fun getTopScheduleData() {
        BusinessNetManager.getTopScheduleData(mdsPositionId, object :
            OnAdapterCommonListenerImpl<TopCardSchedule, HttpResponse<TopCardSchedule?>?>(this) {
            override fun onSuccess(topCardSchedule: TopCardSchedule) {
                topCardSchedule.addPlaceholderDay()
                topCardSchedule.setAutoSelectDay()
                mTopCardSchedule = topCardSchedule
                wifi_view.visibility = View.GONE
                tv_position_name.text = topCardSchedule.positionName
                tv_position_city.text = topCardSchedule.city
                tv_position_education.text = topCardSchedule.education
                tv_position_work_year.text = topCardSchedule.workYear
                tv_top_category.text = ResourceUtils.getString(
                    R.string.top_position_category,
                    topCardSchedule.topCategory
                )
                if (topCardSchedule.isShowTips) {
                    iv_top_gift.visibility = View.VISIBLE
                    val layoutParams = iv_top_gift.layoutParams
                    layoutParams.width =
                        DeviceUtils.getScreenWidth() - ResourceUtils.getDimenSize(R.dimen.dp_30)
                    layoutParams.height = layoutParams.width * 180 / 1035
                    iv_top_gift.layoutParams = layoutParams
                } else {
                    iv_top_gift.visibility = View.GONE
                }
                autoSelectDate()
            }

            override fun onError(errorBean: HttpResponse<TopCardSchedule?>?) {
                if (errorBean == null) {
                    wifi_view.visibility = View.VISIBLE
                    return
                }
                if (errorBean.state == HttpResult.TopExceptionState.NOT_FIND
                    || errorBean.state == HttpResult.TopExceptionState.ALREADY_OFFLINE
                ) {
                    DialogUtils.showTopCardExceptionDialog(
                        baseActivity,
                        errorBean.message,
                        object : ADismissListener<Any?>() {
                            override fun onRight() {
                                finishActivity()
                            }
                        })
                    return
                }
                ToastUtil.show(baseActivity, errorBean.message)
                wifi_view.visibility = View.VISIBLE
            }

            override fun onNoInternet() {
                wifi_view.visibility = View.VISIBLE
            }

            override fun isShowToast(): Boolean {
                return false
            }
        })
    }

    /**
     * 默认选择2天，如果可选天数不足2天，默认选择1天
     * 如果可选天数不足1天，则不选
     */
    private fun autoSelectDate() {
        mTopCardSchedule?.autoSelectDate(TopCardSchedule.TopPositionDuration.TWO)
        mSelectDateList = mTopCardSchedule?.selectDateList
        for (duration in mDurationList!!) {
            duration.isSelect = false
        }
        if (mSelectDateList!!.size in 1..2) {
            mDurationList?.get(mSelectDateList!!.size - 1)?.isSelect = true
        }
        topPositionDurationAdapter?.notifyDataSetChanged()
        showBottomStatus()
    }

    private fun showBottomStatus() {
        tv_top_select_date.text =
            Html.fromHtml(mTopCardSchedule?.getSelectDateDesc(mSelectDateList))
        if (ListUtil.isEmpty(mSelectDateList)) {
            tv_bottom_click.text = ResourceUtils.getString(R.string.reserve_top)
            tv_bottom_click.isEnabled = false
            tv_top_rights_tips.text = ""
            return
        }
        mSelectConsumeNum = mTopCardSchedule?.getSelectConsumeNum(mSelectDateList)!!
        tv_top_rights_tips.text = mTopCardSchedule?.getTopRightsTips(mSelectConsumeNum)
        tv_bottom_click.text = mTopCardSchedule?.getBottomTxt(mSelectConsumeNum)
        tv_bottom_click.isEnabled = true
    }

    @OnClick(R.id.tv_bottom_click)
    fun bottomClick() {
        if (mTopCardSchedule == null) {
            return
        }
        if (mSelectConsumeNum > mTopCardSchedule!!.topCardNum) {
            if (mTopCardSchedule!!.isBuyPlus) {
                IntentUtils.startLagouWebViewActivity(this, mTopCardSchedule!!.getGoodsUrl)
            }
            if (mTopCardSchedule!!.isApplyGoods) {
                IntentUtils.startRightsApplyActivity(
                    this,
                    RightsScene.TOP_CARD,
                    RightsApplyActivity.NOT_NEED_ID.toLong()
                )
            }
            return
        }
        reserveTopCard()
    }

    /**
     * 预订置顶
     */
    private fun reserveTopCard() {
        AnalyticUtilsB.topSelectSubmit()
        BusinessNetManager.reserveTopCard(
            mdsPositionId,
            mTopCardSchedule!!.cardType,
            mSelectDateList,
            object :
                OnAdapterCommonListenerImpl<TopCardReserve, HttpResponse<TopCardReserve?>?>(this) {
                override fun onSuccess(topCardReserve: TopCardReserve) {
                    DialogUtils.showTopPositionSuccessDialog(
                        baseActivity, topCardReserve.account,
                        object : LgDialogListener() {
                            override fun onRight() {
                                OkBus.getInstance().onEvent(EventTags.B_POSITION_FLUSH_ONLINE)
                                IntentUtils.startPositionMain(baseActivity)
                                ActivityStackHelper.clearAndFinishOtherActivity(HomeActivity::class.java)
                            }
                        })
                }

                override fun onError(errorBean: HttpResponse<TopCardReserve?>?) {
                    if (errorBean == null) {
                        return
                    }
                    if (errorBean.state == TopCardReserve.ReserveState.SCHEDULE_CONFLICT) {
                        val adapterList = errorBean.content?.adapterList
                        if (adapterList != null) {
                            DialogUtils.getScheduleConflict(
                                adapterList.size, adapterList
                            ) { requestCode: Int, resultCode: Int ->
                                if (requestCode == RESULT_OK) {
                                    getTopScheduleData()
                                }
                            }.show(supportFragmentManager, javaClass.simpleName)
                        }
                        return
                    }
                    ToastUtil.show(baseActivity, errorBean.message)
                }

                override fun onNoInternet() {
                    ToastUtil.show(baseActivity, R.string.no_network)
                }

                override fun isShowToast(): Boolean {
                    return false
                }
            })
    }

    override fun getPageId(): String {
        return "1mbu"
    }
}