package com.lagou.lagouee.ui.candidate.detail

import android.content.Context
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.SpannableStringBuilder
import android.text.Spanned
import android.text.TextUtils
import android.text.style.ClickableSpan
import android.text.style.ForegroundColorSpan
import android.view.View
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.RelativeLayout
import android.widget.TextView
import androidx.core.widget.NestedScrollView
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.common.adapter.PreviewAttachmentImgAdapter
import com.common.adapter.PreviewAttachmentImgAdapter.OnLoadCallBack
import com.common.utils.PdfUtils
import com.common.utils.ViewUtils
import com.lagou.baselib.BaseFragment
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ShowLogInfo
import com.lagou.baselib.analytic.definition.b.BPageId
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.utils.DensityUtil
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.help.ClickableMovementMethod
import com.lagou.commonlibs.view.help.NoLineCllikcSpan
import com.lagou.lagouee.bean.candidate.CandidateAttachmentResumeInfo
import com.lagou.lagouee.bean.candidate.CandidateAttachmentResumeParams
import com.lagou.lagouee.bean.candidate.CandidateCountParamsBean
import com.lagou.lagouee.manager.net.ResumeNetManager
import com.lagou.socketchannel.http.HttpResponse

/**
 * @author 作者：ryan.lei
 * @date 创建时间：2022/3/28 20:02
 * @Description 描述：人才详情附件简历
 **/
class CandidateAttachmentResumeFragment : BaseFragment(), View.OnClickListener {
    /**
     * 埋点数据参数
     */
    private var mCountParams: CandidateCountParamsBean? = null

    private var mCandidateAttachmentResumeInfo: CandidateAttachmentResumeInfo? = null

    private var mResumeCoreInfoId: Long = -1
    private var mAttachmentResumeId: String = ""
    private var mUserId: Long = -1
    private var mIsResumeNoPermit = false;
    private var mUserName: String? = ""
    private var mUserIcon: String? = ""

    private var mErrorType = PreviewAttachmentImgAdapter.ERROR_TYPE_NONE
    private var attachResumeImgAdapter: PreviewAttachmentImgAdapter? = null
    private var mEnable: Boolean = true
    private val mainHandler: Handler = Handler(Looper.getMainLooper())
    private val mCacheImageSize: ArrayList<IntArray> = arrayListOf()

    private var svRoot: NestedScrollView? = null
    private var rvResumeImg: RecyclerView? = null
    private var llAttachmentPlaceholder: LinearLayout? = null
    private var ivAttachmentPlaceholder: ImageView? = null
    private var tvAttachmentPlaceholderTitle: TextView? = null
    private var tvAttachmentPlaceholderDesc: TextView? = null
    private var tvCandidateContactTips: TextView? = null

    private val mGray = ResourceUtils.getColor(R.color.color_999999)
    private val mGreen = ResourceUtils.getColor(R.color.theme_text_color)

    private var mResumePermitListener: ResumePermitListener? = null
    private var mResumeClickListener: ResumeClickListener? = null

    companion object {
        private const val KEY_CANDIDATE_COUNT_PARAMS_BEAN = "candidateCountParamsBean"

        fun newInstance(mCountParams: CandidateCountParamsBean): CandidateAttachmentResumeFragment {
            val bundle = Bundle()
            bundle.putSerializable(KEY_CANDIDATE_COUNT_PARAMS_BEAN, mCountParams)
            val fragment = CandidateAttachmentResumeFragment()
            fragment.arguments = bundle
            return fragment
        }
    }

    /**
     * 查看附件简历
     */
    private val seeClickSpan: ClickableSpan = object : NoLineCllikcSpan() {
        override fun onClick(widget: View) {
            skip2AttachmentActivity()
        }
    }

    /**
     * 网络重试
     */
    private val retryClickSpan: ClickableSpan = object : NoLineCllikcSpan() {
        override fun onClick(widget: View) {
            retry()
        }
    }

    override fun getLayoutId(): Int =
        R.layout.fragment_candidate_attachment_resume

    override fun onAttach(context: Context) {
        super.onAttach(context)
        val bundle = arguments
        bundle?.apply {
            mCountParams =
                getSerializable(KEY_CANDIDATE_COUNT_PARAMS_BEAN) as CandidateCountParamsBean?
        }
    }

    override fun init() {
        initParams()
        initView()
        initData()
    }

    private fun initParams() {
        //解析bundle参数，尽量复用之前的逻辑
        mCountParams?.apply {
            mAttachmentResumeId = attachmentResumeId
            mUserId = userId
            mResumeCoreInfoId = resumeCoreInfoId
            mIsResumeNoPermit = isResumeNoPermit
            mUserName = userName
            mUserIcon = userIcon
        }
    }

    private fun initView() {
        svRoot = findViewById(R.id.sv_root)
        rvResumeImg = findViewById(R.id.rv_resume_img)
        llAttachmentPlaceholder = findViewById(R.id.ll_attachment_placeholder)
        ivAttachmentPlaceholder = findViewById(R.id.iv_attachment_placeholder)
        tvAttachmentPlaceholderTitle = findViewById(R.id.tv_attachment_placeholder_title)
        tvAttachmentPlaceholderDesc = findViewById(R.id.tv_attachment_placeholder_desc)
        tvCandidateContactTips = findViewById(R.id.tv_candidate_contact_tips)
        tvCandidateContactTips?.visibility = View.GONE
    }

    private fun initRecyclerview() {
        attachResumeImgAdapter = PreviewAttachmentImgAdapter(mContext)
        attachResumeImgAdapter?.setOnLoadDataListener(object : OnLoadCallBack {
            override fun onSuccess() {
                mErrorType = PreviewAttachmentImgAdapter.ERROR_TYPE_NONE
                rvResumeImg?.visibility = View.VISIBLE
                llAttachmentPlaceholder?.visibility = View.GONE
            }

            override fun onFailed() {
                showResumeFailure(PreviewAttachmentImgAdapter.ERROR_TYPE_SEE)
            }

            override fun onItemClick() {
                skip2AttachmentActivity()
            }
        })
        rvResumeImg?.adapter = attachResumeImgAdapter
    }

    private fun initData() {
        initRecyclerview()
        if (mIsResumeNoPermit) {
            showResumePermitFailure()
            return
        }
        fetchCandidateAttachmentResumeInfo(mAttachmentResumeId)
    }

    private fun fetchCandidateAttachmentResumeInfo(attachmentResumeId: String) {
        if (TextUtils.isEmpty(mAttachmentResumeId)) {
            return
        }
        showResumeLoading()
        ResumeNetManager.getCandidateResumeInfo(attachmentResumeId, object :
            OnAdapterCommonListenerImpl<CandidateAttachmentResumeInfo, HttpResponse<CandidateAttachmentResumeInfo?>>(
                this
            ) {
            override fun onSuccess(resumeInfo: CandidateAttachmentResumeInfo) {
                mCandidateAttachmentResumeInfo = resumeInfo
                showResumeThumbs(
                    mCacheImageSize,
                    mCandidateAttachmentResumeInfo?.thumbFileIds,
                    mCandidateAttachmentResumeInfo?.imgRatios
                )
                reportResumeState()
            }

            override fun onError(errorBean: HttpResponse<CandidateAttachmentResumeInfo?>) {
                showResumeFailure(PreviewAttachmentImgAdapter.ERROR_TYPE_RETRY)
                reportResumeState()
            }

            override fun onNoInternet() {
                showResumeFailure(PreviewAttachmentImgAdapter.ERROR_TYPE_RETRY)
            }

            override fun isShowToast(): Boolean {
                return false
            }
        })
    }

    private fun showResumeThumbs(
        cacheImageSize: ArrayList<IntArray>?,
        thumbList: List<String?>?,
        imgRatios: List<Float>?
    ) {
        if (ListUtil.size(thumbList) > ListUtil.size(imgRatios)
            || ListUtil.isEmpty(thumbList) || ListUtil.isEmpty(imgRatios)
        ) {
            // 缩略图数据不合规，显示点击查看
            showResumeFailure(PreviewAttachmentImgAdapter.ERROR_TYPE_SEE)
            return
        }
        showResumeLoading()
        cacheImageSize?.clear()
        tvCandidateContactTips?.visibility = View.VISIBLE
        attachResumeImgAdapter?.refreshData(thumbList)
        val params = rvResumeImg?.layoutParams as RelativeLayout.LayoutParams
        val screenWidth = resources.displayMetrics.widthPixels
        val imgWidth = screenWidth - params.leftMargin - params.rightMargin
        for (i in thumbList!!.indices) {
            val ratio: Float = imgRatios!![i]
            val imgHeight = (imgWidth / ratio + 0.5f).toInt()
            cacheImageSize?.add(intArrayOf(imgWidth, imgHeight))
        }
    }

    private fun showResumeLoading() {
        llAttachmentPlaceholder?.visibility = View.VISIBLE
        llAttachmentPlaceholder?.setBackgroundColor(ResourceUtils.getColor(R.color.color_fcfcfc))
        rvResumeImg?.visibility = View.INVISIBLE
        ViewUtils.ditherClick(llAttachmentPlaceholder, null)
        val layoutParams = ivAttachmentPlaceholder?.layoutParams as LinearLayout.LayoutParams
        layoutParams.topMargin = DensityUtil.dip2px(mContext, 30f)
        ivAttachmentPlaceholder?.setImageResource(R.drawable.jd_img_jianlijiazaizhong_b)
        tvAttachmentPlaceholderTitle?.visibility = View.GONE
        tvAttachmentPlaceholderDesc?.text = ResourceUtils.getString(R.string.loading_resume)
        tvAttachmentPlaceholderDesc?.setTextColor(mGray)
    }

    private fun showResumeFailure(errorType: Int) {
        mErrorType = errorType
        llAttachmentPlaceholder?.visibility = View.VISIBLE
        llAttachmentPlaceholder?.setBackgroundColor(ResourceUtils.getColor(R.color.color_fcfcfc))
        rvResumeImg?.visibility = View.INVISIBLE
        ViewUtils.ditherClick(llAttachmentPlaceholder, this)
        val layoutParams = ivAttachmentPlaceholder?.layoutParams as LinearLayout.LayoutParams
        layoutParams.topMargin = DensityUtil.dip2px(mContext, 80f)
        ivAttachmentPlaceholder?.setImageResource(R.drawable.jd_img_jiazaishibai_b)
        tvAttachmentPlaceholderTitle?.visibility = View.GONE
        val builder = SpannableStringBuilder(ResourceUtils.getString(R.string.resume_too_big))
        val cache = builder.length
        builder.setSpan(ForegroundColorSpan(mGray), 0, cache, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
        builder.append(
            if (isRetry())
                ResourceUtils.getString(R.string.click_retry)
            else
                ResourceUtils.getString(R.string.click_see)
        )
        builder.setSpan(
            if (isRetry()) retryClickSpan else seeClickSpan,
            cache,
            builder.length,
            Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
        )
        builder.setSpan(
            ForegroundColorSpan(mGreen),
            cache,
            builder.length,
            Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
        )
        tvAttachmentPlaceholderDesc?.movementMethod = ClickableMovementMethod.getInstance()
        tvAttachmentPlaceholderDesc?.text = builder
    }

    /**
     * 显示简历未授权错误
     */
    private fun showResumePermitFailure() {
        llAttachmentPlaceholder?.visibility = View.VISIBLE
        llAttachmentPlaceholder?.setBackgroundColor(ResourceUtils.getColor(R.color.transparent))
        rvResumeImg?.visibility = View.INVISIBLE
        val layoutParams = ivAttachmentPlaceholder?.layoutParams as LinearLayout.LayoutParams
        layoutParams.topMargin = DensityUtil.dip2px(mContext, 80f)
        ivAttachmentPlaceholder?.setImageResource(R.drawable.public_img_blank_seen)
        tvAttachmentPlaceholderTitle?.visibility = View.VISIBLE
        tvAttachmentPlaceholderTitle?.text =
            ResourceUtils.getString(R.string.candidate_attachment_resume_no_permit)
        tvAttachmentPlaceholderDesc?.text =
            ResourceUtils.getString(R.string.candidate_resume_no_permit_desc)
        mResumePermitListener?.onResumePermitFailure()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.ll_attachment_placeholder -> skip2AttachmentActivity()
        }
    }

    /**
     * 跳转附件简历
     */
    fun skip2AttachmentActivity() {
        if (!mEnable) {
            // 防止重复触发
            return
        }
        mEnable = false
        mainHandler.postDelayed({ mEnable = true }, 1000)
        if (!PdfUtils.checkResumeValid(
                mCandidateAttachmentResumeInfo?.hideContactPdfUrl,
                mCandidateAttachmentResumeInfo?.hideContactImgUrls
            )
        ) {
            return
        }
        val params = CandidateAttachmentResumeParams.Builder()
            .userId(mUserId)
            .resumeCoreInfoId(mResumeCoreInfoId)
            .attachmentResumeId(mAttachmentResumeId)
            .cacheImageSize(mCacheImageSize)
            .thumbnailImgUrls(mCandidateAttachmentResumeInfo?.thumbFileIds)
            .imgUrls(mCandidateAttachmentResumeInfo?.hideContactImgUrls)
            .thumbRatios(mCandidateAttachmentResumeInfo?.imgRatios)
            .pdfUrl(mCandidateAttachmentResumeInfo?.hideContactPdfUrl)
            .userIcon(mUserIcon)
            .username(mUserName)
            .build()
        //回调到最外层的CandidateCommonPage做跳转操作,因为要用到共享元素动画,共享控件为viewpager
        mResumeClickListener?.onResumeClick(params)
    }

    fun scroll2Top() {
        svRoot?.fling(0)
        svRoot?.fullScroll(View.FOCUS_UP)
    }

    private fun retry() {
        fetchCandidateAttachmentResumeInfo(mAttachmentResumeId)
    }

    private fun isRetry(): Boolean {
        return PreviewAttachmentImgAdapter.ERROR_TYPE_RETRY == mErrorType
    }

    fun isResumeNoPermit(): Boolean {
        return mIsResumeNoPermit
    }

    fun setResumePermitListener(listener: ResumePermitListener?) {
        mResumePermitListener = listener
    }

    interface ResumePermitListener {
        fun onResumePermitFailure()
    }

    fun setResumeClickListener(listener: ResumeClickListener?) {
        mResumeClickListener = listener
    }

    interface ResumeClickListener {
        fun onResumeClick(params: CandidateAttachmentResumeParams)
    }

    private fun reportResumeState() {
        val showLogInfo = ShowLogInfo()
        showLogInfo.setPage_Id(BPageId.fU00)
        showLogInfo.setAddress_Id("m1u2q")
        showLogInfo.addShowProp("resumeId", mAttachmentResumeId)
        showLogInfo.addShowProp("result", getReportState())
        AnalyticHelper.getInstance().sendShowInfo(showLogInfo)
    }

    private fun getReportState(): String {
        if (mCandidateAttachmentResumeInfo == null) {
            return ResourceUtils.getString(R.string.request_failure)
        }
        if (TextUtils.isEmpty(mCandidateAttachmentResumeInfo!!.hideContactPdfUrl)) {
            return ResourceUtils.getString(R.string.not_have_pdf)
        }
        if (ListUtil.isEmpty(mCandidateAttachmentResumeInfo!!.hideContactImgUrls)) {
            return ResourceUtils.getString(R.string.not_have_image)
        }
        return ResourceUtils.getString(R.string.success)
    }
}