package com.lagou.lagouee.ui.dialog

import android.content.pm.ActivityInfo
import android.os.Build
import android.text.Html
import butterknife.OnClick
import com.alpha.lagouapk.R
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ClickInfo
import com.lagou.baselib.analytic.bean.json.ShowLogInfo
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.inter.OnSingleMdTwoPsListener
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.NumberUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.component.ui.itemDecoration.CustomDividerItemDecoration
import com.lagou.lagouee.bean.BatchChatTalentBean
import com.lagou.lagouee.bean.SubmitBatchChatBean
import com.lagou.lagouee.bean.TalentCardBean
import com.lagou.lagouee.bean.UserBusinessRightsBean
import com.lagou.lagouee.manager.net.BusinessNetManager
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.ui.adapter.BatchChatTalentAdapter
import com.lagou.lagouee.ui.dialog.HomeBatchChatDialogActivity.Companion.ROUTER_URL_PREFIX
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.dialog_home_batch_chat.*

/**
 * Created by mihao on 10/20/22
 * 首页一键开聊弹窗
 */
@RouterRule("$ROUTER_URL_PREFIX?pushMsgId={pushMsgId}&suggestType={suggestType}&positionId={positionId}&talentId={talentId}")
class HomeBatchChatDialogActivity : BaseActivity() {

    private var mTalentList: ArrayList<TalentCardBean>? = null
    private var batchChatTalentAdapter: BatchChatTalentAdapter? = null
    private var mBatchChatTalentBean: BatchChatTalentBean? = null
    private var selectSet: HashSet<Int>? = null

    /**
     * 购买权益成功
     */
    private val mPaySuccessEvent = Event { getBusinessRights() }

    companion object {
        const val ROUTER_URL_PREFIX = "lagouhr://lagou.com/talkRecommend"
        const val INTENT_KEY_TALENT_BEAN = "talent_bean"
    }

    override fun getContentLayoutId() = R.layout.dialog_home_batch_chat

    override fun init() {
        if (Build.VERSION.SDK_INT != Build.VERSION_CODES.O) {
            requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
        }
        initRecyclerView()
        initData()
        OkBus.getInstance().register(BEventTags.PAY_SUCCESS_COMMUNICATE_USER, mPaySuccessEvent)
        reportShow()
    }

    private fun initRecyclerView() {
        mTalentList = ArrayList()
        batchChatTalentAdapter = BatchChatTalentAdapter(baseActivity, mTalentList)
        batchChatTalentAdapter!!.setOnItemCheckListener(OnSingleMdTwoPsListener { position: Int?, talentCardBean: TalentCardBean? ->
            if (talentCardBean != null) {
                if (talentCardBean.isChecked) {
                    selectSet!!.add(talentCardBean.userId)
                } else {
                    selectSet!!.remove(talentCardBean.userId)
                }
                updateClickText()
                updateRightsText()
            }
        })
        rv_batch_chat.adapter = batchChatTalentAdapter
        val itemDecoration = CustomDividerItemDecoration.newBuilder(baseActivity)
            .setLeftSpace(10).setRightSpacce(10)
            .setColor(ResourceUtils.getColor(R.color.color_e8e9eb))
            .setDividerWidth(0.5f).build()
        rv_batch_chat.addItemDecoration(itemDecoration)
        rv_batch_chat.isNestedScrollingEnabled = false
    }

    private fun initData() {
        mBatchChatTalentBean =
            intent.getSerializableExtra(INTENT_KEY_TALENT_BEAN) as BatchChatTalentBean?
        if (mBatchChatTalentBean == null || ListUtil.isEmpty(mBatchChatTalentBean?.showTalentList)) {
            finish()
            return
        }
        selectSet = HashSet()
        mTalentList!!.clear()
        mTalentList!!.addAll(mBatchChatTalentBean!!.showTalentList)
        batchChatTalentAdapter!!.setBatchChatData(mBatchChatTalentBean)
        batchChatTalentAdapter!!.notifyDataSetChanged()
        for (talentCardBean in mBatchChatTalentBean!!.showTalentList) {
            if (talentCardBean == null) {
                continue
            }
            if (talentCardBean.isChecked) {
                selectSet!!.add(talentCardBean.userId)
            }
        }
        tv_batch_chat_desc.text = ResourceUtils.getString(
            R.string.home_batch_chat_dialog_desc,
            mBatchChatTalentBean!!.showTalentList.size,
            mBatchChatTalentBean!!.positionDesc
        )
        updateClickText()
        updateRightsText()
    }

    /**
     * 设置底部按钮文案
     */
    private fun updateClickText() {
        val selectSize = selectSet!!.size
        tv_batch_chat_click.isEnabled = selectSize != 0
        tv_batch_chat_click.text =
            if (selectSize == 0) ResourceUtils.getString(R.string.talent_batch_chat_no_select)
            else ResourceUtils.getString(R.string.talent_batch_chat_select_num, selectSize)
    }

    private fun updateRightsText() {
        val remainRights = mBatchChatTalentBean!!.remainRights
        if (remainRights < selectSet!!.size) {
            tv_batch_chat_rights.text = Html.fromHtml(
                ResourceUtils.getString(
                    R.string.talent_batch_chat_rights_num_red,
                    NumberUtils.formatZero(remainRights)
                )
            )
        } else {
            tv_batch_chat_rights.text = Html.fromHtml(
                ResourceUtils.getString(
                    R.string.talent_batch_chat_rights_num_green,
                    NumberUtils.formatZero(remainRights)
                )
            )
        }
    }

    /**
     * 获取一键开聊权益信息
     */
    private fun getBusinessRights() {
        BusinessNetManager.getBusinessRights(BusinessNetManager.BaseGoodsId.BATCH_CHAT_ID, object :
            OnAdapterCommonListenerImpl<UserBusinessRightsBean, HttpResponse<UserBusinessRightsBean?>?>(
                this
            ) {
            override fun onSuccess(rightsBean: UserBusinessRightsBean) {
                mBatchChatTalentBean!!.remainRights = rightsBean.lastNum
                updateRightsText()
            }
        })
    }

    @OnClick(R.id.iv_close_dialog)
    fun closeDialog() {
        finish()
    }

    @OnClick(R.id.tv_batch_chat_click)
    fun batchChatClick() {
        reportClick()
        BusinessNetManager.createBatchChat(getSubmitTalent(), mBatchChatTalentBean!!.lgPositionId,
            object :
                OnAdapterCommonListenerImpl<SubmitBatchChatBean, HttpResponse<SubmitBatchChatBean?>?>(
                    this
                ) {
                override fun onSuccess(submitBatchChatBean: SubmitBatchChatBean) {
                    if (submitBatchChatBean.isBuyStatus) {
                        IntentUtils.startLagouWebViewActivity(
                            baseActivity,
                            submitBatchChatBean.buyUrl
                        )
                        return
                    }
                    ToastUtil.show(
                        mContext,
                        ResourceUtils.getString(R.string.batch_chat_success_tips, selectSet!!.size)
                    )
                    finish()
                }
            })
    }

    private fun getSubmitTalent(): String {
        val builder = StringBuilder()
        for (talentId in selectSet!!) {
            builder.append(talentId).append(",")
        }
        val index = builder.lastIndexOf(",")
        if (index >= 0) {
            builder.delete(index, builder.length)
        }
        return builder.toString()
    }

    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance().unRegister(mPaySuccessEvent)
    }

    private fun reportShow() {
        val showLogInfo = ShowLogInfo()
        showLogInfo.setPage_Id("f1u1t")
        showLogInfo.setAddress_Id("g1u1u")
        showLogInfo.addShowProp("tal_card_num", mBatchChatTalentBean?.showTalentList?.size)
        AnalyticHelper.getInstance().sendShowInfo(showLogInfo)
    }

    private fun reportClick() {
        val clickInfo = ClickInfo()
        clickInfo.page_id = "f1u1t"
        clickInfo.address_id = "h1u1v"
        clickInfo.addClick_props("tal_chat_num", selectSet?.size)
        AnalyticHelper.getInstance().sendClickInfo(clickInfo)
    }
}