package com.lagou.lagouee.ui.dialog

import android.content.pm.ActivityInfo
import android.os.Build
import android.text.TextUtils
import com.ApiService
import com.alpha.lagouapk.R
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.web.router.RouteUtils
import com.lagou.lagouee.bean.HrAchievementInfoBean
import com.lagou.lagouee.bean.HrRankInfoBean
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse

/**
 * @author 作者：ryan.lei
 * @date 创建时间：2021/9/16 11:51
 * @Description 描述：H5打开成就/排行榜弹窗的中转页面
 *                  playbillID:海报ID,
 *                  playbillType：海报类型-0:招聘者周榜. 1:成就海报,
 *                  playbillDetailType:每种海报具体 1=最受欢迎榜 2=最会撩榜 3=最具潜力榜 4=最具影响力榜 5=最辛劳榜 6=披星戴月卡 7=持之以恒卡 8=不辞辛劳卡,
 *                  playbillPid:上报pagID,
 *                  playbillAid:上报aid
 **/
@RouterRule(
    "lagouhr://lagou.com/playbillAlert_schedule?playbillID={playbillID}&playbillType={playbillType}&" +
            "playbillDetailType={playbillDetailType}&playbillPid={playbillPid}&playbillAid={playbillAid}"
)
class HrRankingAndAchievementDialogOpenActivity : BaseActivity() {

    /**
     * 成就ID/排行榜ID (对应RouteUrl中的playbillID)
     */
    private var mId: String = ""

    /**
     * 要打开的弹窗类型 0:招聘者周榜, 1:成就海报 (对应RouteUrl中的playbillType)
     */
    private var mDialogType: Int? = null

    /**
     * 每种海报具体类型:
     * 1=最受欢迎榜
     * 2=最会撩榜
     * 3=最具潜力榜
     * 4=最具影响力榜
     * 5=最辛劳榜
     * 6=披星戴月卡
     * 7=持之以恒卡
     * 8=不辞辛劳卡
     */
    private var mDialogDetailType: Int? = null

    /**
     * 上报pageId
     */
    private var mPageId: String = ""

    /**
     * 上报aid
     */
    private var mAid: String = ""

    companion object {
        const val DIALOG_TYPE_RANKING = 0
        const val DIALOG_TYPE_ACHIEVEMENT = 1
    }

    override fun getContentLayoutId(): Int =
        R.layout.activity_hr_ranking_and_achievement_dialog_open

    override fun getStatusBarColor(): Int = R.color.color_cc000000

    override fun init() {
        if (intent == null) {
            finish()
            return
        }
        val routeUrl = RouteUtils.getRouteUrl(intent)
        if (TextUtils.isEmpty(routeUrl)) {
            finish()
            return
        }
        mId = RouteUtils.getQueryParameter(routeUrl, "playbillID", String::class.java)
        mDialogType = RouteUtils.getQueryParameter(routeUrl, "playbillType", Int::class.java)
        mDialogDetailType =
            RouteUtils.getQueryParameter(routeUrl, "playbillDetailType", Int::class.java)
        mPageId = RouteUtils.getQueryParameter(routeUrl, "playbillPid", String::class.java)
        mAid = RouteUtils.getQueryParameter(routeUrl, "playbillAid", String::class.java)

        if (mDialogType == DIALOG_TYPE_RANKING) {
            requestHrRankingDialog(mId, mPageId, mAid)
        } else if (mDialogType == DIALOG_TYPE_ACHIEVEMENT) {
            requestHrAchievementDialog(mId, mPageId, mAid)
        }

        if (Build.VERSION.SDK_INT != Build.VERSION_CODES.O) {
            requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
        }
    }

    override fun finish() {
        super.finish()
        overridePendingTransition(R.anim.fade_in, R.anim.fade_out)
    }

    /**
     * 打开成就卡弹窗
     */
    private fun requestHrAchievementDialog(id: String, pageId: String, aid: String) {
        ApiService.api.getHrAchievementInfo(id)
            .enqueue(object : BaseCallback<HrAchievementInfoBean>() {
                override fun onSuccess(
                    request: HttpRequest<*>?,
                    response: HttpResponse<HrAchievementInfoBean>?
                ) {
                    if (response == null || response.content == null) {
                        return
                    }
                    val bean = response.content
                    DialogUtils.showHrAchievementDialog(
                        bean,
                        pageId,
                        aid,
                        this@HrRankingAndAchievementDialogOpenActivity
                    )
                }
            })
    }

    /**
     * 打开排行榜弹窗
     */
    private fun requestHrRankingDialog(id: String, pageId: String, aid: String) {
        ApiService.api.getHrRankInfo(id).enqueue(object : BaseCallback<HrRankInfoBean>() {
            override fun onSuccess(
                request: HttpRequest<*>?,
                response: HttpResponse<HrRankInfoBean>?
            ) {
                if (response == null || response.content == null) {
                    return
                }
                val bean = response.content
                DialogUtils.showHrRankingDialog(
                    bean,
                    pageId,
                    aid,
                    this@HrRankingAndAchievementDialogOpenActivity
                )
            }
        })
    }
}