package com.lagou.lagouee.ui.dialog.business

import android.text.TextUtils
import android.view.View
import android.view.ViewGroup
import butterknife.OnClick
import butterknife.OnLongClick
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.SystemUtils
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.transform.PartialRoundTransform
import com.lagou.commonlibs.ui.dialog.BaseDialogFragment
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.business.ObtainRightsStrategy
import com.lagou.lagouee.utils.IntentUtils
import kotlinx.android.synthetic.main.dialog_publish_position_rights.*

/**
 * Created by mihao on 10/18/22
 * 发布职位引导购买权益弹窗
 */
class BuyPublishPositionRightsDialog : BaseDialogFragment() {

    private var mPopInfoBean: ObtainRightsStrategy.PopInfoBean? = null

    override fun getLayoutId() = R.layout.dialog_publish_position_rights

    companion object {
        fun newInstance(popInfoBean: ObtainRightsStrategy.PopInfoBean): BuyPublishPositionRightsDialog {
            val buyPublishPositionRightsDialog = BuyPublishPositionRightsDialog()
            buyPublishPositionRightsDialog.mPopInfoBean = popInfoBean
            return buyPublishPositionRightsDialog
        }
    }

    override fun initConfigAtCreateView() {
        super.initConfigAtCreateView()
        dialog?.setCanceledOnTouchOutside(false)
        isCancelable = false
    }

    override fun fillUI() {
        super.fillUI()
        val params: ViewGroup.LayoutParams = iv_dialog_bg.layoutParams
        params.width = width
        params.height = params.width * 432 / 903
        iv_dialog_bg.layoutParams = params
        ImageLoadUtils.with(activity)
            .load(R.drawable.postosition_bg)
            .bitmapTransform(PartialRoundTransform(8).setNeedCorner(true, true, false, false))
            .into(iv_dialog_bg)

        tv_dialog_title.text = mPopInfoBean?.title
        tv_dialog_subtitle.text = mPopInfoBean?.subTitle
        ImageLoadUtils.with(activity).load(mPopInfoBean?.portrait).into(iv_user_portrait)
        tv_dialog_content.text = mPopInfoBean?.greeting + "\n" + mPopInfoBean?.popContent
        if (TextUtils.isEmpty(mPopInfoBean?.servicePhone)) {
            tv_sale_phone.visibility = View.GONE
        } else {
            tv_sale_phone.visibility = View.VISIBLE
            tv_sale_phone.text = mPopInfoBean?.servicePhone
        }
        if (TextUtils.isEmpty(mPopInfoBean?.serviceEmail)) {
            tv_sale_email.visibility = View.GONE
        } else {
            tv_sale_email.visibility = View.VISIBLE
            tv_sale_email.text = mPopInfoBean?.serviceEmail
        }
    }

    @OnClick(R.id.tv_sale_phone)
    fun call() {
        BaseUtils.dialNumber(activity, mPopInfoBean?.servicePhone)
    }

    @OnLongClick(R.id.tv_sale_email)
    fun copyEmail() {
        SystemUtils.copyClipboard(activity, mPopInfoBean?.serviceEmail)
    }

    @OnClick(R.id.tv_buy_tights)
    fun buyRights() {
        IntentUtils.startLagouWebViewActivity(activity, mPopInfoBean?.plusIntroUrl)
        dismiss()
    }

    @OnClick(R.id.iv_dialog_close)
    fun closeDialog() {
        dismiss()
    }

    override fun getWidth() = ResourceUtils.getDimenSize(R.dimen.dp_300)

}