package com.lagou.lagouee.ui.interview

import android.graphics.Paint
import androidx.recyclerview.widget.LinearLayoutManager
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.widget.FrameLayout
import android.widget.LinearLayout
import android.widget.TextView
import androidx.recyclerview.widget.DividerItemDecoration
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.UserHeadUtils
import com.lagou.annotation.apt.RouterRule
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.chat.chatlibrary.manager.ChatStatusManager
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.commonlibs.web.router.RouteUtils
import com.lagou.lagouee.bean.InterviewData
import com.lagou.lagouee.bean.jsonbean.interview.BInterviewDetailRes
import com.lagou.lagouee.manager.net.InterviewNetManager
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.ui.interview.adapter.BNewInterviewRecordAdapter
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.activity_interview_detail_b.*
import kotlinx.android.synthetic.main.layout_calendar_empty.*

/**
 * @date 创建时间：2020/7/23
 * @author 作者：codeman
 * @Description  描述：B端面试详情页
 * @version
 */

@RouterRule(BInterviewDetailActivity.URI)
class BInterviewDetailActivity : BaseActivity() {

    private var interviewId: Long? = null
    private var detailRes: BInterviewDetailRes? = null
    private var interviewRecordAdapter: BNewInterviewRecordAdapter? = null
    private val dp_14_05 = ResourceUtils.getDimenSize(R.dimen.dp_14_05)
    private val dp_15 = ResourceUtils.getDimenSize(R.dimen.dp_15)
    private val bottomViews = mutableListOf<View>()

    companion object {
        const val KEY_INTERVIEW_ID = "key_interview_id"
        const val URI = "lagouhr://lagou.com/interview_detail?interviewid={interviewid}"
    }

    private val eventFlush = Event { getInterviewDetail() }

    private val eventFinish = Event { finish() }

    private val commonListenerImpl =
            object : OnAdapterCommonListenerImpl<BInterviewDetailRes, HttpResponse<BInterviewDetailRes>>(this) {
                override fun onSuccess(t: BInterviewDetailRes?) {
                    super.onSuccess(t)
                    detailRes = t
                    showNormal()
                    fillUi(t)
                }

                override fun onError(errorBean: HttpResponse<BInterviewDetailRes>?) {
                    super.onError(errorBean)
                    if (errorBean?.state == 2003005) showOther(errorBean.message)
                }

                override fun onNoInternet() {
                    super.onNoInternet()
                    showWifi()
                }
            }

    /**
     * 发起视频
     */
    private val btnVideoClick = View.OnClickListener {

        AnalyticHelper.getInstance().sendClickInfo("1qqp")
        detailRes?.apply {
            IntentUtils.startChatActivityVideo(this@BInterviewDetailActivity, userId.toLong(), positionId.toLong())
        }
    }

    /**
     * 评价
     */
    private val btnCommentClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qqv")
        detailRes?.apply {
            IntentUtils.startResumeEvaluate(this@BInterviewDetailActivity, orderResumeId, name)
        }
    }

    /**
     * 再次约面
     */
    private val btnAgainClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qqt")
        detailRes?.apply {
            val interviewData = InterviewData.newInstance(resumeStageCode, isAfterInterview, orderResumeId, name)
            IntentUtils.startInviteInterviewActivity(this@BInterviewDetailActivity, interviewData)
        }
    }

    /**
     * 修改面试
     */
    private val btnEditClick = View.OnClickListener {
        AnalyticHelper.getInstance().sendClickInfo("1qqr")
        detailRes?.apply {
            val interviewData = InterviewData.newInstance(resumeStageCode, isAfterInterview, orderResumeId, name)
            IntentUtils.startInviteInterviewActivity(this@BInterviewDetailActivity, interviewData)
        }
    }

    override fun getContentLayoutId() = R.layout.activity_interview_detail_b

    override fun init() {
        interviewId = if (RouteUtils.matchRule(intent, URI)) {
            RouteUtils.getQueryParameter(intent, "interviewid", Long::class.javaPrimitiveType)
        } else {
            intent?.getLongExtra(KEY_INTERVIEW_ID, -1)
        }
        initRecycleView()
        initListener()
        getInterviewDetail()
        ChatStatusManager.getInstance().checkVideo()
    }

    private fun initRecycleView() {
        recycle_interview_record.isNestedScrollingEnabled = false
        interviewRecordAdapter = BNewInterviewRecordAdapter(this)
        recycle_interview_record?.apply {
            adapter = interviewRecordAdapter
            layoutManager = LinearLayoutManager(mContext)
            var decoration = DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL)
            decoration.setDrawable(ResourceUtils.getDrawable(R.drawable.shape_no_size))
            addItemDecoration(decoration)
        }
    }

    private fun getInterviewDetail() {
        if (interviewId == -1L) {
            return
        }

        InterviewNetManager.getInterviewDetail(interviewId, commonListenerImpl)
    }

    private fun initListener() {
        ltitle_bar.setLeftImgListener {
            AnalyticHelper.getInstance().sendClickInfo("1qqi")
            finish()
        }

        tv_see_resume.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qqj")
            //去简历详情
            detailRes?.orderResumeId?.let {
                IntentUtils.startResumeActivityByResumeId(this, it)
            }
        }
        tv_contact_ta.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qqk")
            detailRes?.apply {
                DialogUtils.showContactTaDialog(this@BInterviewDetailActivity, userId.toLong(), positionId.toLong(), phone)
            }
        }

        rel_interview_position.setOnClickListener {
            AnalyticHelper.getInstance().sendClickInfo("1qqm")
            //去职位详情
            detailRes?.positionId?.let {
                IntentUtils.startPositionDetailActivity(this, it)
            }
        }
        wifi.setReLoadListener {
            getInterviewDetail()
        }

        OkBus.getInstance()
                .register(BEventTags.INTERVIEW_INVITE_SUCCESS, eventFlush)
                .register(BEventTags.FLUSH_INTERVIEW_DETAIL, eventFlush)
                .register(BEventTags.INTERVIEW_AGAIN_FINISH, eventFinish)
                .register(BEventTags.INTERVIEW_AGAIN_FINISH, eventFlush)
    }

    private fun showWifi() {
        constrain_empty.visibility = View.GONE
        wifi.visibility = View.VISIBLE
        nest_root.visibility = View.GONE
    }

    private fun showNormal() {
        constrain_empty.visibility = View.GONE
        wifi.visibility = View.GONE
        nest_root.visibility = View.VISIBLE
    }

    private fun showOther(message: String?) {
        wifi.visibility = View.GONE
        nest_root.visibility = View.GONE
        constrain_empty.visibility = View.VISIBLE
        tv_state.text = message
    }

    private fun fillUi(detailRes: BInterviewDetailRes?) {
        detailRes?.apply {

            //1 候选人信息部分
            iv_interview_icon?.apply {
                UserHeadUtils.setUserHeader(this, headPic)
            }
            iv_interview_sex?.apply {
                when (sex) {
                    "男" -> setImageResource(R.drawable.icon_male_flag)
                    "女" -> setImageResource(R.drawable.icon_female_flag)
                    else -> setImageDrawable(null)
                }
            }
            tv_interview_name?.text = name
            tv_talent_company?.text = companyName
            tv_talent_skill?.text = positionName
            tv_except_salary?.text = expectSalary
            fillWorkInfo()

            //2 面试详情部分
            fillInterview()

            //3 面试状态记录问题
            if (interviewStatusList == null || interviewStatusList.isEmpty()) {
                lin_interview_record?.visibility = View.GONE
                return
            }
            lin_interview_record?.visibility = View.VISIBLE
            interviewRecordAdapter?.setData(interviewStatusList)

            //4 按钮展示文案和状态
            fillInterviewBtn()
        }
    }

    /***
     * 底部按钮点击事件
     */
    private fun BInterviewDetailRes.fillInterviewBtn() {
        //1 底部造作区域是否隐藏
        if (!isShowBottomArea) {
            lin_btn_bottom.visibility = View.GONE
            return
        }

        lin_btn_bottom.visibility = View.VISIBLE
        //2 特殊样式视频区域是否展示
        if (isShowSpecialVideo) {
            lin_btn_bottom.setPadding(0, dp_14_05, dp_15, dp_14_05)
            lin_video.visibility = View.VISIBLE
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qqn")
            lin_video.setOnClickListener(btnVideoClick)
        } else {
            lin_btn_bottom.setPadding(dp_15, dp_14_05, dp_15, dp_14_05)
        }
        for (view in bottomViews) {
            lin_btn_bottom.removeView(view)
        }
        bottomViews.clear()
        var index = 0
        for (interviewBtnStyle in btnList) {
            interviewBtnStyle?.apply {
                if (!isSpecialBtn) {
                    val btn = TextView(mContext)
                    bottomViews.add(btn)
                    index++
                    btn.apply {
                        val params = LinearLayout.LayoutParams(0, ResourceUtils.getDimenSize(R.dimen.dp_46))
                        if (index > 1) {
                            params.leftMargin = ResourceUtils.getDimenSize(R.dimen.dp_10)
                        }
                        params.weight = 1.0F
                        background = ResourceUtils.getDrawable(btnBackground)
                        gravity = Gravity.CENTER
                        setTextColor(ResourceUtils.getColor(btnTxtColor))
                        textSize = 16F
                        text = btnTxt
                        layoutParams = params
                        if (interviewBtnStyle.isEnable) {
                            alpha = 1.0F
                            isEnabled = true
                        } else {
                            alpha = 0.8F
                            isEnabled = false
                        }
                        handleBtnClick(interviewBtnStyle, btn)
                    }
                    lin_btn_bottom.addView(btn)
                }
            }
        }
    }

    private fun handleBtnClick(interviewBtnStyle: BInterviewDetailRes.InterviewBtnStyle, btn: TextView) {
        if (interviewBtnStyle.isAgainInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qqs")
            btn.setOnClickListener(btnAgainClick)
            return
        }
        if (interviewBtnStyle.isChangeInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qqq")
            btn.setOnClickListener(btnEditClick)
            return
        }
        if (interviewBtnStyle.isCommentInterview) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qqu")
            btn.setOnClickListener(btnCommentClick)
            return
        }

        if (interviewBtnStyle.isSendVideo) {
            AnalyticHelper.getInstance().sendShowInfo(pageId,"1qqn")
            btn.setOnClickListener(btnVideoClick)
            return
        }
    }

    private fun BInterviewDetailRes.fillInterview() {
        if (isShowContactTa) {
            vm_occupy.visibility = View.VISIBLE
            vm_occupy2.visibility = View.VISIBLE
            tv_contact_ta.visibility = View.VISIBLE
        } else {
            vm_occupy.visibility = View.GONE
            vm_occupy2.visibility = View.GONE
            tv_contact_ta.visibility = View.GONE
        }


        if (!TextUtils.isEmpty(interviewType)) {
            lin_form_title?.visibility = View.VISIBLE
            tv_interview_form_content?.text = interviewType
        } else {
            lin_form_title?.visibility = View.GONE
        }
        if (!TextUtils.isEmpty(interviewTime)) {
            lin_time_title?.visibility = View.VISIBLE
            tv_interview_time_content?.text = interviewTime
        } else {
            lin_time_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(linkMan)) {
            lin_contact_title?.visibility = View.VISIBLE
            tv_interview_contact_content?.text = linkMan
        } else {
            lin_contact_title?.visibility = View.GONE
        }
        if (!TextUtils.isEmpty(linkPhone)) {
            lin_contact_phone_title?.visibility = View.VISIBLE
            tv_interview_contact_phone_content?.text = StringUtil.getMaskString(linkPhone)
            tv_interview_contact_phone_content.paint.flags = Paint.UNDERLINE_TEXT_FLAG //下划线
            tv_interview_contact_phone_content.paint.isAntiAlias = true//抗锯齿
            tv_interview_contact_phone_content.setOnClickListener {
                //调起拨号页面
                BaseUtils.dialNumber(this@BInterviewDetailActivity, linkPhone)
            }
        } else {
            lin_contact_phone_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(address)) {
            lin_address_title?.visibility = View.VISIBLE
            tv_interview_address_content?.text = address
        } else {
            lin_address_title?.visibility = View.GONE
        }

        if (!TextUtils.isEmpty(showInterviewPosition)) {
            rel_interview_position?.visibility = View.VISIBLE
            tv_interview_position_content?.text = showInterviewPosition
        } else {
            rel_interview_position?.visibility = View.GONE
        }
        if (!TextUtils.isEmpty(addInfo)) {
            lin_remark_title?.visibility = View.VISIBLE
            tv_interview_remark_content?.text = addInfo
        } else {
            lin_remark_title?.visibility = View.GONE
        }
    }

    /***
     * 处理带竖线的工作信息逻辑，之所以使用几个TextView是为了控制不同内容显示长度差异化，没有采取VerticalCenterImageSpan
     */
    private fun BInterviewDetailRes.fillWorkInfo() {
        //工作信息
        if (!TextUtils.isEmpty(workYear)) {
            tv_talent_experience?.visibility = FrameLayout.VISIBLE
            tv_talent_experience?.text = workYear
        } else {
            tv_talent_experience?.visibility = FrameLayout.GONE
        }
        if (!TextUtils.isEmpty(workYear)) {
            tv_talent_education?.visibility = View.VISIBLE
            tv_talent_education?.text = education
        } else {
            tv_talent_education?.visibility = FrameLayout.GONE
        }
        if (!TextUtils.isEmpty(age)) {
            tv_talent_age?.visibility = View.VISIBLE
            tv_talent_age?.text = age
        } else {
            tv_talent_age?.visibility = FrameLayout.GONE
        }
        //竖线隐藏和展示逻辑
        if (tv_talent_experience?.visibility == View.VISIBLE && tv_talent_education?.visibility == View.VISIBLE) {
            v_interview_history_gap?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap?.visibility = View.GONE
        }
        if (tv_talent_education?.visibility == View.VISIBLE && tv_talent_age?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
        if (tv_talent_experience?.visibility == View.VISIBLE && tv_talent_age?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        OkBus.getInstance()
                .unRegister(eventFlush)
                .unRegister(eventFinish)
    }

    override fun getPageId() = "1qqh"
}