package com.lagou.lagouee.ui.interview.widget

import android.content.Context
import android.text.Html
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.UserHeadUtils
import com.lagou.annotation.aspect.SingleClick
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.commonlibs.bean.SpanBean
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.TextViewUtils
import com.lagou.lagouee.bean.InterviewList
import com.lagou.lagouee.utils.IntentUtils
import kotlinx.android.synthetic.main.item_interview_schedule_b.view.*

/**
 * @author 作者：codeman
 * @date 创建时间：2020/7/22
 * @Description 描述：新面试日程卡片页页
 */
class NewInterviewCardView(context: Context, attrs: AttributeSet?) : FrameLayout(context, attrs) {
    init {
        LayoutInflater.from(context).inflate(R.layout.item_interview_schedule_b, this)
    }

    fun fillUi(bean: InterviewList.InterviewArrangeVosBean?) {
        bean?.apply {
            //1 基本信息包含头像、姓名等
            iv_interview_icon?.apply {
                UserHeadUtils.setUserHeader(this, portrait)
            }
            iv_interview_sex?.apply {
                when (sex) {
                    "男" -> setImageResource(R.drawable.icon_male_flag)
                    "女" -> setImageResource(R.drawable.icon_female_flag)
                    else -> setImageDrawable(null)
                }
            }
            tv_interview_name?.text = candidateName
            if (!TextUtils.isEmpty(interviewTag)) {
                tv_interview_state?.visibility = VISIBLE
                tv_interview_state?.text = interviewTag
            } else {
                tv_interview_state?.visibility = GONE
            }

            //2 工作信息
            fillWorkInfo()

            //3 应聘相关信息

            if (!TextUtils.isEmpty(positionName)) {
                val apply = ResourceUtils.getString(R.string.application_position)
                val positionSpan = TextViewUtils.adapterSpan("$apply  ${Html.fromHtml(positionName)}",
                        SpanBean(apply, ResourceUtils.getColor(R.color.color_999999)))
                tv_position?.text = positionSpan
                tv_position?.visibility = View.VISIBLE
            } else {
                tv_position?.visibility = View.GONE
            }

            if (!TextUtils.isEmpty(interviewModel)) {
                val mode = ResourceUtils.getString(R.string.interview_model)
                val modeSpan = TextViewUtils.adapterSpan("$mode  ${Html.fromHtml(interviewModel)}",
                        SpanBean(mode, ResourceUtils.getColor(R.color.color_999999)))
                tv_mode?.visibility = View.VISIBLE
                tv_mode?.text = modeSpan
            } else {
                tv_mode.visibility = View.GONE
            }
            if (!TextUtils.isEmpty(lastStatusText)) {
                val state = ResourceUtils.getString(R.string.interview_state)
                val stateSpan = TextViewUtils.adapterSpan("$state  ${Html.fromHtml(lastStatusText)}",
                        SpanBean(state, ResourceUtils.getColor(R.color.color_999999)))
                ltv_state?.visibility = View.VISIBLE
                ltv_state?.text = stateSpan
            } else {
                ltv_state?.visibility = View.GONE
            }

            if (hideChat()) {
                image_chat.visibility = View.GONE
            } else {
                image_chat.visibility = View.VISIBLE
            }
            if (hidePhone()) {
                image_video.visibility = View.GONE
            } else {
                image_video.visibility = View.VISIBLE
            }

            if (image_chat.visibility == View.GONE || image_video.visibility == View.GONE) {
                tv_interview_name.maxWidth = ResourceUtils.getDimenSize(R.dimen.dp_120)
            } else if (image_chat.visibility == View.GONE && image_video.visibility == View.GONE) {
                tv_interview_name.maxWidth = ResourceUtils.getDimenSize(R.dimen.dp_140)
            } else {
                tv_interview_name.maxWidth = ResourceUtils.getDimenSize(R.dimen.dp_100)
            }

            //4 点击事件
            image_chat?.setOnClickListener {
                //4.1 去Im聊天
                handleChatRepeatClick()
            }
            image_video?.setOnClickListener {
                //4.2 电话沟通
                handlePhoneRepeatClick()
            }
        }
    }

    @SingleClick
    fun InterviewList.InterviewArrangeVosBean.handlePhoneRepeatClick() {
        AnalyticHelper.getInstance().sendClickInfo("1qqd")
        candidatePhone?.let {
            BaseUtils.dialNumber(context, it)
        }
    }

    @SingleClick
    fun InterviewList.InterviewArrangeVosBean.handleChatRepeatClick() {
        AnalyticHelper.getInstance().sendClickInfo("1qqc")
        IntentUtils.startChatActivity(context, userId.toLong(), positionId.toLong())
    }

    /***
     * 处理带竖线的工作信息逻辑，之所以使用几个TextView是为了控制不同内容显示长度差异化，没有采取VerticalCenterImageSpan
     */
    private fun InterviewList.InterviewArrangeVosBean.fillWorkInfo() {
        //工作信息
        if (!TextUtils.isEmpty(lastCompanyName)) {
            tv_interview_company?.visibility = VISIBLE
            tv_interview_company?.text = lastCompanyName
        } else {
            tv_interview_company?.visibility = GONE
        }
        if (!TextUtils.isEmpty(workYear)) {
            tv_interview_year?.visibility = View.VISIBLE
            tv_interview_year?.text = workYear
        } else {
            tv_interview_year?.visibility = GONE
        }
        if (!TextUtils.isEmpty(lastTitleName)) {
            tv_interview_skill?.visibility = View.VISIBLE
            tv_interview_skill?.text = lastTitleName
        } else {
            tv_interview_skill?.visibility = GONE
        }
        //竖线隐藏和展示逻辑
        if (tv_interview_company?.visibility == View.VISIBLE && tv_interview_year?.visibility == View.VISIBLE) {
            v_interview_history_gap?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap?.visibility = View.GONE
        }
        if (tv_interview_year?.visibility == View.VISIBLE && tv_interview_skill?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
        if (tv_interview_company?.visibility == View.VISIBLE && tv_interview_skill?.visibility == View.VISIBLE) {
            v_interview_history_gap_two?.visibility = View.VISIBLE
        } else {
            v_interview_history_gap_two?.visibility = View.GONE
        }
    }

}