package com.lagou.lagouee.ui.position

import android.os.Bundle
import android.os.Message
import android.text.TextUtils
import android.view.View
import android.widget.TextView
import com.ApiService
import com.alpha.lagouapk.R
import com.alpha.lagouapk.widget.decoration.DividerItemDecoration
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.PVLogInfo
import com.lagou.baselib.analytic.definition.b.BPageId
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.lagouee.bean.PositionManagerBean
import com.lagou.lagouee.bean.PositionTemplatesResponse
import com.lagou.lagouee.bean.PositionType
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.ui.dialog.PositionTemplateDialog
import com.lagou.lagouee.ui.position.PositionManagerBaseFragment.ListFragmentRefreshListener
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse

/**
 * 职位模板
 */
class PositionManagerTemplateFragment: PositionManagerBaseFragment(), ListFragmentRefreshListener {
    private lateinit var mTemplateAdapter: PositionManagerAdapter
    private var showGuide:Boolean = false
    private var source:String? = null
    private lateinit var tvTemplateGuide:TextView
    companion object{
        const val KEY_SHOW_POSITION_TEMPLATE_GUIDE = "key_show_position_template_guide"
        const val KEY_SHOW_POSITION_TEMPLATE_SOURCE = "key_show_position_template_source"
        @JvmStatic
        fun newInstance(showGuide:Boolean,source:String?): PositionManagerTemplateFragment? {
            val args = Bundle()
            args.putBoolean(KEY_SHOW_POSITION_TEMPLATE_GUIDE,showGuide)
            args.putString(KEY_SHOW_POSITION_TEMPLATE_SOURCE,source)
            val fragment = PositionManagerTemplateFragment()
            fragment.arguments = args
            return fragment
        }
    }


    override fun init() {
        super.init()
        showGuide = arguments?.getBoolean(KEY_SHOW_POSITION_TEMPLATE_GUIDE) ?: false
        source = arguments?.getString(KEY_SHOW_POSITION_TEMPLATE_SOURCE)
        tvTemplateGuide = findViewById<TextView>(R.id.tv_template_guide)
        val paddingLR = ResourceUtils.getDimenSize(R.dimen.dp_15)
        recyclerView.setPadding(paddingLR,0,paddingLR,0)
        recyclerView.addItemDecoration(DividerItemDecoration(mContext,DividerItemDecoration.HORIZONTAL_LIST,ResourceUtils.getDimenSize(R.dimen.dp_05),ResourceUtils.getColor(R.color.color_e8e9eb)))
        mTemplateAdapter = PositionManagerAdapter(mContext, PositionType.TEMPLATE)
        recyclerView.adapter = mTemplateAdapter
        initListener()
        requestPositionTemplate(true)
    }

    private fun initListener() {
        setRefreshListener(this)
        recyclerView.setOnLoadMoreListener {
           requestPositionTemplate(false)
        }
        OkBus.getInstance().register(BEventTags.POSITION_FLUSH_TEMPLATE, flushPositionEvent)
        OkBus.getInstance().register(BEventTags.POSITION_FLUSH_TEMPLATE_SOURCE, updateSourceEvent)
    }

    private val flushPositionEvent = Event { _: Message? -> requestPositionTemplate(true) }

    private val updateSourceEvent = Event { msg: Message? -> source = msg?.obj as? String}

    override fun onVisibleToUser(isVisibleToUser: Boolean) {
        super.onVisibleToUser(isVisibleToUser)
        if (isVisibleToUser){
            if (showGuide){
                if (mContext is BaseActivity){
                    val dialog = PositionTemplateDialog.newInstance()
                    dialog.show((mContext as BaseActivity).supportFragmentManager, PositionTemplateDialog::class.java.simpleName)
                }
                showGuide = false
            }
            val pvLogInfo = PVLogInfo().setPage_id(BPageId._1yY0).addBrowse_props("tab", "template")
            if (source.isNullOrEmpty().not()){
                pvLogInfo.addBrowse_props("link_from",source)
                //置空，否则再手动切换tab的时候会上报link_from，导致数据不准确。link_from是统计由路由跳转进来的
                source = null
            }
            AnalyticHelper.getInstance().sendExploreInfo(pvLogInfo)
        }
    }

    private fun requestPositionTemplate(isRefresh:Boolean) {
        if (isRefresh){
            mCurrentPositionPage = 1
        }
        ApiService.api.fetchTemplatePositions(mCurrentPositionPage,PAGE_SIZE).enqueue(object:
            BaseCallback<PositionTemplatesResponse>(){
            override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<PositionTemplatesResponse>?) {
                if (mIsDestroy){
                    return
                }
                setRefreshDown() //刷新完成
                showNetError(false)
                val positions:PositionManagerBean.PositionsBean? =  response?.content?.page
                val isEmpty = positions == null || positions.result.isNullOrEmpty()
                recyclerView.completeOnSuccess(response?.content?.page?.isHasNextPage == true,isEmpty)
                if(isEmpty){
                    showEmpty()
                    return
                }
                tvTemplateGuide.text = StringUtil.jointString("\n",response?.content?.textOne,response?.content?.textTwo)
                hideEmpty()
                mCurrentPositionPage++
                mTemplateAdapter.setData(isRefresh,positions?.result)
            }

            override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<PositionTemplatesResponse>?) {
                super.onFailure(request, response)
                if (mIsDestroy) {
                    return
                }
                recyclerView.completeOnFailure()
                setRefreshDown()
                if (mTemplateAdapter.itemCount == 0) {
                    showNetError(true)
                }
            }

        })
    }


    override fun onAgainRequest() {
        requestPositionTemplate(true)
    }

    override fun showEmpty() {
        super.showEmpty()
        tvRelativeDesc.text = "职位模版已全部上线完成啦～"
        btnRelativeAction.visibility = View.GONE
        tvGoRights.visibility = View.GONE
        tvTemplateGuide.visibility = View.GONE
    }

    override fun hideEmpty() {
        super.hideEmpty()
        tvTemplateGuide.visibility = if (TextUtils.isEmpty(tvTemplateGuide.text)) View.GONE else View.VISIBLE
    }

    override fun onRefresh() {
        requestPositionTemplate(true)
    }


    override fun onDestroyView() {
        super.onDestroyView()
        OkBus.getInstance().unRegister(flushPositionEvent)
        OkBus.getInstance().unRegister(updateSourceEvent)
    }
}