package com.lagou.lagouee.ui.resume.mail

import android.os.Message
import android.text.TextUtils
import android.view.View
import com.alpha.lagouapk.R
import com.common.utils.ViewUtils
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.lagouee.bean.MailItem
import com.lagou.lagouee.bean.ResumeShareParams
import com.lagou.lagouee.observer.BEventTags
import com.lagou.lagouee.utils.IntentUtils
import kotlinx.android.synthetic.main.activity_mail_share.*

/**
 * 邮件转发
 *
 * 邮件分享简历
 * @author yph
 * @date 2019/9/26
 */
class MailShareActivity : BaseActivity(), MailShareContract.View, MailShareDialog.Callback, Event {

    private val mPresenter by lazy(LazyThreadSafetyMode.NONE) {
        MailSharePresenter()
    }

    private val mAdapter by lazy(LazyThreadSafetyMode.NONE) {
        MailShareAdapter(this)
    }

    private var mParams: ResumeShareParams? = null

    override fun getContentLayoutId(): Int = R.layout.activity_mail_share

    override fun init() {
        mParams = intent.getSerializableExtra(ResumeShareParams.TAG) as? ResumeShareParams
        mPresenter.attachView(this)
        initListener()
        rv_mail_send.apply {
            adapter = mAdapter
            setEmptyView(R.layout.layout_mail_share_empty)
        }

        mPresenter.getMergeList(false)
    }

    override fun onDestroy() {
        mPresenter.detachView()
        OkBus.getInstance().unRegister(this)
        super.onDestroy()
    }

    private fun initListener() {
        OkBus.getInstance().register(BEventTags.REFRESH_RECENT_MAIL_LIST, this)
        tbl_mail_share_title.setLeftImgListener {
            finish()
        }
        ViewUtils.ditherClick(fl_mail_search_area) {
            mParams?.apply {
                // 搜索
                IntentUtils.startMailSearchActivity(this@MailShareActivity, this)
            }
        }
        wv_mail_send.setReLoadListener {
            mPresenter.getMergeList(true)
        }
        rv_mail_send.setOnLoadMoreListener {
            mPresenter.getMoreColleagueList()
        }
        rv_mail_send.setOnItemClickListener { _, _, position ->
            val item = mAdapter.getItem(position)
            val params = mParams
            if (item == null || item.type == MailItem.SINGLE_TITLE
                    || params == null) {
                return@setOnItemClickListener
            }
            if (TextUtils.isEmpty(item.email)) {
                ToastUtil.show(this, R.string.no_email_tip)
                return@setOnItemClickListener
            }
            MailShareDialog(item, params).show(supportFragmentManager)
        }

    }

    override fun showError() {
        wv_mail_send.visibility = View.VISIBLE
        rv_mail_send.visibility = View.GONE
        rv_mail_send.completeOnFailure()
    }

    override fun showLoadSuccess(first: Boolean, hasNext: Boolean, list: List<MailItem>) {
        rv_mail_send.completeOnSuccess(hasNext)
        wv_mail_send.visibility = View.GONE
        rv_mail_send.visibility = View.VISIBLE

        mAdapter.addList(first, list)
        mAdapter.notifyDataSetChanged()
    }

    override fun showLoadMoreFailure() {
        rv_mail_send.completeOnFailure()
    }

    override fun shareSuccess() {
        if (isActive) {
            ToastUtil.show(this, R.string.forward_success)
            mPresenter.refreshRecentList()
        }
    }

    override fun call(msg: Message?) {
        when (msg?.what) {
            BEventTags.REFRESH_RECENT_MAIL_LIST -> mPresenter.refreshRecentList()
        }
    }

    override fun updateRecentList(list: List<MailItem>) {
        mAdapter.updateRecentList(list)
        mAdapter.notifyDataSetChanged()
    }

}
