package com.lagou.lagouee.ui.resume.mail

import android.content.Context
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import android.text.Spannable
import android.text.SpannableString
import android.text.TextUtils
import android.text.style.ForegroundColorSpan
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.UserHeadUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.lagouee.bean.MailItem
import java.util.regex.Pattern

/**
 * 邮件转发适配器
 *
 * @author yph
 * @date 2019/9/26
 */
class MailShareAdapter(context: Context) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private val mLayoutInflater: LayoutInflater = LayoutInflater.from(context)
    private val mList: ArrayList<MailItem> = arrayListOf()
    private var mPattern: Pattern? = null
    private val mGreen: Int = ContextCompat.getColor(context, R.color.theme_text_color)

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return when (viewType) {
            MailItem.SINGLE_TITLE -> TitleHolder(mLayoutInflater.inflate(R.layout.item_mail_share_single_title, parent, false))
            MailItem.SINGLE_MAIL -> MailHolder(mLayoutInflater.inflate(R.layout.item_mail_share_single_mail, parent, false))
            else -> DetailHolder(mLayoutInflater.inflate(R.layout.item_mail_share_detail, parent, false))
        }
    }

    override fun getItemCount(): Int = mList.size

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val mailItem = mList[position]
        when (holder) {
            is TitleHolder -> {
                holder.itemView.apply {
                    if (this is TextView) {
                        this.text = mailItem.title
                    }
                }
            }
            is MailHolder -> {
                //holder.tvMail.setHighlightText(mailItem.email, mGreen, mPattern)
                holder.tvMail.setMaskText(mailItem.email)
                checkLine(holder.vLine, position)
            }
            is DetailHolder -> {
                UserHeadUtils.setUserHeader(holder.ivIcon, mailItem.portrait)
                val s = if (TextUtils.isEmpty(mailItem.title)) mailItem.name else "${mailItem.name}·${mailItem.title}"
                holder.tvTitle.setHighlightText(s, mGreen, mPattern)
                //holder.tvMail.setHighlightText(if (TextUtils.isEmpty(mailItem.email)) "暂无邮箱" else mailItem.email, mGreen, mPattern)
                holder.tvMail.setMaskText(if (TextUtils.isEmpty(mailItem.email)) "暂无邮箱" else mailItem.email)
                checkLine(holder.vLine, position)
            }
        }
    }

    /**
     * 下一个是标题类型，需隐藏分割线
     */
    private fun checkLine(view: View, position: Int) {
        val next = position + 1
        view.visibility = if (next < itemCount &&
                getItemViewType(next) == MailItem.SINGLE_TITLE) View.GONE else View.VISIBLE
    }

    fun getItem(position: Int): MailItem? {
        return when (position) {
            in 0 until mList.size -> mList[position]
            else -> null
        }
    }

    override fun getItemViewType(position: Int): Int {
        return mList[position].type
    }

    fun setKeyword(keyword: String?) {
        mPattern = Pattern.compile(keyword, Pattern.LITERAL or Pattern.CASE_INSENSITIVE)
    }

    fun addList(first: Boolean, list: List<MailItem>) {
        if (first) {
            mList.clear()
        }
        mList.addAll(list)
    }

    fun updateRecentList(list: List<MailItem>) {
        val endIndex = mList.indexOfFirst {
            // "你的同事"的位置
            MailItem.SINGLE_TITLE == it.type && MailSharePresenter.COLLEAGUE == it.title
        }
        if (endIndex > 0) {
            for (index in (endIndex - 1) downTo 0) {
                // 倒序删除
                mList.removeAt(index)
            }
        }
        mList.addAll(0, list)
    }

    class TitleHolder(itemView: View) : RecyclerView.ViewHolder(itemView)

    class MailHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val tvMail: TextView = itemView.findViewById(R.id.tv_mail_share_single_mail)
        val vLine: View = itemView.findViewById(R.id.v_mail_share_single_mail)
    }

    class DetailHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val ivIcon: ImageView = itemView.findViewById(R.id.iv_mail_share_detail)
        val tvTitle: TextView = itemView.findViewById(R.id.tv_mail_share_detail_title)
        val tvMail: TextView = itemView.findViewById(R.id.tv_mail_share_detail_mail)
        val vLine: View = itemView.findViewById(R.id.v_mail_share_detail)
    }

}

/**
 * 设置文本高亮
 * 仅高亮查询一次
 */
fun TextView.setHighlightText(text: String?, color: Int, pattern: Pattern?) {
    if (pattern == null || TextUtils.isEmpty(text)) {
        this.text = text
    } else {
        val matcher = pattern.matcher(text)
        if (matcher.find()) {
            val spannable = SpannableString(text)
            spannable.setSpan(ForegroundColorSpan(color), matcher.start(), matcher.end(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
            this.text = spannable
        } else {
            this.text = text
        }
    }
}

/**
 * 设置脱敏邮箱 不再显示高亮绿色
 */
fun TextView.setMaskText(text: String?) {
    if (text != null && text.contains("@")) {
        this.text = StringUtil.getMaskString(text)
    } else {
        this.text = text
    }
}
