package com.lagou.lagouee.ui.resume.mail

import android.app.Activity
import android.os.Bundle
import androidx.fragment.app.FragmentManager
import android.view.View
import com.ApiService
import com.alpha.lagouapk.R
import com.common.utils.ViewUtils
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.ui.dialog.BaseDialogFragment
import com.lagou.lagouee.bean.MailItem
import com.lagou.lagouee.bean.ResumeShareParams
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import kotlinx.android.synthetic.main.dialog_mail_share.*

/**
 * 邮件转发对话框
 *
 * @author yph
 * @date 2019/9/29
 */
class MailShareDialog : BaseDialogFragment() {
    private var mailItem: MailItem? = null
    private var mParams: ResumeShareParams? = null
    private var mCallback: Callback? = null

    override fun onAttach(activity: Activity) {
        super.onAttach(activity)
        mCallback = activity as? Callback
    }

    override fun getLayoutId(): Int = R.layout.dialog_mail_share

    override fun getWidth(): Int = (screenWidth * 0.76f).toInt()

    override fun show(manager: FragmentManager) {
        super.show(manager, MailShareDialog::class.java.simpleName)
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        arguments?.apply {
            val item = getSerializable(MAIL_ITEM) as? MailItem
            val params = getSerializable(ResumeShareParams.TAG) as? ResumeShareParams
            if (item != null && params != null) {
                tv_mail_share_content.text = getString(R.string.forward_content_tip, params.candidateName,
                        if (item.type == MailItem.SINGLE_MAIL) item.email else item.name)
            }

            mailItem = item
            mParams = params
        }
        ViewUtils.ditherClick(tv_mail_share_confirm, this)
        ViewUtils.ditherClick(tv_mail_share_cancel, this)
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.tv_mail_share_confirm -> {
                dismiss()
                share()
            }
            R.id.tv_mail_share_cancel -> dismiss()
        }
    }

    private fun share() {
        val item = mailItem
        val params = mParams
        if (item == null || item.type == MailItem.SINGLE_TITLE || params == null) {
            return
        }
        var email = ""
        var recruitorId = 0
        if (item.userId > 0) {
            // 站内使用id
            recruitorId = item.userId
        } else {
            // 站外使用email
            email = item.email
        }

        if (params.resumeId > 0) {
            // 已投递
            mCallback?.showLoading()
            ApiService.api.forwardByResumeId(email, recruitorId, params.resumeId).enqueue(object : BaseCallback<Any?>() {
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                    mCallback?.apply {
                        hideLoading()
                        shareSuccess()
                    }
                }

                override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                    super.onFailure(request, response)
                    mCallback?.hideLoading()
                }
            })
        } else if (params.userId > 0) {
            // 未投递
            mCallback?.showLoading()
            ApiService.api.forwardByUserId(email, recruitorId, params.userId, params.attachmentResumeId).enqueue(object : BaseCallback<Any?>() {
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                    mCallback?.apply {
                        hideLoading()
                        shareSuccess()
                    }
                }

                override fun onFailure(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                    super.onFailure(request, response)
                    mCallback?.hideLoading()
                }
            })
        }

    }

    companion object {
        private const val MAIL_ITEM: String = "mail_item"

        operator fun invoke(item: MailItem, params: ResumeShareParams): MailShareDialog {
            val dialog = MailShareDialog()
            val args = Bundle()
            args.putSerializable(MAIL_ITEM, item)
            args.putSerializable(ResumeShareParams.TAG, params)
            dialog.arguments = args
            return dialog
        }
    }

    interface Callback {
        fun showLoading()

        fun hideLoading()

        fun shareSuccess()
    }

}