package com.lagou.lagouee.ui.settled.perfect

import android.text.Editable
import android.text.InputFilter
import android.text.TextUtils
import android.view.View
import com.alpha.lagouapk.R
import com.alpha.lagouapk.ui.login.perfect.EditInfoCode
import com.alpha.lagouapk.ui.login.perfect.EditInfoContract.SuggestView
import com.alpha.lagouapk.ui.login.perfect.EditInfoModel
import com.alpha.lagouapk.ui.login.perfect.EditInfoPresenter
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.OnAdapterCommonListenerImpl
import com.lagou.baselib.util.BarUtil
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.commonlibs.ui.dialog.inter.ADismissListener
import com.lagou.commonlibs.utils.InputMethodUtil
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.ToastUtil
import com.lagou.commonlibs.view.MaxInputWatcher
import com.lagou.commonlibs.view.MaxInputWatcher.OnMaxInputListener
import com.lagou.commonlibs.view.filter.EmojiFilter
import com.lagou.lagouee.bean.UserInfoBean
import com.lagou.lagouee.manager.net.CommonNetManager
import com.lagou.lagouee.utils.DialogUtils
import kotlinx.android.synthetic.main.activity_input_company_name.*

/**
 * Created by mihao on 2023/3/15
 * 入驻输入公司全称
 */
class InputCompanyNameActivity : BaseActivity(), SuggestView {

    private var mRequestId = 0

    private var mUserInfo: UserInfoBean? = null

    private var mPresenter: EditInfoPresenter? = null

    private var isAutoQuery = true

    companion object {
        const val REQUEST_ID = "request_id"
        const val GUIDE_TEXT = "guide_text"
        const val USER_INFO = "user_info"
    }

    private val textWatcher: OnMaxInputListener = object : OnMaxInputListener {
        override fun equalMaxLength(isEqual: Boolean) {
            if (isEqual) {
                ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.company_name_input_limit_b))
            }
        }

        override fun onTextChanged(s: String) {
            checkPerfect(false)
            if (TextUtils.isEmpty(et_company_name.textContent)) {
                et_company_name.setAutoData(null)
                et_company_name.showAutoComplete(false)
                return
            }
            ThreadUtil.uiDelay({
                if (!isAutoQuery) {
                    isAutoQuery = true
                    return@uiDelay
                }
                mPresenter?.getDataByKey(
                    EditInfoCode.B_TYPE_COMPANY_FULL,
                    et_company_name.textContent
                )
            }, 100)
        }

        override fun showLengthTip(length: Int, text: String) {}
    }

    override fun getContentLayoutId() = R.layout.activity_input_company_name

    override fun isEnableCommonBarSetting(): Boolean {
        return false
    }

    override fun init() {
        initListener()
        initEditText()
        mRequestId = intent.getIntExtra(REQUEST_ID, 0)
        if (intent.getSerializableExtra(USER_INFO) is UserInfoBean) {
            mUserInfo = intent.getSerializableExtra(USER_INFO) as UserInfoBean
            if (!TextUtils.isEmpty(mUserInfo?.getmMineCompanyFull())) {
                et_company_name.setEditText(mUserInfo?.getmMineCompanyFull())
            }
        }
        if (mUserInfo == null) {
            mUserInfo = UserInfoBean.getUserInforBean()
        }
        tv_company_guide.text = intent.getStringExtra(GUIDE_TEXT)
        mPresenter = EditInfoPresenter()
        mPresenter?.setVM(this, EditInfoModel())
        checkPerfect(false)
    }

    private fun initListener() {
        BarUtil.headerImageBarInit(this, R.id.title_bar)
        title_bar.setLeftImgListener { finish() }
        title_bar.setRightTvListener { DialogUtils.showBGuestTipsDialog(baseActivity, true) }
        btn_loading.setBigClick { goNext() }
    }

    private fun initEditText() {
        val maxInputWatcher = MaxInputWatcher(100)
        maxInputWatcher.setIsCalTextLength(true)
        maxInputWatcher.setInputType(MaxInputWatcher.INPUT_TYPE_DOUBLE)
        maxInputWatcher.setMaxInputListener(textWatcher)
        et_company_name.apply {
            showTitleSubTitle(false)
            showAutoComplete(false)
            setGetDataOrNot(false)
            setLineColorFocus(true)
            editTextView.filters = arrayOf<InputFilter>(EmojiFilter())
            editTextView.addTextChangedListener(maxInputWatcher)
        }
        et_company_name.setOnClickItemListener {
            isAutoQuery = false
            InputMethodUtil.hideKeyboard(this)
            et_company_name.showAutoComplete(false)
        }
    }

    private fun checkPerfect(isShowRead: Boolean): String? {
        tv_error_tip.visibility = View.GONE
        var tips: String? = null
        if (TextUtils.isEmpty(et_company_name.textContent)) {
            tips = ResourceUtils.getString(R.string.perfect_company_name_tips)
            btn_loading.showLoadingStyle(0.65f)
            if (isShowRead) {
                et_company_name.setLineColorError()
            }
        } else {
            btn_loading.hideLoadingStyle(1.0f)
        }
        return tips
    }

    private fun doNext(){
        mUserInfo?.setmMineCompanyFull(et_company_name.textContent)
        CommonNetManager.saveCompanyName(mRequestId,
            et_company_name.textContent,
            mUserInfo,
            object : OnAdapterCommonListenerImpl<Any, Any>(baseActivity) {
                override fun showLoading() {
                    btn_loading.showLoading()
                    btn_loading.showLoadingStyle(0.65f)
                }

                override fun hideSuccessLoading() {
                    btn_loading.hideLoading()
                    btn_loading.hideLoadingStyle(1.0f)
                }

                override fun onError(errorBean: Any) {
                    if (errorBean is String) {
                        tv_error_tip.visibility =
                            if (errorBean.isNullOrEmpty()) View.GONE else View.VISIBLE
                        tv_error_tip.text = errorBean
                        et_company_name.setLineColorError()
                    }
                }
            })
    }

    private fun goNext() {
        et_company_name.editTextView.clearFocus()
        val isShowDialog = tv_error_tip.visibility != View.VISIBLE
        val perfectTips = checkPerfect(true)
        if (!TextUtils.isEmpty(perfectTips)) {
            ToastUtil.showCenter(baseActivity, perfectTips)
            return
        }
        if (isShowDialog){
            DialogUtils.showCompanyNameConfirmDialog(baseActivity, et_company_name.textContent, object : ADismissListener<Any>() {
                    override fun onRight() {
                        doNext()
                    }
                })
        }else{
            doNext()
        }
    }

    override fun showSuggest(key: String?, suggests: List<String?>?) {
        if (!TextUtils.equals(key, et_company_name.textContent)) {
            return
        }
        et_company_name.showAutoComplete(!ListUtil.isEmpty(suggests))
        et_company_name.setAutoData(suggests)
    }

}