package com.lagou.lagouee.ui.settled.requirement

import android.content.Context
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.text.style.ForegroundColorSpan
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.alpha.lagouapk.R
import com.common.utils.ViewUtils
import com.google.android.flexbox.FlexboxLayout
import com.lagou.commonlibs.utils.VisibilityUtil
import com.lagou.lagouee.utils.IntentUtils

/**
 * 招聘需求适配器
 *
 * @author yph
 * @date 2019/10/29
 */
class RequirementAdapter(private val context: Context, viewGroup: ViewGroup) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    private val mList = arrayListOf<RequirementItem>()
    private val mInflater: LayoutInflater = LayoutInflater.from(context)
    private val mHeaderView: View = mInflater.inflate(R.layout.item_recruit_requirement_header, viewGroup, false)
    private val mFlexBox: FlexboxLayout

    private val mCellWidth = context.resources.run {
        val value = (displayMetrics.widthPixels - getDimensionPixelSize(R.dimen.dp_70)).toFloat() / getInteger(R.integer.recruit_requirement_span_count)
        value.toInt()
    }
    private val mCellMaxWidth = context.resources.getDimensionPixelSize(R.dimen.dp_102)
    private val mDp12 = context.resources.getDimensionPixelSize(R.dimen.dp_12)
    private val mDp33 = context.resources.getDimensionPixelSize(R.dimen.dp_33)

    /**
     * 搜索添加的label集合
     */
    private val mAddedLabels: ArrayList<String> = arrayListOf()

    init {
        mFlexBox = mHeaderView.findViewById(R.id.fl_item_recruit_header_label)
        mHeaderView.findViewById<TextView>(R.id.tv_item_recruit_header_tip).apply {
            val red = ContextCompat.getColor(context, R.color.color_ff7452)
            val builder = SpannableStringBuilder("请选择你最关注的")
            var pre = builder.length
            builder.append(SelectHelper.MAX.toString())
            builder.setSpan(ForegroundColorSpan(red), pre, builder.length, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
            builder.append("类人才，我会每天为你推荐")
            pre = builder.length
            builder.append("25")
            builder.setSpan(ForegroundColorSpan(red), pre, builder.length, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
            builder.append("份优质简历")
            text = builder
        }

        ViewUtils.ditherClick(mHeaderView.findViewById<TextView>(R.id.tv_item_recruit_header_search)) {
            // 搜索职位名称
            IntentUtils.startPositionNameSearchActivity(context, RecruitRequirementActivity.REQUEST_CODE)
        }
    }

    fun refreshList(list: List<RequirementItem>) {
        mList.clear()
        mList.addAll(list)
        notifyDataSetChanged()
    }

    fun addLabel(label: String) {
        if (label.isEmpty()) {
            return
        }
        // 在头部标签中如果查到此label，未选中则选中
        for (index in 0 until mFlexBox.childCount) {
            val textView = mFlexBox.getChildAt(index) as? TextView
            if (label.equals(textView?.text?.toString(), true)) {
                SelectHelper.getInstance().select(textView)
                return
            }
        }
        // 在列表标签中继续查找是否已存在
        var result = RecyclerView.NO_POSITION
        for ((index, value) in mList.withIndex()) {
            if (value.itemType == RequirementItem.CELL && label.equals(value.text, true)) {
                result = index
                break
            }
        }
        if (result == RecyclerView.NO_POSITION) {
            // 未查到，添加此label，并选中
            val textView = makeLabel().apply {
                text = label
            }
            SelectHelper.getInstance().select(textView)
            mFlexBox.addView(textView, -1, FlexboxLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, mDp33))
            mAddedLabels.add(label)
            VisibilityUtil.setVisible(mFlexBox)
        } else {
            // 查到，需要选中
            val item = mList[result]
            if (SelectHelper.getInstance().select(item.text)) {
                // 刷新
                notifyItemChanged(result)
            }
        }
    }

    private fun makeLabel(): TextView = TextView(context).apply {
        setBackgroundResource(R.drawable.selector_recruit_label)
        gravity = Gravity.CENTER
        ellipsize = TextUtils.TruncateAt.END
        setSingleLine(true)
        setTextColor(ContextCompat.getColorStateList(context, R.color.selector_recruit_label_color))
        textSize = 12.0f
        minWidth = mCellWidth
        maxWidth = mCellMaxWidth
        setPadding(mDp12, 0, mDp12, 0)

        setOnClickListener {
            SelectHelper.getInstance().click(this)
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder = when (viewType) {
        RequirementItem.HEADER -> HeaderHolder(mHeaderView)
        RequirementItem.CELL -> CellHolder(mInflater.inflate(R.layout.item_recruit_requirement_cell, parent, false))
        else -> TitleHolder(mInflater.inflate(R.layout.item_recruit_requirement_title, parent, false))
    }

    override fun getItemViewType(position: Int): Int = mList[position].itemType

    override fun getItemCount(): Int = mList.size

    fun getItem(position: Int): RequirementItem = mList[position]

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val itemText = mList[position].text
        when (holder) {
            is TitleHolder -> {
                holder.tvTitle.text = itemText
            }
            is CellHolder -> {
                holder.tvCell.apply {
                    text = itemText
                    // 小心复用
                    isSelected = SelectHelper.getInstance().isSelected(itemText)
                }
            }
        }
    }

    /**
     * 头部
     */
    internal class HeaderHolder(itemView: View) : RecyclerView.ViewHolder(itemView)

    /**
     * 标题
     */
    internal class TitleHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val tvTitle = itemView as TextView
    }

    /**
     * 筛选项
     */
    internal class CellHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val tvCell = itemView as TextView

        init {
            tvCell.setOnClickListener {
                SelectHelper.getInstance().click(tvCell)
            }
        }
    }

}