package com.lagou.lagouee.widget

import android.content.DialogInterface
import android.content.DialogInterface.OnKeyListener
import android.os.Bundle
import android.text.TextUtils
import android.view.KeyEvent
import android.view.View
import android.view.ViewGroup
import com.alpha.lagouapk.R
import com.common.widget.CommonLoadingView
import com.lagou.commonlibs.inter.OnSingleMethodListener
import com.lagou.commonlibs.ui.dialog.BaseDialogFragment

/**
 * @date 创建时间：2019-07-05
 * @author 作者：codeman
 * @Description  描述： 全屏loading  popupwindow实现
 * @version
 */

class FullLoadingDialog : BaseDialogFragment() {

    var loadingView: CommonLoadingView? = null

    private val LOADING_TXT_KEY = "loading_txt"
    private val BACK_CLOSE = "back_close"

    /***
     * 只是用来当loading效果 不走CommonLoadingView回调那一套
     */
    private val ONLY_LOADING = "only_loading"

    private var failListener: OnSingleMethodListener<*>? = null

    companion object {
        /***
         * loadingTxt  修改loading文案, 为空代表使用默认值
         * isBackClose 返回键是否关闭，默认关闭
         */
        fun getInstance(loadingTxt: String = "", isBackClose: Boolean = true, onlyLoading: Boolean): FullLoadingDialog {
            val loadingDialog = FullLoadingDialog()
            val bundle = Bundle()
            bundle.putCharSequence(loadingDialog.LOADING_TXT_KEY, loadingTxt)
            bundle.putBoolean(loadingDialog.BACK_CLOSE, isBackClose)
            bundle.putBoolean(loadingDialog.ONLY_LOADING, onlyLoading)
            loadingDialog.arguments = bundle
            return loadingDialog
        }

        fun getInstance(loadingTxt: String = "", onlyLoading: Boolean): FullLoadingDialog {
            return getInstance(loadingTxt, true, onlyLoading)
        }

        fun getInstance(loadingTxt: String = ""): FullLoadingDialog {
            return getInstance(loadingTxt, isBackClose = true, onlyLoading = false)
        }
    }


    override fun getLayoutId() = R.layout.loading_common

    override fun initView(view: View?) {
        super.initView(view)
        loadingView = view?.findViewById(R.id.common_load_view)
    }

    override fun fillUI() {
        super.fillUI()
        loadingView?.visibility = View.VISIBLE
        val loadingTxt = arguments?.getString(LOADING_TXT_KEY)
        if (!TextUtils.isEmpty(loadingTxt)) {
            loadingView?.setLoadingTxt(loadingTxt)
        }
        val isBackClose = arguments?.getBoolean(BACK_CLOSE, true)
        if (isBackClose != true) {
            setCancelBackClose()
        }
        loadingView?.isClickable = true
        loadingView?.setFailListener(failListener)
        val onlyLoading = arguments?.getBoolean(ONLY_LOADING, false)
        onlyLoading?.let {
            loadingView?.setOnlyLoading(onlyLoading)
        }
    }


    public override fun initConfigAtCreateView() {
        super.initConfigAtCreateView()
        dialog?.setCanceledOnTouchOutside(false)
    }

    fun setContinueLCheckPublish(isContinueCheckPublish: Boolean) {
        loadingView?.setContinueLCheckPublish(isContinueCheckPublish)
    }

    fun setFailListener(failListener: OnSingleMethodListener<*>) {
        this.failListener = failListener
    }

    /***
     * 是否设置返回键不关闭loading
     */
    private fun setCancelBackClose(): FullLoadingDialog {
        dialog?.setOnKeyListener(object : OnKeyListener {
            override fun onKey(dialog: DialogInterface?, keyCode: Int, event: KeyEvent?): Boolean {
                if (keyCode == KeyEvent.KEYCODE_BACK) {
                    return true
                }
                return false
            }
        })

        return this
    }

    /***
     * 是否设置返回键关闭loading
     */
    fun setBackClose(): FullLoadingDialog {
        dialog?.setOnKeyListener(object : OnKeyListener {
            override fun onKey(dialog: DialogInterface?, keyCode: Int, event: KeyEvent?): Boolean {
                return false
            }
        })

        return this
    }

    override fun getWidth(): Int {
        return ViewGroup.LayoutParams.MATCH_PARENT
    }

    override fun getHeight(): Int {
        return ViewGroup.LayoutParams.MATCH_PARENT
    }

    override fun dismiss() {
        try {
            loadingView?.visibility = View.GONE
        } catch (e: Exception) {
            e.printStackTrace()
        }
        super.dismiss()
    }

}