package com.lagou.lagouee.widget

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.UserHeadUtils
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.definition.b.BAid
import com.lagou.baselib.analytic.definition.b.BPageId
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.VisibilityUtil
import com.lagou.lagouee.bean.InterviewList
import kotlinx.android.synthetic.main.item_interview_list_default.view.*
import kotlinx.android.synthetic.main.layout_interview_list_info.view.*

/**
 * 面试记录卡片
 *
 * @author yph
 * @date 2019/12/25
 */
class InterviewCardView(context: Context, attrs: AttributeSet? = null) : FrameLayout(context, attrs), View.OnClickListener {

    init {
        LayoutInflater.from(context).inflate(R.layout.item_interview_list_default, this)
    }

    fun setData(bean: InterviewList.InterviewArrangeVosBean?, selected: Boolean) {
        bean?.let {
            iv_interview_icon?.apply {
                UserHeadUtils.setUserHeader(this, it.portrait)
            }
            iv_interview_sex?.apply {
                when (it.sex) {
                    "男" -> setImageResource(R.drawable.icon_male_flag)
                    "女" -> setImageResource(R.drawable.icon_female_flag)
                    else -> setImageDrawable(null)
                }
            }
            tv_interview_name?.text = it.candidateName
            tv_interview_label?.text = it.interviewTag
            tv_is_video?.text = if (it.isVideo) "视频面试" else ResourceUtils.getString(R.string.offline_interview)
            if (it.isVideo) {
                tv_is_video.setBackgroundResource(R.drawable.solid_3994e9_lr_2_rb_6)
            } else {
                tv_is_video.setBackgroundResource(R.drawable.solid_00b38a_lr_2_rb_6)
            }
            tv_interview_phone?.apply {
                val candidatePhone = it.candidatePhone
                if (TextUtils.isEmpty(candidatePhone)) {
                    text = ""
                } else {
                    text = candidatePhone
                    setOnClickListener {
                        BaseUtils.dialNumber(context, candidatePhone)
                        AnalyticHelper.getInstance().sendClickInfo(BPageId._1ped, BAid._1peh)
                    }
                }
            }

            tv_interview_company?.setTextWithVisibility(it.lastCompanyName)
            tv_interview_title?.setTextWithVisibility(it.lastTitleName)
            v_interview_history_gap?.visibility = if (VisibilityUtil.isVisible(tv_interview_company)
                    && VisibilityUtil.isVisible(tv_interview_title)) View.VISIBLE else View.GONE

            tv_interview_position?.text = "应聘岗位：${it.positionName}"
            // 面试信息
            val beanId = it.id
            tv_interview_switch?.apply {
                // 初始化
                isSelected = selected
                setOnClickListener {
                    onSwitchListener?.onSwitch(beanId, !isSelected)
                    AnalyticHelper.getInstance().sendClickInfo(BPageId._1ped, BAid._1pei)
                }
            }

            ll_interview_info?.apply {
                visibility = if (selected) View.VISIBLE else View.GONE
                // 阻塞点击跳转简历详情
                setOnClickListener(this@InterviewCardView)
            }
            tv_interview_info_name?.text = it.linkMan
            tv_interview_info_phone?.apply {
                val linkPhone = it.linkPhone
                if (TextUtils.isEmpty(linkPhone)) {
                    text = ""
                } else {
                    text = linkPhone
                    paint.isUnderlineText = true
                    setOnClickListener {
                        BaseUtils.dialNumber(context, linkPhone)
                        AnalyticHelper.getInstance().sendClickInfo(BPageId._1ped, BAid._1pej)
                    }
                }
            }
            tv_interview_info_address?.text = it.address
            if (TextUtils.isEmpty(it.addInfo)) {
                VisibilityUtil.setGone(v_interview_info_line, ll_interview_info_remark)
            } else {
                VisibilityUtil.setVisible(v_interview_info_line, ll_interview_info_remark)
                tv_interview_info_remark?.text = it.addInfo
            }
        }
    }

    fun updateSwitchState(selected: Boolean) {
        tv_interview_switch?.isSelected = selected
        ll_interview_info?.visibility = if (selected) View.VISIBLE else View.GONE
    }

    fun updateInterviewTag(interviewTag: String?) {
        tv_interview_label?.text = interviewTag
    }

    interface OnSwitchListener {
        fun onSwitch(id: Long, newState: Boolean)
    }

    var onSwitchListener: OnSwitchListener? = null

    /**
     * 设置文本及文本可见性
     */
    fun TextView.setTextWithVisibility(str: String?) {
        if (TextUtils.isEmpty(str)) {
            visibility = View.GONE
        } else {
            visibility = View.VISIBLE
            this.text = str
        }
    }

    override fun onClick(v: View?) {
        // empty
    }


}