package com.lagou.lagouee.widget.position

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.graphics.Bitmap
import android.net.Uri
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.constraintlayout.widget.ConstraintLayout
import com.alibaba.sdk.android.vod.upload.model.UploadFileInfo
import com.alpha.lagouapk.R
import com.common.bean.VideoRes
import com.common.bean.json.UploadVideoParams
import com.common.integrate.picture.UploadFileNetManager
import com.common.integrate.video.AliyunUploadManager
import com.common.integrate.video.VideoProcessManager
import com.common.inter.ICompressProgress
import com.common.inter.IUploadVideoListener
import com.common.mvp.listener.OnUploadPictureListener
import com.common.ui.CommonCropActivity
import com.common.ui.video.VideoListActivity
import com.common.ui.video.VideoPlayActivity
import com.common.utils.PaletteUtils
import com.lagou.baselib.BaseActivity
import com.lagou.chat.chatlibrary.gallery.GalleryUtil
import com.lagou.chat.chatlibrary.gallery.SelectedImage
import com.lagou.commonlibs.engine.ThreadUtil
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.engine.DiskCacheEnum
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.imageload.inter.ALoadImgListener
import com.lagou.commonlibs.ui.dialog.inter.ADismissListener
import com.lagou.commonlibs.utils.*
import com.lagou.lagouee.bean.jsonbean.position.VideoDetailBean
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.socketchannel.http.HttpResponse
import com.yalantis.ucrop.UCrop
import kotlinx.android.synthetic.main.view_upload_video_after.view.*
import kotlinx.android.synthetic.main.view_upload_video_prepare.view.*
import kotlinx.android.synthetic.main.view_upload_video_release.view.*
import java.io.File

/**
 * @date： Crate by wangjunwei on 2022/7/28
 * @description：B端发布职位上传视频，自定义View
 */
class VideoUploadView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null) :
    ConstraintLayout(context, attrs) {

    var activity = context as BaseActivity

    /**
     * 屏幕宽高
     */
    val screenWidth = DeviceUtils.getScreenWidth()

    /***
     * 上传的宽占屏幕宽的比例，根据设计图换算，高占宽的比例
     */
    private val uploadWidth = (0.53 * screenWidth).toInt()
    private val uploadHeight = (1.35 * uploadWidth).toInt()

    /***
     * 上传的各个状态
     * 1 视频未上传，操作：上传视频
     * 2 视频上传中，操作：取消上传
     * 3 视频上传失败， 操作：重新上传
     *
     * 4 视频上传成功，操作：删除视频、重新上传、更换封面
     * 5 视频审核中，操作：删除视频、重新上传、更换封面
     * 6 视频审核失败，操作：删除视频、重新上传
     */
    val UPLOAD_NOT = 1
    val UPLOAD_ING = 2
    val UPLOAD_FAIL = 3
    val UPLOAD_SUCCESS = 4
    val UPLOAD_AUTHING = 5
    val UPLOAD_AUTH_FAIL = 6

    /***
     * 视频上传状态，默认未上传
     */
    var uploadState = UPLOAD_NOT

    /***
     * 选中视频本地数据源
     */
    private var videoRes: VideoRes? = null

    /**
     * 视频id作为获取视频播放地址的凭证，封面地址
     */
    private var videoId: String? = null
    private var coverUrl: String? = null

    /***
     * 视频 封面处理中
     */
    private var isHandleVideo = false
    private var isHandleCover = false

    private var iVideoViewListener: IVideoViewListener? = null

    /***
     * 回调tag
     */
    private var callbackTag = 1


    companion object {
        /***
         * 选择封面
         */
        const val SELECT_COVER_REQUEST = 0x1000

        /**
         * 视频引导链接
         */
        const val VIDEO_INTRODUCE_HELP = "https://zhuanti.lagou.com/page51.html"

        /***
         * 删除视频tag
         */
        const val DELETE_VIDEO_TAG = "DELETE"
    }

    interface IVideoViewListener {
        fun onDeleteVideo()
    }

    init {
        initView()
        initListener()
    }

    private fun initView() {
        LayoutInflater.from(activity).inflate(R.layout.view_upload_video_release, this)
        //上传完成前View尺寸设置
        var uploadBeforeParams = rel_upload_before.layoutParams
        uploadBeforeParams.width = uploadWidth
        uploadBeforeParams.height = uploadHeight
        rel_upload_before.layoutParams = uploadBeforeParams

        var uploadOnParams = rel_upload_on.layoutParams
        uploadOnParams.width = uploadWidth
        uploadOnParams.height = uploadHeight
        rel_upload_on.layoutParams = uploadOnParams


        var uploadFailParams = rel_upload_fail.layoutParams
        uploadFailParams.width = uploadWidth
        uploadFailParams.height = uploadHeight
        rel_upload_fail.layoutParams = uploadFailParams


        //上传完成后View尺寸设置
        val uploadBodyParams = rel_upload_body.layoutParams
        uploadBodyParams.width = uploadWidth
        uploadBodyParams.height = uploadHeight
        rel_upload_body.layoutParams = uploadBodyParams
    }

    private fun initListener() {
        //0 跳转到视频引导页面
        tv_video_help.setOnClickListener {
            IntentUtils.startLagouWebViewActivity(activity, VIDEO_INTRODUCE_HELP)
        }

        //1 执行视频上传操作，跳转到视频选页面，操作区域尽可能大
        rel_upload_before.setOnClickListener {
            VideoListActivity.startVideoListActivity(activity)
        }
        //2 取消上传操作，操作区域尽可能小
        tv_upload_cancel.setOnClickListener {
            //取消成功的回调里，恢复页面到未上传状态
            AliyunUploadManager.cancelUploadProcess()
            VideoProcessManager.cancelCompressProcess()
            moveUploadingInit()
            isHandleVideo = false
            isHandleCover = false
        }
        //3 上传失败-重新上传
        rel_upload_fail.setOnClickListener {
            VideoListActivity.startVideoListActivity(activity)
        }

        //4 上传成功，跳转到视频播放页面
        rel_upload_body.setOnClickListener {
            //先判断当前状态是否是审核是失败，是的话不跳转
            if (uploadState == UPLOAD_AUTH_FAIL) {
                return@setOnClickListener
            }
            //跳转到视频播放页面，可能是本地连接、也可能是网络视频 补充视频来源
            videoRes?.let {
                VideoPlayActivity.startPlayActivity(activity, it)
            }
        }
        //5 删除视频
        image_video_delete.setOnClickListener {
            DialogUtils.showDeleteVideoDialog(activity, object : ADismissListener<Any>() {
                override fun onRight() {
                    //恢复到页面未上传状态
                    moveCompleteInit()
                    //清除显示的图像
                    image_cover_pic.setImageBitmap(null)
                    iVideoViewListener?.onDeleteVideo()
                    videoId = DELETE_VIDEO_TAG
                    coverUrl = DELETE_VIDEO_TAG
                }
            })
        }
        //6 上传成功-重新上传
        tv_upload_video.setOnClickListener {
            VideoListActivity.startVideoListActivity(activity)
        }
        //7 更换封面
        tv_cover_change.setOnClickListener {
            // 跳转到更换封面页面，Activity oActivityResult需要接收，建立回调当当前View处理
            GalleryUtil.openPhoneGallery(GalleryUtil.Builder(activity)
                .preview(true)
                .requestCode(SELECT_COVER_REQUEST)
                .sceneRightsKey(""))
        }
    }

    fun setIVideoViewListener(iVideoViewListener: IVideoViewListener) {
        this.iVideoViewListener = iVideoViewListener
    }

    fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        if (data == null) {
            return false
        }
        //1 选择视频
        if (requestCode == VideoListActivity.SELECT_REQUEST_CODE
            && resultCode == VideoListActivity.SELECT_RESULT_CODE
        ) {
            handleVideoResult(data)
            return true
        }

        //2 选择封面图
        if (requestCode == SELECT_COVER_REQUEST && resultCode == Activity.RESULT_OK) {
            if (data != null && data.extras != null) {
                val selectedImage =
                    data.extras?.getParcelable(GalleryUtil.KEY_SELECTED_IMAGE) as? SelectedImage
                if (selectedImage != null) {
                    CommonCropActivity.startCropActivity(
                        activity,
                        selectedImage.uri,
                        selectedImage.fileNamePrefix
                    )
                }
            }
            return true
        }

        //3 裁剪封面图完成
        if (resultCode == Activity.RESULT_OK && requestCode == UCrop.REQUEST_CROP) {
            uploadCropResult(data)
            return true
        }
        return false
    }

    private fun uploadCropResult(data: Intent) {
        isHandleCover = true
        //1 裁剪后的图片uri
        val resultUri: Uri? = data.getParcelableExtra(CommonCropActivity.KEY_CROP_RESULT)
        uploadSelectImage(resultUri)
    }


    private fun uploadSelectImage(cropUri: Uri?) {
        if (cropUri == null) {
            isHandleCover = false
            ToastUtil.show(activity, ResourceUtils.getString(R.string.head_pic_upload_fail_error))
            return
        }
        UploadFileNetManager.uploadBigPicture(
            cropUri,
            activity,
            object : OnUploadPictureListener<String?> {
                override fun uploadFail(response: HttpResponse<*>?) {
                    isHandleCover = false
                    ToastUtil.show(activity, ResourceUtils.getString(R.string.upload_cover_fail))
                }

                override fun isActive(): Boolean {
                    return activity.isActive
                }

                override fun uploadSuccess(url: String?) {
                    coverUrl = url
                    isHandleCover = false
                    ImageLoadUtils
                        .with(activity)
                        .load(url)
                        .skipMemoryCache(true)
                        .diskCacheStrategy(DiskCacheEnum.NONE)
                        .centerCrop()
                        .bitmapTransform(RoundTransform(8f))
                        .into(object : ALoadImgListener<Bitmap>() {
                            override fun onResourceReady(bitmap: Bitmap?) {
                                image_cover_pic?.setImageBitmap(bitmap)
                                //判断上传的封面是否符合要求，不符合要求的给出toast提示
                                PaletteUtils.paletteSingleColor(bitmap, object : PaletteUtils.Companion.IAnalyzeColor {
                                    override fun onVerifyResult(isOneColor: Boolean) {
                                        if (isOneColor) ToastUtil.show(activity, ResourceUtils.getString(R.string.video_cover_wrongful_tip))
                                    }
                                })
                            }
                        })
                }

            })
    }

    /***
     * 压缩视频，接入阿里云上传视频，更新上传中状态
     * 选中视频之后后续处理：上传到阿里云获取，视频链接
     *                   获取并上传封面，获取封面链接
     */
    private fun handleVideoResult(data: Intent?) {
        //1 选中视频之后，执行压缩，页面状态切换成上传中
        moveInitUploadIng()
        videoRes = data?.getParcelableExtra(VideoListActivity.KEY_SELECT_VIDEO) as? VideoRes
        videoRes?.apply {
            isHandleVideo = true
            VideoProcessManager.compressVideoMiddle(activity, videoRes,
                object : ICompressProgress {
                    override fun compressProgress(progress: Int) {
                        //压缩进度作为整体进度的一半使用
                        progress_upload.progress = progress / 2
                        tv_progress_txt.text = "${progress_upload.progress}%"
                    }

                    override fun compressComplete(
                        destPath: String?,
                        sourceSize: Long,
                        compressSize: Long) {
                        videoRes?.destPath = destPath ?: ""
                        videoRes?.let {
                            ThreadUtil.ui {
                                aliyunUpload(it)
                            }
                        }
                    }

                    override fun onCancelCompress() {
                        ThreadUtil.ui{
                            if(activity.isActivityDestroyed){
                                return@ui
                            }
                            progress_upload.progress = 0
                            tv_progress_txt.text = "0%"
                        }
                    }
                }, callbackTag++)
        }

    }

    private fun aliyunUpload(videoInfo: VideoRes) {
        AliyunUploadManager.uploadVideoFirst(activity, videoInfo, object : IUploadVideoListener {
            override fun onUploadProgress(
                info: UploadFileInfo?, uploadedSize: Long, totalSize: Long) {
                progress_upload.progress = (50 + (uploadedSize * 1f / totalSize) * 100).toInt()
                tv_progress_txt.text = "${progress_upload.progress}%"
            }


            override fun onUploadSucceed(
                info: UploadFileInfo?,
                uploadVideoParams: UploadVideoParams,
                videoRes: VideoRes?) {
                videoId = uploadVideoParams?.videoId
                isHandleVideo = false
                isHandleCover = true
                //上传成功之后，拿到视频链接、封面链接
                moveUploadingSuccess()
                ImageLoadUtils
                    .with(activity)
                    .load(File(videoRes?.destPath))
                    .into(object : ALoadImgListener<Bitmap>() {
                        override fun onResourceReady(bitmap: Bitmap) {
                            ThreadUtil.io {
                                createCoverShow(videoRes, bitmap)
                            }
                        }
                    })
            }

            override fun onUploadFailed(
                info: UploadFileInfo?, code: String?,
                message: String?
            ) {
                isHandleVideo = false
                moveUploadingFail()
            }

            override fun onCancelUpload() {
                isHandleVideo = false
                isHandleVideo = false
                ThreadUtil.ui{
                    if(activity.isActivityDestroyed){
                        return@ui
                    }
                    progress_upload.progress = 0
                    tv_progress_txt.text = "0%"
                }
            }
            /***
             * 生成封面图像，裁剪然后上传展示
             * 注意：直接从视频中提取的图像帧，不裁剪直接上传作为封面
             */
            private fun createCoverShow(videoRes: VideoRes?, bitmap: Bitmap) {
                //上传成功之后，把封面的字节流传输到后端，拿到封面链接
                val coverNamePrefix = getCoverName(videoRes?.name)
                val pathPrefix =
                    "${SDCardUtils.getInternalStorageImageDir(activity).path}/$coverNamePrefix"
                val coverPath: String = BitmapUtils.saveBitmapPng(pathPrefix, bitmap)
                //创建目标uri，产品最新要求，恢复视频抽取封面也需要执行裁剪
                val coverOriginalUri = Uri.fromFile(File(coverPath))
                coverOriginalUri?.let {
                    CommonCropActivity.startCropActivity(activity, it, coverNamePrefix)
                }

                //uploadSelectImage(coverOriginalUri)
            }
        }, callbackTag)
    }

    /***
     * 设置完成上传之后的各种状态
     */
    fun setCompleteUploadUi(videoDetail: VideoDetailBean?) {
        if (videoDetail == null) {
            return
        }

        videoId = videoDetail.videoId
        coverUrl = videoDetail.coverUrl

        lin_upload_complete.visibility = VISIBLE
        lin_upload_not_complete.visibility = GONE

        //1 审核状态
        tv_verify_state.visibility = videoDetail.isAuthStateVisible
        tv_verify_state.setTextColor(ResourceUtils.getColor(videoDetail.authStateTxtColor))
        tv_verify_state.text = videoDetail.authStateTxt
        tv_verify_state.background = ResourceUtils.getDrawable(videoDetail.authStateBackground)
        //2 更换封面图
        tv_cover_change.visibility = if (videoDetail.isAuthRefuse) GONE else VISIBLE
        //3 封面图
        ImageLoadUtils
            .with(activity)
            .load(videoDetail.coverUrl)
            .centerCrop()
            .bitmapTransform(RoundTransform(8f))
            .into(image_cover_pic)
        if (videoRes == null) {
            videoRes = VideoRes(
                videoDetail.duration.toLong(),
                videoDetail.size.toLong(),
                uri = null,
                name = "",
                destPath = "",
                videoUrl = videoDetail.fileUrl,
                coverUrl = videoDetail.coverUrl
            )
        } else {
            videoRes?.apply {
                videoUrl = videoDetail.fileUrl
                coverUrl = videoDetail.coverUrl
                duration = videoDetail.duration.toLong()
                size = videoDetail.size
            }
        }
    }

    /***
     * 上传前-到上传中状态
     */
    private fun moveInitUploadIng() {
        lin_upload_complete.visibility = GONE
        lin_upload_not_complete.visibility = VISIBLE

        rel_upload_before.visibility = GONE
        rel_upload_on.visibility = VISIBLE
        rel_upload_fail.visibility = GONE
    }


    /***
     * 取消上传，上传中到初始状态
     */
    private fun moveUploadingInit() {
        //说明属于重新上传直接恢复原状即可
        if (!TextUtils.isEmpty(videoId) && !TextUtils.isEmpty(coverUrl)){
            lin_upload_complete.visibility = VISIBLE
            lin_upload_not_complete.visibility = GONE
            return
        }
        lin_upload_complete.visibility = GONE
        lin_upload_not_complete.visibility = VISIBLE

        rel_upload_before.visibility = VISIBLE
        rel_upload_on.visibility = GONE
        rel_upload_fail.visibility = GONE

        progress_upload.progress = 0
    }

    /***
     * 上传中状态 - 上传失败
     */
    private fun moveUploadingFail() {
        lin_upload_complete.visibility = GONE
        lin_upload_not_complete.visibility = VISIBLE

        rel_upload_before.visibility = GONE
        rel_upload_on.visibility = GONE
        rel_upload_fail.visibility = VISIBLE

        progress_upload.progress = 0
    }

    /**
     * 恢复上传页面，从视频上传完成，到初始状态
     */
    private fun moveCompleteInit() {
        lin_upload_complete.visibility = GONE
        lin_upload_not_complete.visibility = VISIBLE

        rel_upload_before.visibility = VISIBLE
        rel_upload_on.visibility = GONE
        rel_upload_fail.visibility = GONE
    }

    /***
     * 上传中 - 上传成功
     */
    private fun moveUploadingSuccess() {
        lin_upload_complete.visibility = VISIBLE
        lin_upload_not_complete.visibility = GONE

        tv_verify_state.visibility = GONE
        tv_cover_change.visibility = VISIBLE
    }

    /***
     * 返回视频id、封面链接
     */
    fun getVideoId() = videoId
    fun getCoverUrl() = coverUrl

    /***
     * 是否正在处理视频：压缩、上传流程
     * 供点击发布职位判断使用
     */
    fun isHandleVideo() = isHandleVideo

    /***
     * 是否正在处理封面：压缩、上传视频成功之后，包含封面图片处理流程
     * 供点击发布职位判断使用
     */
    fun isHandleCover() = isHandleCover


    /**
     * 获取缩略图名称
     */
    private fun getCoverName(videoName: String?): String {
        videoName?.let {
            val nameParts = it.split(".")
            if (nameParts != null && nameParts.isNotEmpty()) {
                return nameParts[0]
            }
        }
        return System.currentTimeMillis().toString();
    }
}