package com.lagou.lagouee.widget.session

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.DensityUtil
import com.common.chat.ViviMessageManager
import com.common.manager.functionsession.FunctionSessionManager
import com.lagou.chat.chatlibrary.bean.ConversationBean
import com.lagou.chat.chatlibrary.db.SessionDBManager
import com.lagou.commonlibs.engine.ThreadUtil

@Suppress("LeakingThis")
abstract class BaseSessionView @JvmOverloads constructor(context: Context, attr: AttributeSet? = null, defStyleResId: Int = 0):FrameLayout(context,attr,defStyleResId) {
    protected  var contentViewContainer: View
    protected lateinit var mTvTopAction:TextView
    protected lateinit var mTvDeleteAction:TextView
    protected lateinit var llActionContainer:LinearLayout
    init {
        LayoutInflater.from(context).inflate(R.layout.layout_session_base, this)
        contentViewContainer = LayoutInflater.from(context).inflate(getContentLayoutId(), null)
        contentViewContainer.layoutParams = LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT)
        addView(contentViewContainer)
        initView()
    }

    private fun initView() {
        mTvTopAction = findViewById(R.id.prl_top)
        mTvDeleteAction = findViewById(R.id.prl_delete)
        llActionContainer = findViewById(R.id.ll_action_container)
        mTvDeleteAction.visibility = if (isShowDeleteAction()) VISIBLE else GONE
        mTvTopAction.visibility = if (isShowTopAction()) VISIBLE else GONE
        val layoutParams:FrameLayout.LayoutParams = llActionContainer.layoutParams as LayoutParams
        layoutParams.leftMargin = 0
        layoutParams.rightMargin = 0
        llActionContainer.layoutParams = layoutParams
    }

    /**
     * 点击
     */
    open fun onSessionClick(bean:ConversationBean,position:Int){
        if (FunctionSessionManager.getInstance().isReportState(bean.serverSesstionId)) {
            ViviMessageManager.getInstance().updateViviMessage(0, 1, 0, bean.serverSesstionId)
        }
        if (FunctionSessionManager.getInstance().isSupportRedDot(bean.serverSesstionId)) {
            ThreadUtil.io {
                SessionDBManager.getInstance().clearUnreadCount(bean.serverSesstionId)
            }
        }
    }

    /**
     * 设置未读数量
     * @param textView
     */
    protected fun setUnReadRedNum(textView: TextView, unReadCount: Int) {
        textView.visibility = if (unReadCount > 0) VISIBLE else GONE
        if (unReadCount > 99) {
            textView.text = ""
            textView.setBackgroundResource(R.drawable.ic_conver_more)
            return
        }
        if (unReadCount >= 10) {
            textView.text = unReadCount.toString()
            textView.setBackgroundResource(R.drawable.ic_conver_two)
            return
        }
        if (unReadCount > 0) {
            textView.text = unReadCount.toString()
            textView.setPadding(DensityUtil.dip2px(0.5f), 0, 0, DensityUtil.dip2px(0.5f))
            textView.setBackgroundResource(R.drawable.ic_conver_one)
        }
    }

    /**
     * 设置红点
     * @param imageView
     */
    protected fun setUnReadRedDot(imageView: ImageView, unReadCount: Int) {
        imageView.visibility = if (unReadCount > 0) VISIBLE else GONE
    }

    /**
     * 设置标题
     */
    protected fun setTvAutoShowByText(tv: TextView?, text: String?) {
        tv?.visibility = if (TextUtils.isEmpty(text)) GONE else VISIBLE
        tv?.text = text
    }


    /**
     * 布局资源id
     *
     * @return
     */
    protected abstract fun getContentLayoutId():Int

    abstract fun bindData(bean: ConversationBean?,isLast:Boolean)

    /**
     * 是否展示删除
     *
     * @return
     */
    protected open fun isShowDeleteAction(): Boolean = true

    /**
     * 是否展示置顶
     */
    protected open fun isShowTopAction() :Boolean = true

    fun getTvDeleteAction(): TextView? = mTvDeleteAction
    fun getTvTopAction(): TextView? = mTvTopAction
    fun getContentViewWrap(): View? = contentViewContainer
    fun getActionContainer(): LinearLayout?  = llActionContainer
}