package com.lagou.lagouee.widget.session

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.alpha.lagouapk.R
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.definition.c.PageId
import com.lagou.chat.chatlibrary.bean.ConversationBean
import com.lagou.chat.chatlibrary.view.EmojiconTextView
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.utils.GlideUtil
import com.lagou.commonlibs.utils.ImageUrlUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.lagouee.bean.CollectNoticeBean
import com.lagou.lagouee.utils.IntentUtils
import com.lagou.socketchannel.util.GsonUtil

/**
 * B端收藏session
 */
class CollectSessionView @JvmOverloads constructor(context: Context, attr: AttributeSet? = null, defStyleResId: Int = 0): BaseSessionView(context,attr,defStyleResId) {
    private var ivAvatar: ImageView = findViewById(R.id.iv_conversation_logo)
    private var ivUnRead: ImageView = findViewById(R.id.iv_unread_count)
    private var tvTitle: TextView = findViewById(R.id.tv_title)
    private var tvMessage: EmojiconTextView = findViewById(R.id.tv_message)
    private var dividerView: View = findViewById(R.id.divider_bottom)
    private var viewRoot: View = findViewById(R.id.session_collect_root)

    override fun getContentLayoutId(): Int = R.layout.layout_b_session_collect

    override fun bindData(bean: ConversationBean?, isLast: Boolean) {
        if (bean == null) {
            visibility = GONE
            return
        }
        visibility = VISIBLE
        viewRoot.setBackgroundResource(if (bean.isTop) R.color.color_f7fdfc else R.drawable.item_list_click_bg)
        dividerView.visibility = if (isLast) View.GONE else View.VISIBLE
        setUnReadRedDot(ivUnRead,bean.unReadCount)
        if (GlideUtil.isValidContextForGlide(context)) {
            ImageLoadUtils.with(context)
                .load(ImageUrlUtils.getLagouImageUrl(bean.icon))
                .dontAnimate().placeholder(R.drawable.im_ic_list_collection)
                .error(R.drawable.im_ic_list_collection)
                .into(ivAvatar)
        }
        val collectNoticeBean = GsonUtil.fromJson(bean.lastMessageContent, CollectNoticeBean::class.java)
        collectNoticeBean?.let {
            setTvAutoShowByText(tvTitle,StringUtil.jointString("", collectNoticeBean.collector, "收藏了你"))
            val unReadNum = collectNoticeBean.unReadNum
            tvMessage.text = StringUtil.jointString("", if (unReadNum > 99) "99+" else unReadNum.toString(), "个人才最近收藏了你的职位")
        }
        mTvTopAction.text = ResourceUtils.getString(if (bean.isTop) R.string.message_list_unpin else R.string.message_list_pin)
    }

    override fun onSessionClick(bean: ConversationBean, position: Int) {
        super.onSessionClick(bean, position)
        //收藏通知
        IntentUtils.startCollectMeActivity(context)
        AnalyticHelper.getInstance().sendClickInfo(PageId._1qg2, "s1sdk")
    }
}