package com.lagou.lagouee.widget.session

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.TextView
import com.alpha.lagouapk.R
import com.common.chat.SessionListShownUtils
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.bean.json.ClickInfo
import com.lagou.baselib.analytic.definition.c.PageId
import com.lagou.chat.chatlibrary.bean.ConversationBean
import com.lagou.chat.chatlibrary.view.CircleImageView
import com.lagou.chat.chatlibrary.view.EmojiconTextView
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.utils.DateUtils
import com.lagou.commonlibs.utils.GlideUtil
import com.lagou.commonlibs.utils.ImageUrlUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.manager.EnterManager
import com.lagou.lagouee.utils.IntentUtils

/**
 * B端招聘顾问
 */
class RecruitAdviserSessionView @JvmOverloads constructor(context: Context, attr: AttributeSet? = null, defStyleResId: Int = 0): BaseSessionView(context,attr,defStyleResId){
    private var ivAvatar:CircleImageView = findViewById(R.id.iv_conversation_logo)
    private var tvUnReadCount: TextView = findViewById(R.id.tv_unread_count)
    private var tvTitle: TextView = findViewById(R.id.tv_title)
    private var tvTime: TextView = findViewById(R.id.tv_message_time)
    private var tvMessage: EmojiconTextView = findViewById(R.id.tv_message)
    private var dividerView: View = findViewById(R.id.divider_bottom)
    private var viewRoot: View = findViewById(R.id.session_recruit_adviser_root)

    override fun getContentLayoutId(): Int = R.layout.layout_b_session_recruit_adviser

    override fun bindData(bean: ConversationBean?, isLast: Boolean) {
        if (bean == null) {
            visibility = GONE
            return
        }
        visibility = VISIBLE
        viewRoot.setBackgroundResource(if (bean.isTop) R.color.color_f7fdfc else R.drawable.item_list_click_bg)
        dividerView.visibility = if (isLast) View.GONE else View.VISIBLE
        setUnReadRedNum(tvUnReadCount,bean.unReadCount)
        if (GlideUtil.isValidContextForGlide(context)) {
            ImageLoadUtils.with(context)
                .load(ImageUrlUtils.getLagouImageUrl(bean.icon))
                .dontAnimate().placeholder(R.drawable.public_img_portrait)
                .error(R.drawable.im_img_ask_nankefu)
                .into(ivAvatar)
        }
        setTvAutoShowByText(tvTitle,bean.titleFirst)
        setTvAutoShowByText(tvTime, DateUtils.getMessageTimeV2(bean.time))
        SessionListShownUtils.setLastMessage(bean, tvMessage)
        mTvTopAction.text = ResourceUtils.getString(if (bean.isTop) R.string.message_list_unpin else R.string.message_list_pin)
    }

    override fun onSessionClick(bean: ConversationBean, position: Int) {
        super.onSessionClick(bean, position)
        IntentUtils.startBQuestionnaireActivity(context)
        val clickInfo = ClickInfo()
        clickInfo.address_id = "1qyb"
        if (bean.adviseMsgType > 0) {
            clickInfo.addClick_props("message_id", bean.adviseMsgType)
        }
        clickInfo.page_id = getPageId()
        AnalyticHelper.getInstance().sendClickInfo(clickInfo)
    }

    fun getPageId(): String? {
        var pageId: String? = null
        pageId = if (EnterManager.isAlreadyRecruiterCache()) {
            //已通过招聘者身份审核
            PageId._1qg2
        } else {
            if (!EnterManager.isHighCompany() && !EnterManager.authCanRelease()) {
                //已发职位
                PageId._1qg3
            } else {
                //未发职位
                PageId._1qg4
            }
        }
        return pageId
    }
}