package com.lagou.lagouee.widget.session

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.UserHeadUtils
import com.common.chat.SessionListShownUtils
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.baselib.analytic.definition.c.PageId
import com.lagou.chat.chatlibrary.bean.ConversationBean
import com.lagou.chat.chatlibrary.view.CircleImageView
import com.lagou.chat.chatlibrary.view.EmojiconTextView
import com.lagou.commonlibs.utils.DateUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.manager.EnterManager
import com.lagou.lagouee.ui.chat.ChatSource
import com.lagou.lagouee.ui.freeuser.message.BConversationManager
import com.lagou.lagouee.utils.IntentUtils

/**
 * B端普通会话
 */
class SessionView @JvmOverloads constructor(context: Context, attr: AttributeSet? = null, defStyleResId: Int = 0): BaseSessionView(context,attr,defStyleResId)  {
    private var ivAvatar:CircleImageView = findViewById(R.id.iv_conversation_logo)
    private var tvUnRead:TextView = findViewById(R.id.tv_unread_count)
    private var tvTime:TextView = findViewById(R.id.time)
    private var ivRecommendLabel:ImageView = findViewById(R.id.iv_recommend_label)
    private var tvTitleFirst:TextView = findViewById(R.id.tv_title_first)
    private var tvTitleCenter:TextView = findViewById(R.id.tv_title_center)
    private var tvMsgState:TextView = findViewById(R.id.conversation_message_state)
    private var tvMessage: EmojiconTextView = findViewById(R.id.message)
    private var tvTalentState: TextView = findViewById(R.id.tv_state)
    private var dividerLine: View = findViewById(R.id.divider_bottom)
    private var viewRoot:View = findViewById(R.id.normal_session_root)

    override fun getContentLayoutId(): Int = R.layout.layout_b_session_view

    override fun bindData(bean: ConversationBean?, isLast: Boolean) {
        if (bean == null) {
            visibility = GONE
            return
        }
        visibility = VISIBLE
        viewRoot.setBackgroundResource(if (bean.isTop) R.color.color_f7fdfc else R.drawable.item_list_click_bg)
        dividerLine.visibility = if (isLast) View.GONE else View.VISIBLE
        setUnReadRedNum(tvUnRead,bean.unReadCount)
        UserHeadUtils.setUserHeader(ivAvatar, bean.icon)
        setTvAutoShowByText(tvTitleFirst,bean.titleFirst)
        setTvAutoShowByText(tvTitleCenter,bean.titleCenter)
        setTvAutoShowByText(tvTime, DateUtils.getMessageTimeV2(bean.time))
        SessionListShownUtils.setLastMessage(bean, tvMessage)
        SessionListShownUtils.updateMsgReadState(bean, tvMsgState)
        //已投递简历的，标注已投递，已邀请投递的，标注已邀 已下载简历标记为已下载
        //V7.70已投标签不再展示
        //V7.81已邀标签不再展示
        if (!TextUtils.isEmpty(bean.communicationLevelTxt) && !TextUtils.equals(bean.communicationLevelTxt, "已投") && !TextUtils.equals(bean.communicationLevelTxt, "已邀")) {
            tvTalentState.visibility = VISIBLE
            tvTalentState.text = bean.communicationLevelTxt
            tvTalentState.setTextColor(ResourceUtils.getColor(bean.communicationLevelTxtColor))
            tvTalentState.setBackgroundResource(bean.communicationLevelTxtBack)
        } else {
            tvTalentState.visibility = GONE
        }
        ivRecommendLabel.visibility = if (bean.sessionFlag == 1) VISIBLE else GONE
        mTvTopAction.text = ResourceUtils.getString(if (bean.isTop) R.string.message_list_unpin else R.string.message_list_pin)
    }

    fun getMessageView() = tvMessage
    fun getTitleView() = tvTitleFirst
    fun clearUnRead(){
        setUnReadRedNum(tvUnRead,0)
    }

    override fun onSessionClick(bean: ConversationBean, position: Int) {
        BConversationManager.analytic1(position, bean)
        IntentUtils.startChatActivity(context, bean, ChatSource.IM_LIST_A)
        if (EnterManager.isAlreadyRecruiterCache()) {
            AnalyticHelper.getInstance().sendClickInfo(PageId._1qg2, "1qgy")
        } else {
            AnalyticHelper.getInstance().sendClickInfo(PageId._1qg3, "1qgi")
        }
    }
}